"""Debug UI for a2akit agents — Chat + Task Dashboard."""

from __future__ import annotations

from typing import TYPE_CHECKING

from fastapi.responses import HTMLResponse

if TYPE_CHECKING:
    from fastapi import FastAPI

CHAT_HTML = """\
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<title>a2akit Debug UI</title>
<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600&family=JetBrains+Mono:wght@400;500&display=swap" rel="stylesheet">
  <script type="module" crossorigin>(function(){const N=document.createElement("link").relList;if(N&&N.supports&&N.supports("modulepreload"))return;for(const _ of document.querySelectorAll('link[rel="modulepreload"]'))o(_);new MutationObserver(_=>{for(const C of _)if(C.type==="childList")for(const G of C.addedNodes)G.tagName==="LINK"&&G.rel==="modulepreload"&&o(G)}).observe(document,{childList:!0,subtree:!0});function O(_){const C={};return _.integrity&&(C.integrity=_.integrity),_.referrerPolicy&&(C.referrerPolicy=_.referrerPolicy),_.crossOrigin==="use-credentials"?C.credentials="include":_.crossOrigin==="anonymous"?C.credentials="omit":C.credentials="same-origin",C}function o(_){if(_.ep)return;_.ep=!0;const C=O(_);fetch(_.href,C)}})();var ff={exports:{}},zu={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Sm;function lv(){if(Sm)return zu;Sm=1;var S=Symbol.for("react.transitional.element"),N=Symbol.for("react.fragment");function O(o,_,C){var G=null;if(C!==void 0&&(G=""+C),_.key!==void 0&&(G=""+_.key),"key"in _){C={};for(var P in _)P!=="key"&&(C[P]=_[P])}else C=_;return _=C.ref,{$$typeof:S,type:o,key:G,ref:_!==void 0?_:null,props:C}}return zu.Fragment=N,zu.jsx=O,zu.jsxs=O,zu}var bm;function tv(){return bm||(bm=1,ff.exports=lv()),ff.exports}var r=tv(),sf={exports:{}},K={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tm;function av(){if(Tm)return K;Tm=1;var S=Symbol.for("react.transitional.element"),N=Symbol.for("react.portal"),O=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),_=Symbol.for("react.profiler"),C=Symbol.for("react.consumer"),G=Symbol.for("react.context"),P=Symbol.for("react.forward_ref"),M=Symbol.for("react.suspense"),g=Symbol.for("react.memo"),Y=Symbol.for("react.lazy"),H=Symbol.for("react.activity"),X=Symbol.iterator;function Tl(d){return d===null||typeof d!="object"?null:(d=X&&d[X]||d["@@iterator"],typeof d=="function"?d:null)}var Nl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},zl=Object.assign,nl={};function Al(d,A,D){this.props=d,this.context=A,this.refs=nl,this.updater=D||Nl}Al.prototype.isReactComponent={},Al.prototype.setState=function(d,A){if(typeof d!="object"&&typeof d!="function"&&d!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,d,A,"setState")},Al.prototype.forceUpdate=function(d){this.updater.enqueueForceUpdate(this,d,"forceUpdate")};function Ul(){}Ul.prototype=Al.prototype;function J(d,A,D){this.props=d,this.context=A,this.refs=nl,this.updater=D||Nl}var Ol=J.prototype=new Ul;Ol.constructor=J,zl(Ol,Al.prototype),Ol.isPureReactComponent=!0;var x=Array.isArray;function L(){}var Z={H:null,A:null,T:null,S:null},ul=Object.prototype.hasOwnProperty;function Sl(d,A,D){var R=D.ref;return{$$typeof:S,type:d,key:A,ref:R!==void 0?R:null,props:D}}function Ml(d,A){return Sl(d.type,A,d.props)}function bl(d){return typeof d=="object"&&d!==null&&d.$$typeof===S}function jl(d){var A={"=":"=0",":":"=2"};return"$"+d.replace(/[=:]/g,function(D){return A[D]})}var yt=/\\/+/g;function Il(d,A){return typeof d=="object"&&d!==null&&d.key!=null?jl(""+d.key):A.toString(36)}function Vl(d){switch(d.status){case"fulfilled":return d.value;case"rejected":throw d.reason;default:switch(typeof d.status=="string"?d.then(L,L):(d.status="pending",d.then(function(A){d.status==="pending"&&(d.status="fulfilled",d.value=A)},function(A){d.status==="pending"&&(d.status="rejected",d.reason=A)})),d.status){case"fulfilled":return d.value;case"rejected":throw d.reason}}throw d}function z(d,A,D,R,w){var $=typeof d;($==="undefined"||$==="boolean")&&(d=null);var sl=!1;if(d===null)sl=!0;else switch($){case"bigint":case"string":case"number":sl=!0;break;case"object":switch(d.$$typeof){case S:case N:sl=!0;break;case Y:return sl=d._init,z(sl(d._payload),A,D,R,w)}}if(sl)return w=w(d),sl=R===""?"."+Il(d,0):R,x(w)?(D="",sl!=null&&(D=sl.replace(yt,"$&/")+"/"),z(w,A,D,"",function(Me){return Me})):w!=null&&(bl(w)&&(w=Ml(w,D+(w.key==null||d&&d.key===w.key?"":(""+w.key).replace(yt,"$&/")+"/")+sl)),A.push(w)),1;sl=0;var $l=R===""?".":R+":";if(x(d))for(var Hl=0;Hl<d.length;Hl++)R=d[Hl],$=$l+Il(R,Hl),sl+=z(R,A,D,$,w);else if(Hl=Tl(d),typeof Hl=="function")for(d=Hl.call(d),Hl=0;!(R=d.next()).done;)R=R.value,$=$l+Il(R,Hl++),sl+=z(R,A,D,$,w);else if($==="object"){if(typeof d.then=="function")return z(Vl(d),A,D,R,w);throw A=String(d),Error("Objects are not valid as a React child (found: "+(A==="[object Object]"?"object with keys {"+Object.keys(d).join(", ")+"}":A)+"). If you meant to render a collection of children, use an array instead.")}return sl}function j(d,A,D){if(d==null)return d;var R=[],w=0;return z(d,R,"","",function($){return A.call(D,$,w++)}),R}function V(d){if(d._status===-1){var A=d._result;A=A(),A.then(function(D){(d._status===0||d._status===-1)&&(d._status=1,d._result=D)},function(D){(d._status===0||d._status===-1)&&(d._status=2,d._result=D)}),d._status===-1&&(d._status=0,d._result=A)}if(d._status===1)return d._result.default;throw d._result}var ml=typeof reportError=="function"?reportError:function(d){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var A=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof d=="object"&&d!==null&&typeof d.message=="string"?String(d.message):String(d),error:d});if(!window.dispatchEvent(A))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",d);return}console.error(d)},yl={map:j,forEach:function(d,A,D){j(d,function(){A.apply(this,arguments)},D)},count:function(d){var A=0;return j(d,function(){A++}),A},toArray:function(d){return j(d,function(A){return A})||[]},only:function(d){if(!bl(d))throw Error("React.Children.only expected to receive a single React element child.");return d}};return K.Activity=H,K.Children=yl,K.Component=Al,K.Fragment=O,K.Profiler=_,K.PureComponent=J,K.StrictMode=o,K.Suspense=M,K.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=Z,K.__COMPILER_RUNTIME={__proto__:null,c:function(d){return Z.H.useMemoCache(d)}},K.cache=function(d){return function(){return d.apply(null,arguments)}},K.cacheSignal=function(){return null},K.cloneElement=function(d,A,D){if(d==null)throw Error("The argument must be a React element, but you passed "+d+".");var R=zl({},d.props),w=d.key;if(A!=null)for($ in A.key!==void 0&&(w=""+A.key),A)!ul.call(A,$)||$==="key"||$==="__self"||$==="__source"||$==="ref"&&A.ref===void 0||(R[$]=A[$]);var $=arguments.length-2;if($===1)R.children=D;else if(1<$){for(var sl=Array($),$l=0;$l<$;$l++)sl[$l]=arguments[$l+2];R.children=sl}return Sl(d.type,w,R)},K.createContext=function(d){return d={$$typeof:G,_currentValue:d,_currentValue2:d,_threadCount:0,Provider:null,Consumer:null},d.Provider=d,d.Consumer={$$typeof:C,_context:d},d},K.createElement=function(d,A,D){var R,w={},$=null;if(A!=null)for(R in A.key!==void 0&&($=""+A.key),A)ul.call(A,R)&&R!=="key"&&R!=="__self"&&R!=="__source"&&(w[R]=A[R]);var sl=arguments.length-2;if(sl===1)w.children=D;else if(1<sl){for(var $l=Array(sl),Hl=0;Hl<sl;Hl++)$l[Hl]=arguments[Hl+2];w.children=$l}if(d&&d.defaultProps)for(R in sl=d.defaultProps,sl)w[R]===void 0&&(w[R]=sl[R]);return Sl(d,$,w)},K.createRef=function(){return{current:null}},K.forwardRef=function(d){return{$$typeof:P,render:d}},K.isValidElement=bl,K.lazy=function(d){return{$$typeof:Y,_payload:{_status:-1,_result:d},_init:V}},K.memo=function(d,A){return{$$typeof:g,type:d,compare:A===void 0?null:A}},K.startTransition=function(d){var A=Z.T,D={};Z.T=D;try{var R=d(),w=Z.S;w!==null&&w(D,R),typeof R=="object"&&R!==null&&typeof R.then=="function"&&R.then(L,ml)}catch($){ml($)}finally{A!==null&&D.types!==null&&(A.types=D.types),Z.T=A}},K.unstable_useCacheRefresh=function(){return Z.H.useCacheRefresh()},K.use=function(d){return Z.H.use(d)},K.useActionState=function(d,A,D){return Z.H.useActionState(d,A,D)},K.useCallback=function(d,A){return Z.H.useCallback(d,A)},K.useContext=function(d){return Z.H.useContext(d)},K.useDebugValue=function(){},K.useDeferredValue=function(d,A){return Z.H.useDeferredValue(d,A)},K.useEffect=function(d,A){return Z.H.useEffect(d,A)},K.useEffectEvent=function(d){return Z.H.useEffectEvent(d)},K.useId=function(){return Z.H.useId()},K.useImperativeHandle=function(d,A,D){return Z.H.useImperativeHandle(d,A,D)},K.useInsertionEffect=function(d,A){return Z.H.useInsertionEffect(d,A)},K.useLayoutEffect=function(d,A){return Z.H.useLayoutEffect(d,A)},K.useMemo=function(d,A){return Z.H.useMemo(d,A)},K.useOptimistic=function(d,A){return Z.H.useOptimistic(d,A)},K.useReducer=function(d,A,D){return Z.H.useReducer(d,A,D)},K.useRef=function(d){return Z.H.useRef(d)},K.useState=function(d){return Z.H.useState(d)},K.useSyncExternalStore=function(d,A,D){return Z.H.useSyncExternalStore(d,A,D)},K.useTransition=function(){return Z.H.useTransition()},K.version="19.2.4",K}var zm;function vf(){return zm||(zm=1,sf.exports=av()),sf.exports}var el=vf(),df={exports:{}},Eu={},of={exports:{}},mf={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Em;function ev(){return Em||(Em=1,(function(S){function N(z,j){var V=z.length;z.push(j);l:for(;0<V;){var ml=V-1>>>1,yl=z[ml];if(0<_(yl,j))z[ml]=j,z[V]=yl,V=ml;else break l}}function O(z){return z.length===0?null:z[0]}function o(z){if(z.length===0)return null;var j=z[0],V=z.pop();if(V!==j){z[0]=V;l:for(var ml=0,yl=z.length,d=yl>>>1;ml<d;){var A=2*(ml+1)-1,D=z[A],R=A+1,w=z[R];if(0>_(D,V))R<yl&&0>_(w,D)?(z[ml]=w,z[R]=V,ml=R):(z[ml]=D,z[A]=V,ml=A);else if(R<yl&&0>_(w,V))z[ml]=w,z[R]=V,ml=R;else break l}}return j}function _(z,j){var V=z.sortIndex-j.sortIndex;return V!==0?V:z.id-j.id}if(S.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var C=performance;S.unstable_now=function(){return C.now()}}else{var G=Date,P=G.now();S.unstable_now=function(){return G.now()-P}}var M=[],g=[],Y=1,H=null,X=3,Tl=!1,Nl=!1,zl=!1,nl=!1,Al=typeof setTimeout=="function"?setTimeout:null,Ul=typeof clearTimeout=="function"?clearTimeout:null,J=typeof setImmediate<"u"?setImmediate:null;function Ol(z){for(var j=O(g);j!==null;){if(j.callback===null)o(g);else if(j.startTime<=z)o(g),j.sortIndex=j.expirationTime,N(M,j);else break;j=O(g)}}function x(z){if(zl=!1,Ol(z),!Nl)if(O(M)!==null)Nl=!0,L||(L=!0,jl());else{var j=O(g);j!==null&&Vl(x,j.startTime-z)}}var L=!1,Z=-1,ul=5,Sl=-1;function Ml(){return nl?!0:!(S.unstable_now()-Sl<ul)}function bl(){if(nl=!1,L){var z=S.unstable_now();Sl=z;var j=!0;try{l:{Nl=!1,zl&&(zl=!1,Ul(Z),Z=-1),Tl=!0;var V=X;try{t:{for(Ol(z),H=O(M);H!==null&&!(H.expirationTime>z&&Ml());){var ml=H.callback;if(typeof ml=="function"){H.callback=null,X=H.priorityLevel;var yl=ml(H.expirationTime<=z);if(z=S.unstable_now(),typeof yl=="function"){H.callback=yl,Ol(z),j=!0;break t}H===O(M)&&o(M),Ol(z)}else o(M);H=O(M)}if(H!==null)j=!0;else{var d=O(g);d!==null&&Vl(x,d.startTime-z),j=!1}}break l}finally{H=null,X=V,Tl=!1}j=void 0}}finally{j?jl():L=!1}}}var jl;if(typeof J=="function")jl=function(){J(bl)};else if(typeof MessageChannel<"u"){var yt=new MessageChannel,Il=yt.port2;yt.port1.onmessage=bl,jl=function(){Il.postMessage(null)}}else jl=function(){Al(bl,0)};function Vl(z,j){Z=Al(function(){z(S.unstable_now())},j)}S.unstable_IdlePriority=5,S.unstable_ImmediatePriority=1,S.unstable_LowPriority=4,S.unstable_NormalPriority=3,S.unstable_Profiling=null,S.unstable_UserBlockingPriority=2,S.unstable_cancelCallback=function(z){z.callback=null},S.unstable_forceFrameRate=function(z){0>z||125<z?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):ul=0<z?Math.floor(1e3/z):5},S.unstable_getCurrentPriorityLevel=function(){return X},S.unstable_next=function(z){switch(X){case 1:case 2:case 3:var j=3;break;default:j=X}var V=X;X=j;try{return z()}finally{X=V}},S.unstable_requestPaint=function(){nl=!0},S.unstable_runWithPriority=function(z,j){switch(z){case 1:case 2:case 3:case 4:case 5:break;default:z=3}var V=X;X=z;try{return j()}finally{X=V}},S.unstable_scheduleCallback=function(z,j,V){var ml=S.unstable_now();switch(typeof V=="object"&&V!==null?(V=V.delay,V=typeof V=="number"&&0<V?ml+V:ml):V=ml,z){case 1:var yl=-1;break;case 2:yl=250;break;case 5:yl=1073741823;break;case 4:yl=1e4;break;default:yl=5e3}return yl=V+yl,z={id:Y++,callback:j,priorityLevel:z,startTime:V,expirationTime:yl,sortIndex:-1},V>ml?(z.sortIndex=V,N(g,z),O(M)===null&&z===O(g)&&(zl?(Ul(Z),Z=-1):zl=!0,Vl(x,V-ml))):(z.sortIndex=yl,N(M,z),Nl||Tl||(Nl=!0,L||(L=!0,jl()))),z},S.unstable_shouldYield=Ml,S.unstable_wrapCallback=function(z){var j=X;return function(){var V=X;X=j;try{return z.apply(this,arguments)}finally{X=V}}}})(mf)),mf}var pm;function uv(){return pm||(pm=1,of.exports=ev()),of.exports}var rf={exports:{}},Wl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Am;function nv(){if(Am)return Wl;Am=1;var S=vf();function N(M){var g="https://react.dev/errors/"+M;if(1<arguments.length){g+="?args[]="+encodeURIComponent(arguments[1]);for(var Y=2;Y<arguments.length;Y++)g+="&args[]="+encodeURIComponent(arguments[Y])}return"Minified React error #"+M+"; visit "+g+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function O(){}var o={d:{f:O,r:function(){throw Error(N(522))},D:O,C:O,L:O,m:O,X:O,S:O,M:O},p:0,findDOMNode:null},_=Symbol.for("react.portal");function C(M,g,Y){var H=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:_,key:H==null?null:""+H,children:M,containerInfo:g,implementation:Y}}var G=S.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function P(M,g){if(M==="font")return"";if(typeof g=="string")return g==="use-credentials"?g:""}return Wl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=o,Wl.createPortal=function(M,g){var Y=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!g||g.nodeType!==1&&g.nodeType!==9&&g.nodeType!==11)throw Error(N(299));return C(M,g,null,Y)},Wl.flushSync=function(M){var g=G.T,Y=o.p;try{if(G.T=null,o.p=2,M)return M()}finally{G.T=g,o.p=Y,o.d.f()}},Wl.preconnect=function(M,g){typeof M=="string"&&(g?(g=g.crossOrigin,g=typeof g=="string"?g==="use-credentials"?g:"":void 0):g=null,o.d.C(M,g))},Wl.prefetchDNS=function(M){typeof M=="string"&&o.d.D(M)},Wl.preinit=function(M,g){if(typeof M=="string"&&g&&typeof g.as=="string"){var Y=g.as,H=P(Y,g.crossOrigin),X=typeof g.integrity=="string"?g.integrity:void 0,Tl=typeof g.fetchPriority=="string"?g.fetchPriority:void 0;Y==="style"?o.d.S(M,typeof g.precedence=="string"?g.precedence:void 0,{crossOrigin:H,integrity:X,fetchPriority:Tl}):Y==="script"&&o.d.X(M,{crossOrigin:H,integrity:X,fetchPriority:Tl,nonce:typeof g.nonce=="string"?g.nonce:void 0})}},Wl.preinitModule=function(M,g){if(typeof M=="string")if(typeof g=="object"&&g!==null){if(g.as==null||g.as==="script"){var Y=P(g.as,g.crossOrigin);o.d.M(M,{crossOrigin:Y,integrity:typeof g.integrity=="string"?g.integrity:void 0,nonce:typeof g.nonce=="string"?g.nonce:void 0})}}else g==null&&o.d.M(M)},Wl.preload=function(M,g){if(typeof M=="string"&&typeof g=="object"&&g!==null&&typeof g.as=="string"){var Y=g.as,H=P(Y,g.crossOrigin);o.d.L(M,Y,{crossOrigin:H,integrity:typeof g.integrity=="string"?g.integrity:void 0,nonce:typeof g.nonce=="string"?g.nonce:void 0,type:typeof g.type=="string"?g.type:void 0,fetchPriority:typeof g.fetchPriority=="string"?g.fetchPriority:void 0,referrerPolicy:typeof g.referrerPolicy=="string"?g.referrerPolicy:void 0,imageSrcSet:typeof g.imageSrcSet=="string"?g.imageSrcSet:void 0,imageSizes:typeof g.imageSizes=="string"?g.imageSizes:void 0,media:typeof g.media=="string"?g.media:void 0})}},Wl.preloadModule=function(M,g){if(typeof M=="string")if(g){var Y=P(g.as,g.crossOrigin);o.d.m(M,{as:typeof g.as=="string"&&g.as!=="script"?g.as:void 0,crossOrigin:Y,integrity:typeof g.integrity=="string"?g.integrity:void 0})}else o.d.m(M)},Wl.requestFormReset=function(M){o.d.r(M)},Wl.unstable_batchedUpdates=function(M,g){return M(g)},Wl.useFormState=function(M,g,Y){return G.H.useFormState(M,g,Y)},Wl.useFormStatus=function(){return G.H.useHostTransitionStatus()},Wl.version="19.2.4",Wl}var Om;function iv(){if(Om)return rf.exports;Om=1;function S(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(S)}catch(N){console.error(N)}}return S(),rf.exports=nv(),rf.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var _m;function cv(){if(_m)return Eu;_m=1;var S=uv(),N=vf(),O=iv();function o(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function _(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function C(l){var t=l,a=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(a=t.return),l=t.return;while(l)}return t.tag===3?a:null}function G(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function P(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function M(l){if(C(l)!==l)throw Error(o(188))}function g(l){var t=l.alternate;if(!t){if(t=C(l),t===null)throw Error(o(188));return t!==l?null:l}for(var a=l,e=t;;){var u=a.return;if(u===null)break;var n=u.alternate;if(n===null){if(e=u.return,e!==null){a=e;continue}break}if(u.child===n.child){for(n=u.child;n;){if(n===a)return M(u),l;if(n===e)return M(u),t;n=n.sibling}throw Error(o(188))}if(a.return!==e.return)a=u,e=n;else{for(var i=!1,c=u.child;c;){if(c===a){i=!0,a=u,e=n;break}if(c===e){i=!0,e=u,a=n;break}c=c.sibling}if(!i){for(c=n.child;c;){if(c===a){i=!0,a=n,e=u;break}if(c===e){i=!0,e=n,a=u;break}c=c.sibling}if(!i)throw Error(o(189))}}if(a.alternate!==e)throw Error(o(190))}if(a.tag!==3)throw Error(o(188));return a.stateNode.current===a?l:t}function Y(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=Y(l),t!==null)return t;l=l.sibling}return null}var H=Object.assign,X=Symbol.for("react.element"),Tl=Symbol.for("react.transitional.element"),Nl=Symbol.for("react.portal"),zl=Symbol.for("react.fragment"),nl=Symbol.for("react.strict_mode"),Al=Symbol.for("react.profiler"),Ul=Symbol.for("react.consumer"),J=Symbol.for("react.context"),Ol=Symbol.for("react.forward_ref"),x=Symbol.for("react.suspense"),L=Symbol.for("react.suspense_list"),Z=Symbol.for("react.memo"),ul=Symbol.for("react.lazy"),Sl=Symbol.for("react.activity"),Ml=Symbol.for("react.memo_cache_sentinel"),bl=Symbol.iterator;function jl(l){return l===null||typeof l!="object"?null:(l=bl&&l[bl]||l["@@iterator"],typeof l=="function"?l:null)}var yt=Symbol.for("react.client.reference");function Il(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===yt?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case zl:return"Fragment";case Al:return"Profiler";case nl:return"StrictMode";case x:return"Suspense";case L:return"SuspenseList";case Sl:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case Nl:return"Portal";case J:return l.displayName||"Context";case Ul:return(l._context.displayName||"Context")+".Consumer";case Ol:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case Z:return t=l.displayName||null,t!==null?t:Il(l.type)||"Memo";case ul:t=l._payload,l=l._init;try{return Il(l(t))}catch{}}return null}var Vl=Array.isArray,z=N.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,j=O.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,V={pending:!1,data:null,method:null,action:null},ml=[],yl=-1;function d(l){return{current:l}}function A(l){0>yl||(l.current=ml[yl],ml[yl]=null,yl--)}function D(l,t){yl++,ml[yl]=l.current,l.current=t}var R=d(null),w=d(null),$=d(null),sl=d(null);function $l(l,t){switch(D($,t),D(w,l),D(R,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?Qo(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=Qo(t),l=Zo(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}A(R),D(R,l)}function Hl(){A(R),A(w),A($)}function Me(l){l.memoizedState!==null&&D(sl,l);var t=R.current,a=Zo(t,l.type);t!==a&&(D(w,l),D(R,a))}function pu(l){w.current===l&&(A(R),A(w)),sl.current===l&&(A(sl),gu._currentValue=V)}var Vn,yf;function pa(l){if(Vn===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\\n( *(at )?)/);Vn=t&&t[1]||"",yf=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Vn+l+yf}var Ln=!1;function Kn(l,t){if(!l||Ln)return"";Ln=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var e={DetermineComponentFrameRoot:function(){try{if(t){var p=function(){throw Error()};if(Object.defineProperty(p.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(p,[])}catch(b){var y=b}Reflect.construct(l,[],p)}else{try{p.call()}catch(b){y=b}l.call(p.prototype)}}else{try{throw Error()}catch(b){y=b}(p=l())&&typeof p.catch=="function"&&p.catch(function(){})}}catch(b){if(b&&y&&typeof b.stack=="string")return[b.stack,y.stack]}return[null,null]}};e.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var u=Object.getOwnPropertyDescriptor(e.DetermineComponentFrameRoot,"name");u&&u.configurable&&Object.defineProperty(e.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=e.DetermineComponentFrameRoot(),i=n[0],c=n[1];if(i&&c){var f=i.split(`
`),h=c.split(`
`);for(u=e=0;e<f.length&&!f[e].includes("DetermineComponentFrameRoot");)e++;for(;u<h.length&&!h[u].includes("DetermineComponentFrameRoot");)u++;if(e===f.length||u===h.length)for(e=f.length-1,u=h.length-1;1<=e&&0<=u&&f[e]!==h[u];)u--;for(;1<=e&&0<=u;e--,u--)if(f[e]!==h[u]){if(e!==1||u!==1)do if(e--,u--,0>u||f[e]!==h[u]){var T=`
`+f[e].replace(" at new "," at ");return l.displayName&&T.includes("<anonymous>")&&(T=T.replace("<anonymous>",l.displayName)),T}while(1<=e&&0<=u);break}}}finally{Ln=!1,Error.prepareStackTrace=a}return(a=l?l.displayName||l.name:"")?pa(a):""}function Dm(l,t){switch(l.tag){case 26:case 27:case 5:return pa(l.type);case 16:return pa("Lazy");case 13:return l.child!==t&&t!==null?pa("Suspense Fallback"):pa("Suspense");case 19:return pa("SuspenseList");case 0:case 15:return Kn(l.type,!1);case 11:return Kn(l.type.render,!1);case 1:return Kn(l.type,!0);case 31:return pa("Activity");default:return""}}function gf(l){try{var t="",a=null;do t+=Dm(l,a),a=l,l=l.return;while(l);return t}catch(e){return`
Error generating stack: `+e.message+`
`+e.stack}}var Jn=Object.prototype.hasOwnProperty,wn=S.unstable_scheduleCallback,kn=S.unstable_cancelCallback,Um=S.unstable_shouldYield,Hm=S.unstable_requestPaint,it=S.unstable_now,Rm=S.unstable_getCurrentPriorityLevel,Sf=S.unstable_ImmediatePriority,bf=S.unstable_UserBlockingPriority,Au=S.unstable_NormalPriority,Cm=S.unstable_LowPriority,Tf=S.unstable_IdlePriority,qm=S.log,Bm=S.unstable_setDisableYieldValue,je=null,ct=null;function It(l){if(typeof qm=="function"&&Bm(l),ct&&typeof ct.setStrictMode=="function")try{ct.setStrictMode(je,l)}catch{}}var ft=Math.clz32?Math.clz32:Xm,Ym=Math.log,Gm=Math.LN2;function Xm(l){return l>>>=0,l===0?32:31-(Ym(l)/Gm|0)|0}var Ou=256,_u=262144,Nu=4194304;function Aa(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Mu(l,t,a){var e=l.pendingLanes;if(e===0)return 0;var u=0,n=l.suspendedLanes,i=l.pingedLanes;l=l.warmLanes;var c=e&134217727;return c!==0?(e=c&~n,e!==0?u=Aa(e):(i&=c,i!==0?u=Aa(i):a||(a=c&~l,a!==0&&(u=Aa(a))))):(c=e&~n,c!==0?u=Aa(c):i!==0?u=Aa(i):a||(a=e&~l,a!==0&&(u=Aa(a)))),u===0?0:t!==0&&t!==u&&(t&n)===0&&(n=u&-u,a=t&-t,n>=a||n===32&&(a&4194048)!==0)?t:u}function xe(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function Qm(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function zf(){var l=Nu;return Nu<<=1,(Nu&62914560)===0&&(Nu=4194304),l}function Wn(l){for(var t=[],a=0;31>a;a++)t.push(l);return t}function De(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function Zm(l,t,a,e,u,n){var i=l.pendingLanes;l.pendingLanes=a,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=a,l.entangledLanes&=a,l.errorRecoveryDisabledLanes&=a,l.shellSuspendCounter=0;var c=l.entanglements,f=l.expirationTimes,h=l.hiddenUpdates;for(a=i&~a;0<a;){var T=31-ft(a),p=1<<T;c[T]=0,f[T]=-1;var y=h[T];if(y!==null)for(h[T]=null,T=0;T<y.length;T++){var b=y[T];b!==null&&(b.lane&=-536870913)}a&=~p}e!==0&&Ef(l,e,0),n!==0&&u===0&&l.tag!==0&&(l.suspendedLanes|=n&~(i&~t))}function Ef(l,t,a){l.pendingLanes|=t,l.suspendedLanes&=~t;var e=31-ft(t);l.entangledLanes|=t,l.entanglements[e]=l.entanglements[e]|1073741824|a&261930}function pf(l,t){var a=l.entangledLanes|=t;for(l=l.entanglements;a;){var e=31-ft(a),u=1<<e;u&t|l[e]&t&&(l[e]|=t),a&=~u}}function Af(l,t){var a=t&-t;return a=(a&42)!==0?1:$n(a),(a&(l.suspendedLanes|t))!==0?0:a}function $n(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function Fn(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Of(){var l=j.p;return l!==0?l:(l=window.event,l===void 0?32:om(l.type))}function _f(l,t){var a=j.p;try{return j.p=l,t()}finally{j.p=a}}var Pt=Math.random().toString(36).slice(2),Ll="__reactFiber$"+Pt,Pl="__reactProps$"+Pt,Va="__reactContainer$"+Pt,In="__reactEvents$"+Pt,Vm="__reactListeners$"+Pt,Lm="__reactHandles$"+Pt,Nf="__reactResources$"+Pt,Ue="__reactMarker$"+Pt;function Pn(l){delete l[Ll],delete l[Pl],delete l[In],delete l[Vm],delete l[Lm]}function La(l){var t=l[Ll];if(t)return t;for(var a=l.parentNode;a;){if(t=a[Va]||a[Ll]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(l=Wo(l);l!==null;){if(a=l[Ll])return a;l=Wo(l)}return t}l=a,a=l.parentNode}return null}function Ka(l){if(l=l[Ll]||l[Va]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function He(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(o(33))}function Ja(l){var t=l[Nf];return t||(t=l[Nf]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Ql(l){l[Ue]=!0}var Mf=new Set,jf={};function Oa(l,t){wa(l,t),wa(l+"Capture",t)}function wa(l,t){for(jf[l]=t,l=0;l<t.length;l++)Mf.add(t[l])}var Km=RegExp("^[:A-Z_a-z\\\\u00C0-\\\\u00D6\\\\u00D8-\\\\u00F6\\\\u00F8-\\\\u02FF\\\\u0370-\\\\u037D\\\\u037F-\\\\u1FFF\\\\u200C-\\\\u200D\\\\u2070-\\\\u218F\\\\u2C00-\\\\u2FEF\\\\u3001-\\\\uD7FF\\\\uF900-\\\\uFDCF\\\\uFDF0-\\\\uFFFD][:A-Z_a-z\\\\u00C0-\\\\u00D6\\\\u00D8-\\\\u00F6\\\\u00F8-\\\\u02FF\\\\u0370-\\\\u037D\\\\u037F-\\\\u1FFF\\\\u200C-\\\\u200D\\\\u2070-\\\\u218F\\\\u2C00-\\\\u2FEF\\\\u3001-\\\\uD7FF\\\\uF900-\\\\uFDCF\\\\uFDF0-\\\\uFFFD\\\\-.0-9\\\\u00B7\\\\u0300-\\\\u036F\\\\u203F-\\\\u2040]*$"),xf={},Df={};function Jm(l){return Jn.call(Df,l)?!0:Jn.call(xf,l)?!1:Km.test(l)?Df[l]=!0:(xf[l]=!0,!1)}function ju(l,t,a){if(Jm(t))if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var e=t.toLowerCase().slice(0,5);if(e!=="data-"&&e!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+a)}}function xu(l,t,a){if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+a)}}function Rt(l,t,a,e){if(e===null)l.removeAttribute(a);else{switch(typeof e){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(a);return}l.setAttributeNS(t,a,""+e)}}function gt(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Uf(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function wm(l,t,a){var e=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof e<"u"&&typeof e.get=="function"&&typeof e.set=="function"){var u=e.get,n=e.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return u.call(this)},set:function(i){a=""+i,n.call(this,i)}}),Object.defineProperty(l,t,{enumerable:e.enumerable}),{getValue:function(){return a},setValue:function(i){a=""+i},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function li(l){if(!l._valueTracker){var t=Uf(l)?"checked":"value";l._valueTracker=wm(l,t,""+l[t])}}function Hf(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var a=t.getValue(),e="";return l&&(e=Uf(l)?l.checked?"true":"false":l.value),l=e,l!==a?(t.setValue(l),!0):!1}function Du(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var km=/[\\n"\\\\]/g;function St(l){return l.replace(km,function(t){return"\\\\"+t.charCodeAt(0).toString(16)+" "})}function ti(l,t,a,e,u,n,i,c){l.name="",i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?l.type=i:l.removeAttribute("type"),t!=null?i==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+gt(t)):l.value!==""+gt(t)&&(l.value=""+gt(t)):i!=="submit"&&i!=="reset"||l.removeAttribute("value"),t!=null?ai(l,i,gt(t)):a!=null?ai(l,i,gt(a)):e!=null&&l.removeAttribute("value"),u==null&&n!=null&&(l.defaultChecked=!!n),u!=null&&(l.checked=u&&typeof u!="function"&&typeof u!="symbol"),c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.name=""+gt(c):l.removeAttribute("name")}function Rf(l,t,a,e,u,n,i,c){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||a!=null){if(!(n!=="submit"&&n!=="reset"||t!=null)){li(l);return}a=a!=null?""+gt(a):"",t=t!=null?""+gt(t):a,c||t===l.value||(l.value=t),l.defaultValue=t}e=e??u,e=typeof e!="function"&&typeof e!="symbol"&&!!e,l.checked=c?l.checked:!!e,l.defaultChecked=!!e,i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"&&(l.name=i),li(l)}function ai(l,t,a){t==="number"&&Du(l.ownerDocument)===l||l.defaultValue===""+a||(l.defaultValue=""+a)}function ka(l,t,a,e){if(l=l.options,t){t={};for(var u=0;u<a.length;u++)t["$"+a[u]]=!0;for(a=0;a<l.length;a++)u=t.hasOwnProperty("$"+l[a].value),l[a].selected!==u&&(l[a].selected=u),u&&e&&(l[a].defaultSelected=!0)}else{for(a=""+gt(a),t=null,u=0;u<l.length;u++){if(l[u].value===a){l[u].selected=!0,e&&(l[u].defaultSelected=!0);return}t!==null||l[u].disabled||(t=l[u])}t!==null&&(t.selected=!0)}}function Cf(l,t,a){if(t!=null&&(t=""+gt(t),t!==l.value&&(l.value=t),a==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=a!=null?""+gt(a):""}function qf(l,t,a,e){if(t==null){if(e!=null){if(a!=null)throw Error(o(92));if(Vl(e)){if(1<e.length)throw Error(o(93));e=e[0]}a=e}a==null&&(a=""),t=a}a=gt(t),l.defaultValue=a,e=l.textContent,e===a&&e!==""&&e!==null&&(l.value=e),li(l)}function Wa(l,t){if(t){var a=l.firstChild;if(a&&a===l.lastChild&&a.nodeType===3){a.nodeValue=t;return}}l.textContent=t}var Wm=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Bf(l,t,a){var e=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?e?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":e?l.setProperty(t,a):typeof a!="number"||a===0||Wm.has(t)?t==="float"?l.cssFloat=a:l[t]=(""+a).trim():l[t]=a+"px"}function Yf(l,t,a){if(t!=null&&typeof t!="object")throw Error(o(62));if(l=l.style,a!=null){for(var e in a)!a.hasOwnProperty(e)||t!=null&&t.hasOwnProperty(e)||(e.indexOf("--")===0?l.setProperty(e,""):e==="float"?l.cssFloat="":l[e]="");for(var u in t)e=t[u],t.hasOwnProperty(u)&&a[u]!==e&&Bf(l,u,e)}else for(var n in t)t.hasOwnProperty(n)&&Bf(l,n,t[n])}function ei(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var $m=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Fm=/^[\\u0000-\\u001F ]*j[\\r\\n\\t]*a[\\r\\n\\t]*v[\\r\\n\\t]*a[\\r\\n\\t]*s[\\r\\n\\t]*c[\\r\\n\\t]*r[\\r\\n\\t]*i[\\r\\n\\t]*p[\\r\\n\\t]*t[\\r\\n\\t]*:/i;function Uu(l){return Fm.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function Ct(){}var ui=null;function ni(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var $a=null,Fa=null;function Gf(l){var t=Ka(l);if(t&&(l=t.stateNode)){var a=l[Pl]||null;l:switch(l=t.stateNode,t.type){case"input":if(ti(l,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=l;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+St(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var e=a[t];if(e!==l&&e.form===l.form){var u=e[Pl]||null;if(!u)throw Error(o(90));ti(e,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name)}}for(t=0;t<a.length;t++)e=a[t],e.form===l.form&&Hf(e)}break l;case"textarea":Cf(l,a.value,a.defaultValue);break l;case"select":t=a.value,t!=null&&ka(l,!!a.multiple,t,!1)}}}var ii=!1;function Xf(l,t,a){if(ii)return l(t,a);ii=!0;try{var e=l(t);return e}finally{if(ii=!1,($a!==null||Fa!==null)&&(Tn(),$a&&(t=$a,l=Fa,Fa=$a=null,Gf(t),l)))for(t=0;t<l.length;t++)Gf(l[t])}}function Re(l,t){var a=l.stateNode;if(a===null)return null;var e=a[Pl]||null;if(e===null)return null;a=e[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(e=!e.disabled)||(l=l.type,e=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!e;break l;default:l=!1}if(l)return null;if(a&&typeof a!="function")throw Error(o(231,t,typeof a));return a}var qt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),ci=!1;if(qt)try{var Ce={};Object.defineProperty(Ce,"passive",{get:function(){ci=!0}}),window.addEventListener("test",Ce,Ce),window.removeEventListener("test",Ce,Ce)}catch{ci=!1}var la=null,fi=null,Hu=null;function Qf(){if(Hu)return Hu;var l,t=fi,a=t.length,e,u="value"in la?la.value:la.textContent,n=u.length;for(l=0;l<a&&t[l]===u[l];l++);var i=a-l;for(e=1;e<=i&&t[a-e]===u[n-e];e++);return Hu=u.slice(l,1<e?1-e:void 0)}function Ru(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function Cu(){return!0}function Zf(){return!1}function lt(l){function t(a,e,u,n,i){this._reactName=a,this._targetInst=u,this.type=e,this.nativeEvent=n,this.target=i,this.currentTarget=null;for(var c in l)l.hasOwnProperty(c)&&(a=l[c],this[c]=a?a(n):n[c]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?Cu:Zf,this.isPropagationStopped=Zf,this}return H(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Cu)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Cu)},persist:function(){},isPersistent:Cu}),t}var _a={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},qu=lt(_a),qe=H({},_a,{view:0,detail:0}),Im=lt(qe),si,di,Be,Bu=H({},qe,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:mi,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Be&&(Be&&l.type==="mousemove"?(si=l.screenX-Be.screenX,di=l.screenY-Be.screenY):di=si=0,Be=l),si)},movementY:function(l){return"movementY"in l?l.movementY:di}}),Vf=lt(Bu),Pm=H({},Bu,{dataTransfer:0}),lr=lt(Pm),tr=H({},qe,{relatedTarget:0}),oi=lt(tr),ar=H({},_a,{animationName:0,elapsedTime:0,pseudoElement:0}),er=lt(ar),ur=H({},_a,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),nr=lt(ur),ir=H({},_a,{data:0}),Lf=lt(ir),cr={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},fr={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},sr={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function dr(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=sr[l])?!!t[l]:!1}function mi(){return dr}var or=H({},qe,{key:function(l){if(l.key){var t=cr[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Ru(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?fr[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:mi,charCode:function(l){return l.type==="keypress"?Ru(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Ru(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),mr=lt(or),rr=H({},Bu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Kf=lt(rr),vr=H({},qe,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:mi}),hr=lt(vr),yr=H({},_a,{propertyName:0,elapsedTime:0,pseudoElement:0}),gr=lt(yr),Sr=H({},Bu,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),br=lt(Sr),Tr=H({},_a,{newState:0,oldState:0}),zr=lt(Tr),Er=[9,13,27,32],ri=qt&&"CompositionEvent"in window,Ye=null;qt&&"documentMode"in document&&(Ye=document.documentMode);var pr=qt&&"TextEvent"in window&&!Ye,Jf=qt&&(!ri||Ye&&8<Ye&&11>=Ye),wf=" ",kf=!1;function Wf(l,t){switch(l){case"keyup":return Er.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function $f(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Ia=!1;function Ar(l,t){switch(l){case"compositionend":return $f(t);case"keypress":return t.which!==32?null:(kf=!0,wf);case"textInput":return l=t.data,l===wf&&kf?null:l;default:return null}}function Or(l,t){if(Ia)return l==="compositionend"||!ri&&Wf(l,t)?(l=Qf(),Hu=fi=la=null,Ia=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Jf&&t.locale!=="ko"?null:t.data;default:return null}}var _r={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Ff(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!_r[l.type]:t==="textarea"}function If(l,t,a,e){$a?Fa?Fa.push(e):Fa=[e]:$a=e,t=Nn(t,"onChange"),0<t.length&&(a=new qu("onChange","change",null,a,e),l.push({event:a,listeners:t}))}var Ge=null,Xe=null;function Nr(l){Co(l,0)}function Yu(l){var t=He(l);if(Hf(t))return l}function Pf(l,t){if(l==="change")return t}var ls=!1;if(qt){var vi;if(qt){var hi="oninput"in document;if(!hi){var ts=document.createElement("div");ts.setAttribute("oninput","return;"),hi=typeof ts.oninput=="function"}vi=hi}else vi=!1;ls=vi&&(!document.documentMode||9<document.documentMode)}function as(){Ge&&(Ge.detachEvent("onpropertychange",es),Xe=Ge=null)}function es(l){if(l.propertyName==="value"&&Yu(Xe)){var t=[];If(t,Xe,l,ni(l)),Xf(Nr,t)}}function Mr(l,t,a){l==="focusin"?(as(),Ge=t,Xe=a,Ge.attachEvent("onpropertychange",es)):l==="focusout"&&as()}function jr(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Yu(Xe)}function xr(l,t){if(l==="click")return Yu(t)}function Dr(l,t){if(l==="input"||l==="change")return Yu(t)}function Ur(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var st=typeof Object.is=="function"?Object.is:Ur;function Qe(l,t){if(st(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var a=Object.keys(l),e=Object.keys(t);if(a.length!==e.length)return!1;for(e=0;e<a.length;e++){var u=a[e];if(!Jn.call(t,u)||!st(l[u],t[u]))return!1}return!0}function us(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function ns(l,t){var a=us(l);l=0;for(var e;a;){if(a.nodeType===3){if(e=l+a.textContent.length,l<=t&&e>=t)return{node:a,offset:t-l};l=e}l:{for(;a;){if(a.nextSibling){a=a.nextSibling;break l}a=a.parentNode}a=void 0}a=us(a)}}function is(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?is(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function cs(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Du(l.document);t instanceof l.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)l=t.contentWindow;else break;t=Du(l.document)}return t}function yi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var Hr=qt&&"documentMode"in document&&11>=document.documentMode,Pa=null,gi=null,Ze=null,Si=!1;function fs(l,t,a){var e=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Si||Pa==null||Pa!==Du(e)||(e=Pa,"selectionStart"in e&&yi(e)?e={start:e.selectionStart,end:e.selectionEnd}:(e=(e.ownerDocument&&e.ownerDocument.defaultView||window).getSelection(),e={anchorNode:e.anchorNode,anchorOffset:e.anchorOffset,focusNode:e.focusNode,focusOffset:e.focusOffset}),Ze&&Qe(Ze,e)||(Ze=e,e=Nn(gi,"onSelect"),0<e.length&&(t=new qu("onSelect","select",null,t,a),l.push({event:t,listeners:e}),t.target=Pa)))}function Na(l,t){var a={};return a[l.toLowerCase()]=t.toLowerCase(),a["Webkit"+l]="webkit"+t,a["Moz"+l]="moz"+t,a}var le={animationend:Na("Animation","AnimationEnd"),animationiteration:Na("Animation","AnimationIteration"),animationstart:Na("Animation","AnimationStart"),transitionrun:Na("Transition","TransitionRun"),transitionstart:Na("Transition","TransitionStart"),transitioncancel:Na("Transition","TransitionCancel"),transitionend:Na("Transition","TransitionEnd")},bi={},ss={};qt&&(ss=document.createElement("div").style,"AnimationEvent"in window||(delete le.animationend.animation,delete le.animationiteration.animation,delete le.animationstart.animation),"TransitionEvent"in window||delete le.transitionend.transition);function Ma(l){if(bi[l])return bi[l];if(!le[l])return l;var t=le[l],a;for(a in t)if(t.hasOwnProperty(a)&&a in ss)return bi[l]=t[a];return l}var ds=Ma("animationend"),os=Ma("animationiteration"),ms=Ma("animationstart"),Rr=Ma("transitionrun"),Cr=Ma("transitionstart"),qr=Ma("transitioncancel"),rs=Ma("transitionend"),vs=new Map,Ti="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Ti.push("scrollEnd");function Nt(l,t){vs.set(l,t),Oa(t,[l])}var Gu=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},bt=[],te=0,zi=0;function Xu(){for(var l=te,t=zi=te=0;t<l;){var a=bt[t];bt[t++]=null;var e=bt[t];bt[t++]=null;var u=bt[t];bt[t++]=null;var n=bt[t];if(bt[t++]=null,e!==null&&u!==null){var i=e.pending;i===null?u.next=u:(u.next=i.next,i.next=u),e.pending=u}n!==0&&hs(a,u,n)}}function Qu(l,t,a,e){bt[te++]=l,bt[te++]=t,bt[te++]=a,bt[te++]=e,zi|=e,l.lanes|=e,l=l.alternate,l!==null&&(l.lanes|=e)}function Ei(l,t,a,e){return Qu(l,t,a,e),Zu(l)}function ja(l,t){return Qu(l,null,null,t),Zu(l)}function hs(l,t,a){l.lanes|=a;var e=l.alternate;e!==null&&(e.lanes|=a);for(var u=!1,n=l.return;n!==null;)n.childLanes|=a,e=n.alternate,e!==null&&(e.childLanes|=a),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(u=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,u&&t!==null&&(u=31-ft(a),l=n.hiddenUpdates,e=l[u],e===null?l[u]=[t]:e.push(t),t.lane=a|536870912),n):null}function Zu(l){if(50<du)throw du=0,Dc=null,Error(o(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var ae={};function Br(l,t,a,e){this.tag=l,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=e,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function dt(l,t,a,e){return new Br(l,t,a,e)}function pi(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Bt(l,t){var a=l.alternate;return a===null?(a=dt(l.tag,t,l.key,l.mode),a.elementType=l.elementType,a.type=l.type,a.stateNode=l.stateNode,a.alternate=l,l.alternate=a):(a.pendingProps=t,a.type=l.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=l.flags&65011712,a.childLanes=l.childLanes,a.lanes=l.lanes,a.child=l.child,a.memoizedProps=l.memoizedProps,a.memoizedState=l.memoizedState,a.updateQueue=l.updateQueue,t=l.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=l.sibling,a.index=l.index,a.ref=l.ref,a.refCleanup=l.refCleanup,a}function ys(l,t){l.flags&=65011714;var a=l.alternate;return a===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=a.childLanes,l.lanes=a.lanes,l.child=a.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=a.memoizedProps,l.memoizedState=a.memoizedState,l.updateQueue=a.updateQueue,l.type=a.type,t=a.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Vu(l,t,a,e,u,n){var i=0;if(e=l,typeof l=="function")pi(l)&&(i=1);else if(typeof l=="string")i=Z0(l,a,R.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case Sl:return l=dt(31,a,t,u),l.elementType=Sl,l.lanes=n,l;case zl:return xa(a.children,u,n,t);case nl:i=8,u|=24;break;case Al:return l=dt(12,a,t,u|2),l.elementType=Al,l.lanes=n,l;case x:return l=dt(13,a,t,u),l.elementType=x,l.lanes=n,l;case L:return l=dt(19,a,t,u),l.elementType=L,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case J:i=10;break l;case Ul:i=9;break l;case Ol:i=11;break l;case Z:i=14;break l;case ul:i=16,e=null;break l}i=29,a=Error(o(130,l===null?"null":typeof l,"")),e=null}return t=dt(i,a,t,u),t.elementType=l,t.type=e,t.lanes=n,t}function xa(l,t,a,e){return l=dt(7,l,e,t),l.lanes=a,l}function Ai(l,t,a){return l=dt(6,l,null,t),l.lanes=a,l}function gs(l){var t=dt(18,null,null,0);return t.stateNode=l,t}function Oi(l,t,a){return t=dt(4,l.children!==null?l.children:[],l.key,t),t.lanes=a,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var Ss=new WeakMap;function Tt(l,t){if(typeof l=="object"&&l!==null){var a=Ss.get(l);return a!==void 0?a:(t={value:l,source:t,stack:gf(t)},Ss.set(l,t),t)}return{value:l,source:t,stack:gf(t)}}var ee=[],ue=0,Lu=null,Ve=0,zt=[],Et=0,ta=null,xt=1,Dt="";function Yt(l,t){ee[ue++]=Ve,ee[ue++]=Lu,Lu=l,Ve=t}function bs(l,t,a){zt[Et++]=xt,zt[Et++]=Dt,zt[Et++]=ta,ta=l;var e=xt;l=Dt;var u=32-ft(e)-1;e&=~(1<<u),a+=1;var n=32-ft(t)+u;if(30<n){var i=u-u%5;n=(e&(1<<i)-1).toString(32),e>>=i,u-=i,xt=1<<32-ft(t)+u|a<<u|e,Dt=n+l}else xt=1<<n|a<<u|e,Dt=l}function _i(l){l.return!==null&&(Yt(l,1),bs(l,1,0))}function Ni(l){for(;l===Lu;)Lu=ee[--ue],ee[ue]=null,Ve=ee[--ue],ee[ue]=null;for(;l===ta;)ta=zt[--Et],zt[Et]=null,Dt=zt[--Et],zt[Et]=null,xt=zt[--Et],zt[Et]=null}function Ts(l,t){zt[Et++]=xt,zt[Et++]=Dt,zt[Et++]=ta,xt=t.id,Dt=t.overflow,ta=l}var Kl=null,El=null,al=!1,aa=null,pt=!1,Mi=Error(o(519));function ea(l){var t=Error(o(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Le(Tt(t,l)),Mi}function zs(l){var t=l.stateNode,a=l.type,e=l.memoizedProps;switch(t[Ll]=l,t[Pl]=e,a){case"dialog":I("cancel",t),I("close",t);break;case"iframe":case"object":case"embed":I("load",t);break;case"video":case"audio":for(a=0;a<mu.length;a++)I(mu[a],t);break;case"source":I("error",t);break;case"img":case"image":case"link":I("error",t),I("load",t);break;case"details":I("toggle",t);break;case"input":I("invalid",t),Rf(t,e.value,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name,!0);break;case"select":I("invalid",t);break;case"textarea":I("invalid",t),qf(t,e.value,e.defaultValue,e.children)}a=e.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||e.suppressHydrationWarning===!0||Go(t.textContent,a)?(e.popover!=null&&(I("beforetoggle",t),I("toggle",t)),e.onScroll!=null&&I("scroll",t),e.onScrollEnd!=null&&I("scrollend",t),e.onClick!=null&&(t.onclick=Ct),t=!0):t=!1,t||ea(l,!0)}function Es(l){for(Kl=l.return;Kl;)switch(Kl.tag){case 5:case 31:case 13:pt=!1;return;case 27:case 3:pt=!0;return;default:Kl=Kl.return}}function ne(l){if(l!==Kl)return!1;if(!al)return Es(l),al=!0,!1;var t=l.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=l.type,a=!(a!=="form"&&a!=="button")||Jc(l.type,l.memoizedProps)),a=!a),a&&El&&ea(l),Es(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(317));El=ko(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(317));El=ko(l)}else t===27?(t=El,ga(l.type)?(l=Fc,Fc=null,El=l):El=t):El=Kl?Ot(l.stateNode.nextSibling):null;return!0}function Da(){El=Kl=null,al=!1}function ji(){var l=aa;return l!==null&&(ut===null?ut=l:ut.push.apply(ut,l),aa=null),l}function Le(l){aa===null?aa=[l]:aa.push(l)}var xi=d(null),Ua=null,Gt=null;function ua(l,t,a){D(xi,t._currentValue),t._currentValue=a}function Xt(l){l._currentValue=xi.current,A(xi)}function Di(l,t,a){for(;l!==null;){var e=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,e!==null&&(e.childLanes|=t)):e!==null&&(e.childLanes&t)!==t&&(e.childLanes|=t),l===a)break;l=l.return}}function Ui(l,t,a,e){var u=l.child;for(u!==null&&(u.return=l);u!==null;){var n=u.dependencies;if(n!==null){var i=u.child;n=n.firstContext;l:for(;n!==null;){var c=n;n=u;for(var f=0;f<t.length;f++)if(c.context===t[f]){n.lanes|=a,c=n.alternate,c!==null&&(c.lanes|=a),Di(n.return,a,l),e||(i=null);break l}n=c.next}}else if(u.tag===18){if(i=u.return,i===null)throw Error(o(341));i.lanes|=a,n=i.alternate,n!==null&&(n.lanes|=a),Di(i,a,l),i=null}else i=u.child;if(i!==null)i.return=u;else for(i=u;i!==null;){if(i===l){i=null;break}if(u=i.sibling,u!==null){u.return=i.return,i=u;break}i=i.return}u=i}}function ie(l,t,a,e){l=null;for(var u=t,n=!1;u!==null;){if(!n){if((u.flags&524288)!==0)n=!0;else if((u.flags&262144)!==0)break}if(u.tag===10){var i=u.alternate;if(i===null)throw Error(o(387));if(i=i.memoizedProps,i!==null){var c=u.type;st(u.pendingProps.value,i.value)||(l!==null?l.push(c):l=[c])}}else if(u===sl.current){if(i=u.alternate,i===null)throw Error(o(387));i.memoizedState.memoizedState!==u.memoizedState.memoizedState&&(l!==null?l.push(gu):l=[gu])}u=u.return}l!==null&&Ui(t,l,a,e),t.flags|=262144}function Ku(l){for(l=l.firstContext;l!==null;){if(!st(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ha(l){Ua=l,Gt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Jl(l){return ps(Ua,l)}function Ju(l,t){return Ua===null&&Ha(l),ps(l,t)}function ps(l,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},Gt===null){if(l===null)throw Error(o(308));Gt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Gt=Gt.next=t;return a}var Yr=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(a,e){l.push(e)}};this.abort=function(){t.aborted=!0,l.forEach(function(a){return a()})}},Gr=S.unstable_scheduleCallback,Xr=S.unstable_NormalPriority,ql={$$typeof:J,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Hi(){return{controller:new Yr,data:new Map,refCount:0}}function Ke(l){l.refCount--,l.refCount===0&&Gr(Xr,function(){l.controller.abort()})}var Je=null,Ri=0,ce=0,fe=null;function Qr(l,t){if(Je===null){var a=Je=[];Ri=0,ce=Bc(),fe={status:"pending",value:void 0,then:function(e){a.push(e)}}}return Ri++,t.then(As,As),t}function As(){if(--Ri===0&&Je!==null){fe!==null&&(fe.status="fulfilled");var l=Je;Je=null,ce=0,fe=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function Zr(l,t){var a=[],e={status:"pending",value:null,reason:null,then:function(u){a.push(u)}};return l.then(function(){e.status="fulfilled",e.value=t;for(var u=0;u<a.length;u++)(0,a[u])(t)},function(u){for(e.status="rejected",e.reason=u,u=0;u<a.length;u++)(0,a[u])(void 0)}),e}var Os=z.S;z.S=function(l,t){fo=it(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&Qr(l,t),Os!==null&&Os(l,t)};var Ra=d(null);function Ci(){var l=Ra.current;return l!==null?l:gl.pooledCache}function wu(l,t){t===null?D(Ra,Ra.current):D(Ra,t.pool)}function _s(){var l=Ci();return l===null?null:{parent:ql._currentValue,pool:l}}var se=Error(o(460)),qi=Error(o(474)),ku=Error(o(542)),Wu={then:function(){}};function Ns(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Ms(l,t,a){switch(a=l[a],a===void 0?l.push(t):a!==t&&(t.then(Ct,Ct),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,xs(l),l;default:if(typeof t.status=="string")t.then(Ct,Ct);else{if(l=gl,l!==null&&100<l.shellSuspendCounter)throw Error(o(482));l=t,l.status="pending",l.then(function(e){if(t.status==="pending"){var u=t;u.status="fulfilled",u.value=e}},function(e){if(t.status==="pending"){var u=t;u.status="rejected",u.reason=e}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,xs(l),l}throw qa=t,se}}function Ca(l){try{var t=l._init;return t(l._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(qa=a,se):a}}var qa=null;function js(){if(qa===null)throw Error(o(459));var l=qa;return qa=null,l}function xs(l){if(l===se||l===ku)throw Error(o(483))}var de=null,we=0;function $u(l){var t=we;return we+=1,de===null&&(de=[]),Ms(de,l,t)}function ke(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function Fu(l,t){throw t.$$typeof===X?Error(o(525)):(l=Object.prototype.toString.call(t),Error(o(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function Ds(l){function t(m,s){if(l){var v=m.deletions;v===null?(m.deletions=[s],m.flags|=16):v.push(s)}}function a(m,s){if(!l)return null;for(;s!==null;)t(m,s),s=s.sibling;return null}function e(m){for(var s=new Map;m!==null;)m.key!==null?s.set(m.key,m):s.set(m.index,m),m=m.sibling;return s}function u(m,s){return m=Bt(m,s),m.index=0,m.sibling=null,m}function n(m,s,v){return m.index=v,l?(v=m.alternate,v!==null?(v=v.index,v<s?(m.flags|=67108866,s):v):(m.flags|=67108866,s)):(m.flags|=1048576,s)}function i(m){return l&&m.alternate===null&&(m.flags|=67108866),m}function c(m,s,v,E){return s===null||s.tag!==6?(s=Ai(v,m.mode,E),s.return=m,s):(s=u(s,v),s.return=m,s)}function f(m,s,v,E){var B=v.type;return B===zl?T(m,s,v.props.children,E,v.key):s!==null&&(s.elementType===B||typeof B=="object"&&B!==null&&B.$$typeof===ul&&Ca(B)===s.type)?(s=u(s,v.props),ke(s,v),s.return=m,s):(s=Vu(v.type,v.key,v.props,null,m.mode,E),ke(s,v),s.return=m,s)}function h(m,s,v,E){return s===null||s.tag!==4||s.stateNode.containerInfo!==v.containerInfo||s.stateNode.implementation!==v.implementation?(s=Oi(v,m.mode,E),s.return=m,s):(s=u(s,v.children||[]),s.return=m,s)}function T(m,s,v,E,B){return s===null||s.tag!==7?(s=xa(v,m.mode,E,B),s.return=m,s):(s=u(s,v),s.return=m,s)}function p(m,s,v){if(typeof s=="string"&&s!==""||typeof s=="number"||typeof s=="bigint")return s=Ai(""+s,m.mode,v),s.return=m,s;if(typeof s=="object"&&s!==null){switch(s.$$typeof){case Tl:return v=Vu(s.type,s.key,s.props,null,m.mode,v),ke(v,s),v.return=m,v;case Nl:return s=Oi(s,m.mode,v),s.return=m,s;case ul:return s=Ca(s),p(m,s,v)}if(Vl(s)||jl(s))return s=xa(s,m.mode,v,null),s.return=m,s;if(typeof s.then=="function")return p(m,$u(s),v);if(s.$$typeof===J)return p(m,Ju(m,s),v);Fu(m,s)}return null}function y(m,s,v,E){var B=s!==null?s.key:null;if(typeof v=="string"&&v!==""||typeof v=="number"||typeof v=="bigint")return B!==null?null:c(m,s,""+v,E);if(typeof v=="object"&&v!==null){switch(v.$$typeof){case Tl:return v.key===B?f(m,s,v,E):null;case Nl:return v.key===B?h(m,s,v,E):null;case ul:return v=Ca(v),y(m,s,v,E)}if(Vl(v)||jl(v))return B!==null?null:T(m,s,v,E,null);if(typeof v.then=="function")return y(m,s,$u(v),E);if(v.$$typeof===J)return y(m,s,Ju(m,v),E);Fu(m,v)}return null}function b(m,s,v,E,B){if(typeof E=="string"&&E!==""||typeof E=="number"||typeof E=="bigint")return m=m.get(v)||null,c(s,m,""+E,B);if(typeof E=="object"&&E!==null){switch(E.$$typeof){case Tl:return m=m.get(E.key===null?v:E.key)||null,f(s,m,E,B);case Nl:return m=m.get(E.key===null?v:E.key)||null,h(s,m,E,B);case ul:return E=Ca(E),b(m,s,v,E,B)}if(Vl(E)||jl(E))return m=m.get(v)||null,T(s,m,E,B,null);if(typeof E.then=="function")return b(m,s,v,$u(E),B);if(E.$$typeof===J)return b(m,s,v,Ju(s,E),B);Fu(s,E)}return null}function U(m,s,v,E){for(var B=null,il=null,q=s,W=s=0,tl=null;q!==null&&W<v.length;W++){q.index>W?(tl=q,q=null):tl=q.sibling;var cl=y(m,q,v[W],E);if(cl===null){q===null&&(q=tl);break}l&&q&&cl.alternate===null&&t(m,q),s=n(cl,s,W),il===null?B=cl:il.sibling=cl,il=cl,q=tl}if(W===v.length)return a(m,q),al&&Yt(m,W),B;if(q===null){for(;W<v.length;W++)q=p(m,v[W],E),q!==null&&(s=n(q,s,W),il===null?B=q:il.sibling=q,il=q);return al&&Yt(m,W),B}for(q=e(q);W<v.length;W++)tl=b(q,m,W,v[W],E),tl!==null&&(l&&tl.alternate!==null&&q.delete(tl.key===null?W:tl.key),s=n(tl,s,W),il===null?B=tl:il.sibling=tl,il=tl);return l&&q.forEach(function(Ea){return t(m,Ea)}),al&&Yt(m,W),B}function Q(m,s,v,E){if(v==null)throw Error(o(151));for(var B=null,il=null,q=s,W=s=0,tl=null,cl=v.next();q!==null&&!cl.done;W++,cl=v.next()){q.index>W?(tl=q,q=null):tl=q.sibling;var Ea=y(m,q,cl.value,E);if(Ea===null){q===null&&(q=tl);break}l&&q&&Ea.alternate===null&&t(m,q),s=n(Ea,s,W),il===null?B=Ea:il.sibling=Ea,il=Ea,q=tl}if(cl.done)return a(m,q),al&&Yt(m,W),B;if(q===null){for(;!cl.done;W++,cl=v.next())cl=p(m,cl.value,E),cl!==null&&(s=n(cl,s,W),il===null?B=cl:il.sibling=cl,il=cl);return al&&Yt(m,W),B}for(q=e(q);!cl.done;W++,cl=v.next())cl=b(q,m,W,cl.value,E),cl!==null&&(l&&cl.alternate!==null&&q.delete(cl.key===null?W:cl.key),s=n(cl,s,W),il===null?B=cl:il.sibling=cl,il=cl);return l&&q.forEach(function(P0){return t(m,P0)}),al&&Yt(m,W),B}function hl(m,s,v,E){if(typeof v=="object"&&v!==null&&v.type===zl&&v.key===null&&(v=v.props.children),typeof v=="object"&&v!==null){switch(v.$$typeof){case Tl:l:{for(var B=v.key;s!==null;){if(s.key===B){if(B=v.type,B===zl){if(s.tag===7){a(m,s.sibling),E=u(s,v.props.children),E.return=m,m=E;break l}}else if(s.elementType===B||typeof B=="object"&&B!==null&&B.$$typeof===ul&&Ca(B)===s.type){a(m,s.sibling),E=u(s,v.props),ke(E,v),E.return=m,m=E;break l}a(m,s);break}else t(m,s);s=s.sibling}v.type===zl?(E=xa(v.props.children,m.mode,E,v.key),E.return=m,m=E):(E=Vu(v.type,v.key,v.props,null,m.mode,E),ke(E,v),E.return=m,m=E)}return i(m);case Nl:l:{for(B=v.key;s!==null;){if(s.key===B)if(s.tag===4&&s.stateNode.containerInfo===v.containerInfo&&s.stateNode.implementation===v.implementation){a(m,s.sibling),E=u(s,v.children||[]),E.return=m,m=E;break l}else{a(m,s);break}else t(m,s);s=s.sibling}E=Oi(v,m.mode,E),E.return=m,m=E}return i(m);case ul:return v=Ca(v),hl(m,s,v,E)}if(Vl(v))return U(m,s,v,E);if(jl(v)){if(B=jl(v),typeof B!="function")throw Error(o(150));return v=B.call(v),Q(m,s,v,E)}if(typeof v.then=="function")return hl(m,s,$u(v),E);if(v.$$typeof===J)return hl(m,s,Ju(m,v),E);Fu(m,v)}return typeof v=="string"&&v!==""||typeof v=="number"||typeof v=="bigint"?(v=""+v,s!==null&&s.tag===6?(a(m,s.sibling),E=u(s,v),E.return=m,m=E):(a(m,s),E=Ai(v,m.mode,E),E.return=m,m=E),i(m)):a(m,s)}return function(m,s,v,E){try{we=0;var B=hl(m,s,v,E);return de=null,B}catch(q){if(q===se||q===ku)throw q;var il=dt(29,q,null,m.mode);return il.lanes=E,il.return=m,il}finally{}}}var Ba=Ds(!0),Us=Ds(!1),na=!1;function Bi(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Yi(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function ia(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function ca(l,t,a){var e=l.updateQueue;if(e===null)return null;if(e=e.shared,(fl&2)!==0){var u=e.pending;return u===null?t.next=t:(t.next=u.next,u.next=t),e.pending=t,t=Zu(l),hs(l,null,a),t}return Qu(l,e,t,a),Zu(l)}function We(l,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var e=t.lanes;e&=l.pendingLanes,a|=e,t.lanes=a,pf(l,a)}}function Gi(l,t){var a=l.updateQueue,e=l.alternate;if(e!==null&&(e=e.updateQueue,a===e)){var u=null,n=null;if(a=a.firstBaseUpdate,a!==null){do{var i={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};n===null?u=n=i:n=n.next=i,a=a.next}while(a!==null);n===null?u=n=t:n=n.next=t}else u=n=t;a={baseState:e.baseState,firstBaseUpdate:u,lastBaseUpdate:n,shared:e.shared,callbacks:e.callbacks},l.updateQueue=a;return}l=a.lastBaseUpdate,l===null?a.firstBaseUpdate=t:l.next=t,a.lastBaseUpdate=t}var Xi=!1;function $e(){if(Xi){var l=fe;if(l!==null)throw l}}function Fe(l,t,a,e){Xi=!1;var u=l.updateQueue;na=!1;var n=u.firstBaseUpdate,i=u.lastBaseUpdate,c=u.shared.pending;if(c!==null){u.shared.pending=null;var f=c,h=f.next;f.next=null,i===null?n=h:i.next=h,i=f;var T=l.alternate;T!==null&&(T=T.updateQueue,c=T.lastBaseUpdate,c!==i&&(c===null?T.firstBaseUpdate=h:c.next=h,T.lastBaseUpdate=f))}if(n!==null){var p=u.baseState;i=0,T=h=f=null,c=n;do{var y=c.lane&-536870913,b=y!==c.lane;if(b?(ll&y)===y:(e&y)===y){y!==0&&y===ce&&(Xi=!0),T!==null&&(T=T.next={lane:0,tag:c.tag,payload:c.payload,callback:null,next:null});l:{var U=l,Q=c;y=t;var hl=a;switch(Q.tag){case 1:if(U=Q.payload,typeof U=="function"){p=U.call(hl,p,y);break l}p=U;break l;case 3:U.flags=U.flags&-65537|128;case 0:if(U=Q.payload,y=typeof U=="function"?U.call(hl,p,y):U,y==null)break l;p=H({},p,y);break l;case 2:na=!0}}y=c.callback,y!==null&&(l.flags|=64,b&&(l.flags|=8192),b=u.callbacks,b===null?u.callbacks=[y]:b.push(y))}else b={lane:y,tag:c.tag,payload:c.payload,callback:c.callback,next:null},T===null?(h=T=b,f=p):T=T.next=b,i|=y;if(c=c.next,c===null){if(c=u.shared.pending,c===null)break;b=c,c=b.next,b.next=null,u.lastBaseUpdate=b,u.shared.pending=null}}while(!0);T===null&&(f=p),u.baseState=f,u.firstBaseUpdate=h,u.lastBaseUpdate=T,n===null&&(u.shared.lanes=0),ma|=i,l.lanes=i,l.memoizedState=p}}function Hs(l,t){if(typeof l!="function")throw Error(o(191,l));l.call(t)}function Rs(l,t){var a=l.callbacks;if(a!==null)for(l.callbacks=null,l=0;l<a.length;l++)Hs(a[l],t)}var oe=d(null),Iu=d(0);function Cs(l,t){l=Wt,D(Iu,l),D(oe,t),Wt=l|t.baseLanes}function Qi(){D(Iu,Wt),D(oe,oe.current)}function Zi(){Wt=Iu.current,A(oe),A(Iu)}var ot=d(null),At=null;function fa(l){var t=l.alternate;D(Rl,Rl.current&1),D(ot,l),At===null&&(t===null||oe.current!==null||t.memoizedState!==null)&&(At=l)}function Vi(l){D(Rl,Rl.current),D(ot,l),At===null&&(At=l)}function qs(l){l.tag===22?(D(Rl,Rl.current),D(ot,l),At===null&&(At=l)):sa()}function sa(){D(Rl,Rl.current),D(ot,ot.current)}function mt(l){A(ot),At===l&&(At=null),A(Rl)}var Rl=d(0);function Pu(l){for(var t=l;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||Wc(a)||$c(a)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Qt=0,k=null,rl=null,Bl=null,ln=!1,me=!1,Ya=!1,tn=0,Ie=0,re=null,Vr=0;function xl(){throw Error(o(321))}function Li(l,t){if(t===null)return!1;for(var a=0;a<t.length&&a<l.length;a++)if(!st(l[a],t[a]))return!1;return!0}function Ki(l,t,a,e,u,n){return Qt=n,k=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,z.H=l===null||l.memoizedState===null?bd:ic,Ya=!1,n=a(e,u),Ya=!1,me&&(n=Ys(t,a,e,u)),Bs(l),n}function Bs(l){z.H=tu;var t=rl!==null&&rl.next!==null;if(Qt=0,Bl=rl=k=null,ln=!1,Ie=0,re=null,t)throw Error(o(300));l===null||Yl||(l=l.dependencies,l!==null&&Ku(l)&&(Yl=!0))}function Ys(l,t,a,e){k=l;var u=0;do{if(me&&(re=null),Ie=0,me=!1,25<=u)throw Error(o(301));if(u+=1,Bl=rl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}z.H=Td,n=t(a,e)}while(me);return n}function Lr(){var l=z.H,t=l.useState()[0];return t=typeof t.then=="function"?Pe(t):t,l=l.useState()[0],(rl!==null?rl.memoizedState:null)!==l&&(k.flags|=1024),t}function Ji(){var l=tn!==0;return tn=0,l}function wi(l,t,a){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~a}function ki(l){if(ln){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}ln=!1}Qt=0,Bl=rl=k=null,me=!1,Ie=tn=0,re=null}function Fl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Bl===null?k.memoizedState=Bl=l:Bl=Bl.next=l,Bl}function Cl(){if(rl===null){var l=k.alternate;l=l!==null?l.memoizedState:null}else l=rl.next;var t=Bl===null?k.memoizedState:Bl.next;if(t!==null)Bl=t,rl=l;else{if(l===null)throw k.alternate===null?Error(o(467)):Error(o(310));rl=l,l={memoizedState:rl.memoizedState,baseState:rl.baseState,baseQueue:rl.baseQueue,queue:rl.queue,next:null},Bl===null?k.memoizedState=Bl=l:Bl=Bl.next=l}return Bl}function an(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Pe(l){var t=Ie;return Ie+=1,re===null&&(re=[]),l=Ms(re,l,t),t=k,(Bl===null?t.memoizedState:Bl.next)===null&&(t=t.alternate,z.H=t===null||t.memoizedState===null?bd:ic),l}function en(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return Pe(l);if(l.$$typeof===J)return Jl(l)}throw Error(o(438,String(l)))}function Wi(l){var t=null,a=k.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var e=k.alternate;e!==null&&(e=e.updateQueue,e!==null&&(e=e.memoCache,e!=null&&(t={data:e.data.map(function(u){return u.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=an(),k.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(l),e=0;e<l;e++)a[e]=Ml;return t.index++,a}function Zt(l,t){return typeof t=="function"?t(l):t}function un(l){var t=Cl();return $i(t,rl,l)}function $i(l,t,a){var e=l.queue;if(e===null)throw Error(o(311));e.lastRenderedReducer=a;var u=l.baseQueue,n=e.pending;if(n!==null){if(u!==null){var i=u.next;u.next=n.next,n.next=i}t.baseQueue=u=n,e.pending=null}if(n=l.baseState,u===null)l.memoizedState=n;else{t=u.next;var c=i=null,f=null,h=t,T=!1;do{var p=h.lane&-536870913;if(p!==h.lane?(ll&p)===p:(Qt&p)===p){var y=h.revertLane;if(y===0)f!==null&&(f=f.next={lane:0,revertLane:0,gesture:null,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null}),p===ce&&(T=!0);else if((Qt&y)===y){h=h.next,y===ce&&(T=!0);continue}else p={lane:0,revertLane:h.revertLane,gesture:null,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},f===null?(c=f=p,i=n):f=f.next=p,k.lanes|=y,ma|=y;p=h.action,Ya&&a(n,p),n=h.hasEagerState?h.eagerState:a(n,p)}else y={lane:p,revertLane:h.revertLane,gesture:h.gesture,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},f===null?(c=f=y,i=n):f=f.next=y,k.lanes|=p,ma|=p;h=h.next}while(h!==null&&h!==t);if(f===null?i=n:f.next=c,!st(n,l.memoizedState)&&(Yl=!0,T&&(a=fe,a!==null)))throw a;l.memoizedState=n,l.baseState=i,l.baseQueue=f,e.lastRenderedState=n}return u===null&&(e.lanes=0),[l.memoizedState,e.dispatch]}function Fi(l){var t=Cl(),a=t.queue;if(a===null)throw Error(o(311));a.lastRenderedReducer=l;var e=a.dispatch,u=a.pending,n=t.memoizedState;if(u!==null){a.pending=null;var i=u=u.next;do n=l(n,i.action),i=i.next;while(i!==u);st(n,t.memoizedState)||(Yl=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),a.lastRenderedState=n}return[n,e]}function Gs(l,t,a){var e=k,u=Cl(),n=al;if(n){if(a===void 0)throw Error(o(407));a=a()}else a=t();var i=!st((rl||u).memoizedState,a);if(i&&(u.memoizedState=a,Yl=!0),u=u.queue,lc(Zs.bind(null,e,u,l),[l]),u.getSnapshot!==t||i||Bl!==null&&Bl.memoizedState.tag&1){if(e.flags|=2048,ve(9,{destroy:void 0},Qs.bind(null,e,u,a,t),null),gl===null)throw Error(o(349));n||(Qt&127)!==0||Xs(e,t,a)}return a}function Xs(l,t,a){l.flags|=16384,l={getSnapshot:t,value:a},t=k.updateQueue,t===null?(t=an(),k.updateQueue=t,t.stores=[l]):(a=t.stores,a===null?t.stores=[l]:a.push(l))}function Qs(l,t,a,e){t.value=a,t.getSnapshot=e,Vs(t)&&Ls(l)}function Zs(l,t,a){return a(function(){Vs(t)&&Ls(l)})}function Vs(l){var t=l.getSnapshot;l=l.value;try{var a=t();return!st(l,a)}catch{return!0}}function Ls(l){var t=ja(l,2);t!==null&&nt(t,l,2)}function Ii(l){var t=Fl();if(typeof l=="function"){var a=l;if(l=a(),Ya){It(!0);try{a()}finally{It(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:l},t}function Ks(l,t,a,e){return l.baseState=a,$i(l,rl,typeof e=="function"?e:Zt)}function Kr(l,t,a,e,u){if(fn(l))throw Error(o(485));if(l=t.action,l!==null){var n={payload:u,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(i){n.listeners.push(i)}};z.T!==null?a(!0):n.isTransition=!1,e(n),a=t.pending,a===null?(n.next=t.pending=n,Js(t,n)):(n.next=a.next,t.pending=a.next=n)}}function Js(l,t){var a=t.action,e=t.payload,u=l.state;if(t.isTransition){var n=z.T,i={};z.T=i;try{var c=a(u,e),f=z.S;f!==null&&f(i,c),ws(l,t,c)}catch(h){Pi(l,t,h)}finally{n!==null&&i.types!==null&&(n.types=i.types),z.T=n}}else try{n=a(u,e),ws(l,t,n)}catch(h){Pi(l,t,h)}}function ws(l,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(e){ks(l,t,e)},function(e){return Pi(l,t,e)}):ks(l,t,a)}function ks(l,t,a){t.status="fulfilled",t.value=a,Ws(t),l.state=a,t=l.pending,t!==null&&(a=t.next,a===t?l.pending=null:(a=a.next,t.next=a,Js(l,a)))}function Pi(l,t,a){var e=l.pending;if(l.pending=null,e!==null){e=e.next;do t.status="rejected",t.reason=a,Ws(t),t=t.next;while(t!==e)}l.action=null}function Ws(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function $s(l,t){return t}function Fs(l,t){if(al){var a=gl.formState;if(a!==null){l:{var e=k;if(al){if(El){t:{for(var u=El,n=pt;u.nodeType!==8;){if(!n){u=null;break t}if(u=Ot(u.nextSibling),u===null){u=null;break t}}n=u.data,u=n==="F!"||n==="F"?u:null}if(u){El=Ot(u.nextSibling),e=u.data==="F!";break l}}ea(e)}e=!1}e&&(t=a[0])}}return a=Fl(),a.memoizedState=a.baseState=t,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:$s,lastRenderedState:t},a.queue=e,a=yd.bind(null,k,e),e.dispatch=a,e=Ii(!1),n=nc.bind(null,k,!1,e.queue),e=Fl(),u={state:t,dispatch:null,action:l,pending:null},e.queue=u,a=Kr.bind(null,k,u,n,a),u.dispatch=a,e.memoizedState=l,[t,a,!1]}function Is(l){var t=Cl();return Ps(t,rl,l)}function Ps(l,t,a){if(t=$i(l,t,$s)[0],l=un(Zt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var e=Pe(t)}catch(i){throw i===se?ku:i}else e=t;t=Cl();var u=t.queue,n=u.dispatch;return a!==t.memoizedState&&(k.flags|=2048,ve(9,{destroy:void 0},Jr.bind(null,u,a),null)),[e,n,l]}function Jr(l,t){l.action=t}function ld(l){var t=Cl(),a=rl;if(a!==null)return Ps(t,a,l);Cl(),t=t.memoizedState,a=Cl();var e=a.queue.dispatch;return a.memoizedState=l,[t,e,!1]}function ve(l,t,a,e){return l={tag:l,create:a,deps:e,inst:t,next:null},t=k.updateQueue,t===null&&(t=an(),k.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=l.next=l:(e=a.next,a.next=l,l.next=e,t.lastEffect=l),l}function td(){return Cl().memoizedState}function nn(l,t,a,e){var u=Fl();k.flags|=l,u.memoizedState=ve(1|t,{destroy:void 0},a,e===void 0?null:e)}function cn(l,t,a,e){var u=Cl();e=e===void 0?null:e;var n=u.memoizedState.inst;rl!==null&&e!==null&&Li(e,rl.memoizedState.deps)?u.memoizedState=ve(t,n,a,e):(k.flags|=l,u.memoizedState=ve(1|t,n,a,e))}function ad(l,t){nn(8390656,8,l,t)}function lc(l,t){cn(2048,8,l,t)}function wr(l){k.flags|=4;var t=k.updateQueue;if(t===null)t=an(),k.updateQueue=t,t.events=[l];else{var a=t.events;a===null?t.events=[l]:a.push(l)}}function ed(l){var t=Cl().memoizedState;return wr({ref:t,nextImpl:l}),function(){if((fl&2)!==0)throw Error(o(440));return t.impl.apply(void 0,arguments)}}function ud(l,t){return cn(4,2,l,t)}function nd(l,t){return cn(4,4,l,t)}function id(l,t){if(typeof t=="function"){l=l();var a=t(l);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function cd(l,t,a){a=a!=null?a.concat([l]):null,cn(4,4,id.bind(null,t,l),a)}function tc(){}function fd(l,t){var a=Cl();t=t===void 0?null:t;var e=a.memoizedState;return t!==null&&Li(t,e[1])?e[0]:(a.memoizedState=[l,t],l)}function sd(l,t){var a=Cl();t=t===void 0?null:t;var e=a.memoizedState;if(t!==null&&Li(t,e[1]))return e[0];if(e=l(),Ya){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[e,t],e}function ac(l,t,a){return a===void 0||(Qt&1073741824)!==0&&(ll&261930)===0?l.memoizedState=t:(l.memoizedState=a,l=oo(),k.lanes|=l,ma|=l,a)}function dd(l,t,a,e){return st(a,t)?a:oe.current!==null?(l=ac(l,a,e),st(l,t)||(Yl=!0),l):(Qt&42)===0||(Qt&1073741824)!==0&&(ll&261930)===0?(Yl=!0,l.memoizedState=a):(l=oo(),k.lanes|=l,ma|=l,t)}function od(l,t,a,e,u){var n=j.p;j.p=n!==0&&8>n?n:8;var i=z.T,c={};z.T=c,nc(l,!1,t,a);try{var f=u(),h=z.S;if(h!==null&&h(c,f),f!==null&&typeof f=="object"&&typeof f.then=="function"){var T=Zr(f,e);lu(l,t,T,ht(l))}else lu(l,t,e,ht(l))}catch(p){lu(l,t,{then:function(){},status:"rejected",reason:p},ht())}finally{j.p=n,i!==null&&c.types!==null&&(i.types=c.types),z.T=i}}function kr(){}function ec(l,t,a,e){if(l.tag!==5)throw Error(o(476));var u=md(l).queue;od(l,u,t,V,a===null?kr:function(){return rd(l),a(e)})}function md(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:V,baseState:V,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:V},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Zt,lastRenderedState:a},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function rd(l){var t=md(l);t.next===null&&(t=l.alternate.memoizedState),lu(l,t.next.queue,{},ht())}function uc(){return Jl(gu)}function vd(){return Cl().memoizedState}function hd(){return Cl().memoizedState}function Wr(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var a=ht();l=ia(a);var e=ca(t,l,a);e!==null&&(nt(e,t,a),We(e,t,a)),t={cache:Hi()},l.payload=t;return}t=t.return}}function $r(l,t,a){var e=ht();a={lane:e,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},fn(l)?gd(t,a):(a=Ei(l,t,a,e),a!==null&&(nt(a,l,e),Sd(a,t,e)))}function yd(l,t,a){var e=ht();lu(l,t,a,e)}function lu(l,t,a,e){var u={lane:e,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(fn(l))gd(t,u);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var i=t.lastRenderedState,c=n(i,a);if(u.hasEagerState=!0,u.eagerState=c,st(c,i))return Qu(l,t,u,0),gl===null&&Xu(),!1}catch{}finally{}if(a=Ei(l,t,u,e),a!==null)return nt(a,l,e),Sd(a,t,e),!0}return!1}function nc(l,t,a,e){if(e={lane:2,revertLane:Bc(),gesture:null,action:e,hasEagerState:!1,eagerState:null,next:null},fn(l)){if(t)throw Error(o(479))}else t=Ei(l,a,e,2),t!==null&&nt(t,l,2)}function fn(l){var t=l.alternate;return l===k||t!==null&&t===k}function gd(l,t){me=ln=!0;var a=l.pending;a===null?t.next=t:(t.next=a.next,a.next=t),l.pending=t}function Sd(l,t,a){if((a&4194048)!==0){var e=t.lanes;e&=l.pendingLanes,a|=e,t.lanes=a,pf(l,a)}}var tu={readContext:Jl,use:en,useCallback:xl,useContext:xl,useEffect:xl,useImperativeHandle:xl,useLayoutEffect:xl,useInsertionEffect:xl,useMemo:xl,useReducer:xl,useRef:xl,useState:xl,useDebugValue:xl,useDeferredValue:xl,useTransition:xl,useSyncExternalStore:xl,useId:xl,useHostTransitionStatus:xl,useFormState:xl,useActionState:xl,useOptimistic:xl,useMemoCache:xl,useCacheRefresh:xl};tu.useEffectEvent=xl;var bd={readContext:Jl,use:en,useCallback:function(l,t){return Fl().memoizedState=[l,t===void 0?null:t],l},useContext:Jl,useEffect:ad,useImperativeHandle:function(l,t,a){a=a!=null?a.concat([l]):null,nn(4194308,4,id.bind(null,t,l),a)},useLayoutEffect:function(l,t){return nn(4194308,4,l,t)},useInsertionEffect:function(l,t){nn(4,2,l,t)},useMemo:function(l,t){var a=Fl();t=t===void 0?null:t;var e=l();if(Ya){It(!0);try{l()}finally{It(!1)}}return a.memoizedState=[e,t],e},useReducer:function(l,t,a){var e=Fl();if(a!==void 0){var u=a(t);if(Ya){It(!0);try{a(t)}finally{It(!1)}}}else u=t;return e.memoizedState=e.baseState=u,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:u},e.queue=l,l=l.dispatch=$r.bind(null,k,l),[e.memoizedState,l]},useRef:function(l){var t=Fl();return l={current:l},t.memoizedState=l},useState:function(l){l=Ii(l);var t=l.queue,a=yd.bind(null,k,t);return t.dispatch=a,[l.memoizedState,a]},useDebugValue:tc,useDeferredValue:function(l,t){var a=Fl();return ac(a,l,t)},useTransition:function(){var l=Ii(!1);return l=od.bind(null,k,l.queue,!0,!1),Fl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,a){var e=k,u=Fl();if(al){if(a===void 0)throw Error(o(407));a=a()}else{if(a=t(),gl===null)throw Error(o(349));(ll&127)!==0||Xs(e,t,a)}u.memoizedState=a;var n={value:a,getSnapshot:t};return u.queue=n,ad(Zs.bind(null,e,n,l),[l]),e.flags|=2048,ve(9,{destroy:void 0},Qs.bind(null,e,n,a,t),null),a},useId:function(){var l=Fl(),t=gl.identifierPrefix;if(al){var a=Dt,e=xt;a=(e&~(1<<32-ft(e)-1)).toString(32)+a,t="_"+t+"R_"+a,a=tn++,0<a&&(t+="H"+a.toString(32)),t+="_"}else a=Vr++,t="_"+t+"r_"+a.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:uc,useFormState:Fs,useActionState:Fs,useOptimistic:function(l){var t=Fl();t.memoizedState=t.baseState=l;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=nc.bind(null,k,!0,a),a.dispatch=t,[l,t]},useMemoCache:Wi,useCacheRefresh:function(){return Fl().memoizedState=Wr.bind(null,k)},useEffectEvent:function(l){var t=Fl(),a={impl:l};return t.memoizedState=a,function(){if((fl&2)!==0)throw Error(o(440));return a.impl.apply(void 0,arguments)}}},ic={readContext:Jl,use:en,useCallback:fd,useContext:Jl,useEffect:lc,useImperativeHandle:cd,useInsertionEffect:ud,useLayoutEffect:nd,useMemo:sd,useReducer:un,useRef:td,useState:function(){return un(Zt)},useDebugValue:tc,useDeferredValue:function(l,t){var a=Cl();return dd(a,rl.memoizedState,l,t)},useTransition:function(){var l=un(Zt)[0],t=Cl().memoizedState;return[typeof l=="boolean"?l:Pe(l),t]},useSyncExternalStore:Gs,useId:vd,useHostTransitionStatus:uc,useFormState:Is,useActionState:Is,useOptimistic:function(l,t){var a=Cl();return Ks(a,rl,l,t)},useMemoCache:Wi,useCacheRefresh:hd};ic.useEffectEvent=ed;var Td={readContext:Jl,use:en,useCallback:fd,useContext:Jl,useEffect:lc,useImperativeHandle:cd,useInsertionEffect:ud,useLayoutEffect:nd,useMemo:sd,useReducer:Fi,useRef:td,useState:function(){return Fi(Zt)},useDebugValue:tc,useDeferredValue:function(l,t){var a=Cl();return rl===null?ac(a,l,t):dd(a,rl.memoizedState,l,t)},useTransition:function(){var l=Fi(Zt)[0],t=Cl().memoizedState;return[typeof l=="boolean"?l:Pe(l),t]},useSyncExternalStore:Gs,useId:vd,useHostTransitionStatus:uc,useFormState:ld,useActionState:ld,useOptimistic:function(l,t){var a=Cl();return rl!==null?Ks(a,rl,l,t):(a.baseState=l,[l,a.queue.dispatch])},useMemoCache:Wi,useCacheRefresh:hd};Td.useEffectEvent=ed;function cc(l,t,a,e){t=l.memoizedState,a=a(e,t),a=a==null?t:H({},t,a),l.memoizedState=a,l.lanes===0&&(l.updateQueue.baseState=a)}var fc={enqueueSetState:function(l,t,a){l=l._reactInternals;var e=ht(),u=ia(e);u.payload=t,a!=null&&(u.callback=a),t=ca(l,u,e),t!==null&&(nt(t,l,e),We(t,l,e))},enqueueReplaceState:function(l,t,a){l=l._reactInternals;var e=ht(),u=ia(e);u.tag=1,u.payload=t,a!=null&&(u.callback=a),t=ca(l,u,e),t!==null&&(nt(t,l,e),We(t,l,e))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var a=ht(),e=ia(a);e.tag=2,t!=null&&(e.callback=t),t=ca(l,e,a),t!==null&&(nt(t,l,a),We(t,l,a))}};function zd(l,t,a,e,u,n,i){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(e,n,i):t.prototype&&t.prototype.isPureReactComponent?!Qe(a,e)||!Qe(u,n):!0}function Ed(l,t,a,e){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,e),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,e),t.state!==l&&fc.enqueueReplaceState(t,t.state,null)}function Ga(l,t){var a=t;if("ref"in t){a={};for(var e in t)e!=="ref"&&(a[e]=t[e])}if(l=l.defaultProps){a===t&&(a=H({},a));for(var u in l)a[u]===void 0&&(a[u]=l[u])}return a}function pd(l){Gu(l)}function Ad(l){console.error(l)}function Od(l){Gu(l)}function sn(l,t){try{var a=l.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(e){setTimeout(function(){throw e})}}function _d(l,t,a){try{var e=l.onCaughtError;e(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(u){setTimeout(function(){throw u})}}function sc(l,t,a){return a=ia(a),a.tag=3,a.payload={element:null},a.callback=function(){sn(l,t)},a}function Nd(l){return l=ia(l),l.tag=3,l}function Md(l,t,a,e){var u=a.type.getDerivedStateFromError;if(typeof u=="function"){var n=e.value;l.payload=function(){return u(n)},l.callback=function(){_d(t,a,e)}}var i=a.stateNode;i!==null&&typeof i.componentDidCatch=="function"&&(l.callback=function(){_d(t,a,e),typeof u!="function"&&(ra===null?ra=new Set([this]):ra.add(this));var c=e.stack;this.componentDidCatch(e.value,{componentStack:c!==null?c:""})})}function Fr(l,t,a,e,u){if(a.flags|=32768,e!==null&&typeof e=="object"&&typeof e.then=="function"){if(t=a.alternate,t!==null&&ie(t,a,u,!0),a=ot.current,a!==null){switch(a.tag){case 31:case 13:return At===null?zn():a.alternate===null&&Dl===0&&(Dl=3),a.flags&=-257,a.flags|=65536,a.lanes=u,e===Wu?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([e]):t.add(e),Rc(l,e,u)),!1;case 22:return a.flags|=65536,e===Wu?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([e])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([e]):a.add(e)),Rc(l,e,u)),!1}throw Error(o(435,a.tag))}return Rc(l,e,u),zn(),!1}if(al)return t=ot.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=u,e!==Mi&&(l=Error(o(422),{cause:e}),Le(Tt(l,a)))):(e!==Mi&&(t=Error(o(423),{cause:e}),Le(Tt(t,a))),l=l.current.alternate,l.flags|=65536,u&=-u,l.lanes|=u,e=Tt(e,a),u=sc(l.stateNode,e,u),Gi(l,u),Dl!==4&&(Dl=2)),!1;var n=Error(o(520),{cause:e});if(n=Tt(n,a),su===null?su=[n]:su.push(n),Dl!==4&&(Dl=2),t===null)return!0;e=Tt(e,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,l=u&-u,a.lanes|=l,l=sc(a.stateNode,e,l),Gi(a,l),!1;case 1:if(t=a.type,n=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(ra===null||!ra.has(n))))return a.flags|=65536,u&=-u,a.lanes|=u,u=Nd(u),Md(u,l,a,e),Gi(a,u),!1}a=a.return}while(a!==null);return!1}var dc=Error(o(461)),Yl=!1;function wl(l,t,a,e){t.child=l===null?Us(t,null,a,e):Ba(t,l.child,a,e)}function jd(l,t,a,e,u){a=a.render;var n=t.ref;if("ref"in e){var i={};for(var c in e)c!=="ref"&&(i[c]=e[c])}else i=e;return Ha(t),e=Ki(l,t,a,i,n,u),c=Ji(),l!==null&&!Yl?(wi(l,t,u),Vt(l,t,u)):(al&&c&&_i(t),t.flags|=1,wl(l,t,e,u),t.child)}function xd(l,t,a,e,u){if(l===null){var n=a.type;return typeof n=="function"&&!pi(n)&&n.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=n,Dd(l,t,n,e,u)):(l=Vu(a.type,null,e,t,t.mode,u),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!Sc(l,u)){var i=n.memoizedProps;if(a=a.compare,a=a!==null?a:Qe,a(i,e)&&l.ref===t.ref)return Vt(l,t,u)}return t.flags|=1,l=Bt(n,e),l.ref=t.ref,l.return=t,t.child=l}function Dd(l,t,a,e,u){if(l!==null){var n=l.memoizedProps;if(Qe(n,e)&&l.ref===t.ref)if(Yl=!1,t.pendingProps=e=n,Sc(l,u))(l.flags&131072)!==0&&(Yl=!0);else return t.lanes=l.lanes,Vt(l,t,u)}return oc(l,t,a,e,u)}function Ud(l,t,a,e){var u=e.children,n=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),e.mode==="hidden"){if((t.flags&128)!==0){if(n=n!==null?n.baseLanes|a:a,l!==null){for(e=t.child=l.child,u=0;e!==null;)u=u|e.lanes|e.childLanes,e=e.sibling;e=u&~n}else e=0,t.child=null;return Hd(l,t,n,a,e)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&wu(t,n!==null?n.cachePool:null),n!==null?Cs(t,n):Qi(),qs(t);else return e=t.lanes=536870912,Hd(l,t,n!==null?n.baseLanes|a:a,a,e)}else n!==null?(wu(t,n.cachePool),Cs(t,n),sa(),t.memoizedState=null):(l!==null&&wu(t,null),Qi(),sa());return wl(l,t,u,a),t.child}function au(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function Hd(l,t,a,e,u){var n=Ci();return n=n===null?null:{parent:ql._currentValue,pool:n},t.memoizedState={baseLanes:a,cachePool:n},l!==null&&wu(t,null),Qi(),qs(t),l!==null&&ie(l,t,e,!0),t.childLanes=u,null}function dn(l,t){return t=mn({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function Rd(l,t,a){return Ba(t,l.child,null,a),l=dn(t,t.pendingProps),l.flags|=2,mt(t),t.memoizedState=null,l}function Ir(l,t,a){var e=t.pendingProps,u=(t.flags&128)!==0;if(t.flags&=-129,l===null){if(al){if(e.mode==="hidden")return l=dn(t,e),t.lanes=536870912,au(null,l);if(Vi(t),(l=El)?(l=wo(l,pt),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:xt,overflow:Dt}:null,retryLane:536870912,hydrationErrors:null},a=gs(l),a.return=t,t.child=a,Kl=t,El=null)):l=null,l===null)throw ea(t);return t.lanes=536870912,null}return dn(t,e)}var n=l.memoizedState;if(n!==null){var i=n.dehydrated;if(Vi(t),u)if(t.flags&256)t.flags&=-257,t=Rd(l,t,a);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(o(558));else if(Yl||ie(l,t,a,!1),u=(a&l.childLanes)!==0,Yl||u){if(e=gl,e!==null&&(i=Af(e,a),i!==0&&i!==n.retryLane))throw n.retryLane=i,ja(l,i),nt(e,l,i),dc;zn(),t=Rd(l,t,a)}else l=n.treeContext,El=Ot(i.nextSibling),Kl=t,al=!0,aa=null,pt=!1,l!==null&&Ts(t,l),t=dn(t,e),t.flags|=4096;return t}return l=Bt(l.child,{mode:e.mode,children:e.children}),l.ref=t.ref,t.child=l,l.return=t,l}function on(l,t){var a=t.ref;if(a===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(o(284));(l===null||l.ref!==a)&&(t.flags|=4194816)}}function oc(l,t,a,e,u){return Ha(t),a=Ki(l,t,a,e,void 0,u),e=Ji(),l!==null&&!Yl?(wi(l,t,u),Vt(l,t,u)):(al&&e&&_i(t),t.flags|=1,wl(l,t,a,u),t.child)}function Cd(l,t,a,e,u,n){return Ha(t),t.updateQueue=null,a=Ys(t,e,a,u),Bs(l),e=Ji(),l!==null&&!Yl?(wi(l,t,n),Vt(l,t,n)):(al&&e&&_i(t),t.flags|=1,wl(l,t,a,n),t.child)}function qd(l,t,a,e,u){if(Ha(t),t.stateNode===null){var n=ae,i=a.contextType;typeof i=="object"&&i!==null&&(n=Jl(i)),n=new a(e,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=fc,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=e,n.state=t.memoizedState,n.refs={},Bi(t),i=a.contextType,n.context=typeof i=="object"&&i!==null?Jl(i):ae,n.state=t.memoizedState,i=a.getDerivedStateFromProps,typeof i=="function"&&(cc(t,a,i,e),n.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(i=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),i!==n.state&&fc.enqueueReplaceState(n,n.state,null),Fe(t,e,n,u),$e(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),e=!0}else if(l===null){n=t.stateNode;var c=t.memoizedProps,f=Ga(a,c);n.props=f;var h=n.context,T=a.contextType;i=ae,typeof T=="object"&&T!==null&&(i=Jl(T));var p=a.getDerivedStateFromProps;T=typeof p=="function"||typeof n.getSnapshotBeforeUpdate=="function",c=t.pendingProps!==c,T||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c||h!==i)&&Ed(t,n,e,i),na=!1;var y=t.memoizedState;n.state=y,Fe(t,e,n,u),$e(),h=t.memoizedState,c||y!==h||na?(typeof p=="function"&&(cc(t,a,p,e),h=t.memoizedState),(f=na||zd(t,a,f,e,y,h,i))?(T||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=e,t.memoizedState=h),n.props=e,n.state=h,n.context=i,e=f):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),e=!1)}else{n=t.stateNode,Yi(l,t),i=t.memoizedProps,T=Ga(a,i),n.props=T,p=t.pendingProps,y=n.context,h=a.contextType,f=ae,typeof h=="object"&&h!==null&&(f=Jl(h)),c=a.getDerivedStateFromProps,(h=typeof c=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i!==p||y!==f)&&Ed(t,n,e,f),na=!1,y=t.memoizedState,n.state=y,Fe(t,e,n,u),$e();var b=t.memoizedState;i!==p||y!==b||na||l!==null&&l.dependencies!==null&&Ku(l.dependencies)?(typeof c=="function"&&(cc(t,a,c,e),b=t.memoizedState),(T=na||zd(t,a,T,e,y,b,f)||l!==null&&l.dependencies!==null&&Ku(l.dependencies))?(h||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(e,b,f),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(e,b,f)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||i===l.memoizedProps&&y===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===l.memoizedProps&&y===l.memoizedState||(t.flags|=1024),t.memoizedProps=e,t.memoizedState=b),n.props=e,n.state=b,n.context=f,e=T):(typeof n.componentDidUpdate!="function"||i===l.memoizedProps&&y===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===l.memoizedProps&&y===l.memoizedState||(t.flags|=1024),e=!1)}return n=e,on(l,t),e=(t.flags&128)!==0,n||e?(n=t.stateNode,a=e&&typeof a.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&e?(t.child=Ba(t,l.child,null,u),t.child=Ba(t,null,a,u)):wl(l,t,a,u),t.memoizedState=n.state,l=t.child):l=Vt(l,t,u),l}function Bd(l,t,a,e){return Da(),t.flags|=256,wl(l,t,a,e),t.child}var mc={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function rc(l){return{baseLanes:l,cachePool:_s()}}function vc(l,t,a){return l=l!==null?l.childLanes&~a:0,t&&(l|=vt),l}function Yd(l,t,a){var e=t.pendingProps,u=!1,n=(t.flags&128)!==0,i;if((i=n)||(i=l!==null&&l.memoizedState===null?!1:(Rl.current&2)!==0),i&&(u=!0,t.flags&=-129),i=(t.flags&32)!==0,t.flags&=-33,l===null){if(al){if(u?fa(t):sa(),(l=El)?(l=wo(l,pt),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ta!==null?{id:xt,overflow:Dt}:null,retryLane:536870912,hydrationErrors:null},a=gs(l),a.return=t,t.child=a,Kl=t,El=null)):l=null,l===null)throw ea(t);return $c(l)?t.lanes=32:t.lanes=536870912,null}var c=e.children;return e=e.fallback,u?(sa(),u=t.mode,c=mn({mode:"hidden",children:c},u),e=xa(e,u,a,null),c.return=t,e.return=t,c.sibling=e,t.child=c,e=t.child,e.memoizedState=rc(a),e.childLanes=vc(l,i,a),t.memoizedState=mc,au(null,e)):(fa(t),hc(t,c))}var f=l.memoizedState;if(f!==null&&(c=f.dehydrated,c!==null)){if(n)t.flags&256?(fa(t),t.flags&=-257,t=yc(l,t,a)):t.memoizedState!==null?(sa(),t.child=l.child,t.flags|=128,t=null):(sa(),c=e.fallback,u=t.mode,e=mn({mode:"visible",children:e.children},u),c=xa(c,u,a,null),c.flags|=2,e.return=t,c.return=t,e.sibling=c,t.child=e,Ba(t,l.child,null,a),e=t.child,e.memoizedState=rc(a),e.childLanes=vc(l,i,a),t.memoizedState=mc,t=au(null,e));else if(fa(t),$c(c)){if(i=c.nextSibling&&c.nextSibling.dataset,i)var h=i.dgst;i=h,e=Error(o(419)),e.stack="",e.digest=i,Le({value:e,source:null,stack:null}),t=yc(l,t,a)}else if(Yl||ie(l,t,a,!1),i=(a&l.childLanes)!==0,Yl||i){if(i=gl,i!==null&&(e=Af(i,a),e!==0&&e!==f.retryLane))throw f.retryLane=e,ja(l,e),nt(i,l,e),dc;Wc(c)||zn(),t=yc(l,t,a)}else Wc(c)?(t.flags|=192,t.child=l.child,t=null):(l=f.treeContext,El=Ot(c.nextSibling),Kl=t,al=!0,aa=null,pt=!1,l!==null&&Ts(t,l),t=hc(t,e.children),t.flags|=4096);return t}return u?(sa(),c=e.fallback,u=t.mode,f=l.child,h=f.sibling,e=Bt(f,{mode:"hidden",children:e.children}),e.subtreeFlags=f.subtreeFlags&65011712,h!==null?c=Bt(h,c):(c=xa(c,u,a,null),c.flags|=2),c.return=t,e.return=t,e.sibling=c,t.child=e,au(null,e),e=t.child,c=l.child.memoizedState,c===null?c=rc(a):(u=c.cachePool,u!==null?(f=ql._currentValue,u=u.parent!==f?{parent:f,pool:f}:u):u=_s(),c={baseLanes:c.baseLanes|a,cachePool:u}),e.memoizedState=c,e.childLanes=vc(l,i,a),t.memoizedState=mc,au(l.child,e)):(fa(t),a=l.child,l=a.sibling,a=Bt(a,{mode:"visible",children:e.children}),a.return=t,a.sibling=null,l!==null&&(i=t.deletions,i===null?(t.deletions=[l],t.flags|=16):i.push(l)),t.child=a,t.memoizedState=null,a)}function hc(l,t){return t=mn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function mn(l,t){return l=dt(22,l,null,t),l.lanes=0,l}function yc(l,t,a){return Ba(t,l.child,null,a),l=hc(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function Gd(l,t,a){l.lanes|=t;var e=l.alternate;e!==null&&(e.lanes|=t),Di(l.return,t,a)}function gc(l,t,a,e,u,n){var i=l.memoizedState;i===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:e,tail:a,tailMode:u,treeForkCount:n}:(i.isBackwards=t,i.rendering=null,i.renderingStartTime=0,i.last=e,i.tail=a,i.tailMode=u,i.treeForkCount=n)}function Xd(l,t,a){var e=t.pendingProps,u=e.revealOrder,n=e.tail;e=e.children;var i=Rl.current,c=(i&2)!==0;if(c?(i=i&1|2,t.flags|=128):i&=1,D(Rl,i),wl(l,t,e,a),e=al?Ve:0,!c&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&Gd(l,a,t);else if(l.tag===19)Gd(l,a,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(u){case"forwards":for(a=t.child,u=null;a!==null;)l=a.alternate,l!==null&&Pu(l)===null&&(u=a),a=a.sibling;a=u,a===null?(u=t.child,t.child=null):(u=a.sibling,a.sibling=null),gc(t,!1,u,a,n,e);break;case"backwards":case"unstable_legacy-backwards":for(a=null,u=t.child,t.child=null;u!==null;){if(l=u.alternate,l!==null&&Pu(l)===null){t.child=u;break}l=u.sibling,u.sibling=a,a=u,u=l}gc(t,!0,a,null,n,e);break;case"together":gc(t,!1,null,null,void 0,e);break;default:t.memoizedState=null}return t.child}function Vt(l,t,a){if(l!==null&&(t.dependencies=l.dependencies),ma|=t.lanes,(a&t.childLanes)===0)if(l!==null){if(ie(l,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(o(153));if(t.child!==null){for(l=t.child,a=Bt(l,l.pendingProps),t.child=a,a.return=t;l.sibling!==null;)l=l.sibling,a=a.sibling=Bt(l,l.pendingProps),a.return=t;a.sibling=null}return t.child}function Sc(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Ku(l)))}function Pr(l,t,a){switch(t.tag){case 3:$l(t,t.stateNode.containerInfo),ua(t,ql,l.memoizedState.cache),Da();break;case 27:case 5:Me(t);break;case 4:$l(t,t.stateNode.containerInfo);break;case 10:ua(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,Vi(t),null;break;case 13:var e=t.memoizedState;if(e!==null)return e.dehydrated!==null?(fa(t),t.flags|=128,null):(a&t.child.childLanes)!==0?Yd(l,t,a):(fa(t),l=Vt(l,t,a),l!==null?l.sibling:null);fa(t);break;case 19:var u=(l.flags&128)!==0;if(e=(a&t.childLanes)!==0,e||(ie(l,t,a,!1),e=(a&t.childLanes)!==0),u){if(e)return Xd(l,t,a);t.flags|=128}if(u=t.memoizedState,u!==null&&(u.rendering=null,u.tail=null,u.lastEffect=null),D(Rl,Rl.current),e)break;return null;case 22:return t.lanes=0,Ud(l,t,a,t.pendingProps);case 24:ua(t,ql,l.memoizedState.cache)}return Vt(l,t,a)}function Qd(l,t,a){if(l!==null)if(l.memoizedProps!==t.pendingProps)Yl=!0;else{if(!Sc(l,a)&&(t.flags&128)===0)return Yl=!1,Pr(l,t,a);Yl=(l.flags&131072)!==0}else Yl=!1,al&&(t.flags&1048576)!==0&&bs(t,Ve,t.index);switch(t.lanes=0,t.tag){case 16:l:{var e=t.pendingProps;if(l=Ca(t.elementType),t.type=l,typeof l=="function")pi(l)?(e=Ga(l,e),t.tag=1,t=qd(null,t,l,e,a)):(t.tag=0,t=oc(null,t,l,e,a));else{if(l!=null){var u=l.$$typeof;if(u===Ol){t.tag=11,t=jd(null,t,l,e,a);break l}else if(u===Z){t.tag=14,t=xd(null,t,l,e,a);break l}}throw t=Il(l)||l,Error(o(306,t,""))}}return t;case 0:return oc(l,t,t.type,t.pendingProps,a);case 1:return e=t.type,u=Ga(e,t.pendingProps),qd(l,t,e,u,a);case 3:l:{if($l(t,t.stateNode.containerInfo),l===null)throw Error(o(387));e=t.pendingProps;var n=t.memoizedState;u=n.element,Yi(l,t),Fe(t,e,null,a);var i=t.memoizedState;if(e=i.cache,ua(t,ql,e),e!==n.cache&&Ui(t,[ql],a,!0),$e(),e=i.element,n.isDehydrated)if(n={element:e,isDehydrated:!1,cache:i.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=Bd(l,t,e,a);break l}else if(e!==u){u=Tt(Error(o(424)),t),Le(u),t=Bd(l,t,e,a);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(El=Ot(l.firstChild),Kl=t,al=!0,aa=null,pt=!0,a=Us(t,null,e,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(Da(),e===u){t=Vt(l,t,a);break l}wl(l,t,e,a)}t=t.child}return t;case 26:return on(l,t),l===null?(a=Po(t.type,null,t.pendingProps,null))?t.memoizedState=a:al||(a=t.type,l=t.pendingProps,e=Mn($.current).createElement(a),e[Ll]=t,e[Pl]=l,kl(e,a,l),Ql(e),t.stateNode=e):t.memoizedState=Po(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return Me(t),l===null&&al&&(e=t.stateNode=$o(t.type,t.pendingProps,$.current),Kl=t,pt=!0,u=El,ga(t.type)?(Fc=u,El=Ot(e.firstChild)):El=u),wl(l,t,t.pendingProps.children,a),on(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&al&&((u=e=El)&&(e=j0(e,t.type,t.pendingProps,pt),e!==null?(t.stateNode=e,Kl=t,El=Ot(e.firstChild),pt=!1,u=!0):u=!1),u||ea(t)),Me(t),u=t.type,n=t.pendingProps,i=l!==null?l.memoizedProps:null,e=n.children,Jc(u,n)?e=null:i!==null&&Jc(u,i)&&(t.flags|=32),t.memoizedState!==null&&(u=Ki(l,t,Lr,null,null,a),gu._currentValue=u),on(l,t),wl(l,t,e,a),t.child;case 6:return l===null&&al&&((l=a=El)&&(a=x0(a,t.pendingProps,pt),a!==null?(t.stateNode=a,Kl=t,El=null,l=!0):l=!1),l||ea(t)),null;case 13:return Yd(l,t,a);case 4:return $l(t,t.stateNode.containerInfo),e=t.pendingProps,l===null?t.child=Ba(t,null,e,a):wl(l,t,e,a),t.child;case 11:return jd(l,t,t.type,t.pendingProps,a);case 7:return wl(l,t,t.pendingProps,a),t.child;case 8:return wl(l,t,t.pendingProps.children,a),t.child;case 12:return wl(l,t,t.pendingProps.children,a),t.child;case 10:return e=t.pendingProps,ua(t,t.type,e.value),wl(l,t,e.children,a),t.child;case 9:return u=t.type._context,e=t.pendingProps.children,Ha(t),u=Jl(u),e=e(u),t.flags|=1,wl(l,t,e,a),t.child;case 14:return xd(l,t,t.type,t.pendingProps,a);case 15:return Dd(l,t,t.type,t.pendingProps,a);case 19:return Xd(l,t,a);case 31:return Ir(l,t,a);case 22:return Ud(l,t,a,t.pendingProps);case 24:return Ha(t),e=Jl(ql),l===null?(u=Ci(),u===null&&(u=gl,n=Hi(),u.pooledCache=n,n.refCount++,n!==null&&(u.pooledCacheLanes|=a),u=n),t.memoizedState={parent:e,cache:u},Bi(t),ua(t,ql,u)):((l.lanes&a)!==0&&(Yi(l,t),Fe(t,null,null,a),$e()),u=l.memoizedState,n=t.memoizedState,u.parent!==e?(u={parent:e,cache:e},t.memoizedState=u,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=u),ua(t,ql,e)):(e=n.cache,ua(t,ql,e),e!==u.cache&&Ui(t,[ql],a,!0))),wl(l,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(o(156,t.tag))}function Lt(l){l.flags|=4}function bc(l,t,a,e,u){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(u&335544128)===u)if(l.stateNode.complete)l.flags|=8192;else if(ho())l.flags|=8192;else throw qa=Wu,qi}else l.flags&=-16777217}function Zd(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!um(t))if(ho())l.flags|=8192;else throw qa=Wu,qi}function rn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?zf():536870912,l.lanes|=t,Se|=t)}function eu(l,t){if(!al)switch(l.tailMode){case"hidden":t=l.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?l.tail=null:a.sibling=null;break;case"collapsed":a=l.tail;for(var e=null;a!==null;)a.alternate!==null&&(e=a),a=a.sibling;e===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:e.sibling=null}}function pl(l){var t=l.alternate!==null&&l.alternate.child===l.child,a=0,e=0;if(t)for(var u=l.child;u!==null;)a|=u.lanes|u.childLanes,e|=u.subtreeFlags&65011712,e|=u.flags&65011712,u.return=l,u=u.sibling;else for(u=l.child;u!==null;)a|=u.lanes|u.childLanes,e|=u.subtreeFlags,e|=u.flags,u.return=l,u=u.sibling;return l.subtreeFlags|=e,l.childLanes=a,t}function l0(l,t,a){var e=t.pendingProps;switch(Ni(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return pl(t),null;case 1:return pl(t),null;case 3:return a=t.stateNode,e=null,l!==null&&(e=l.memoizedState.cache),t.memoizedState.cache!==e&&(t.flags|=2048),Xt(ql),Hl(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(l===null||l.child===null)&&(ne(t)?Lt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,ji())),pl(t),null;case 26:var u=t.type,n=t.memoizedState;return l===null?(Lt(t),n!==null?(pl(t),Zd(t,n)):(pl(t),bc(t,u,null,e,a))):n?n!==l.memoizedState?(Lt(t),pl(t),Zd(t,n)):(pl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==e&&Lt(t),pl(t),bc(t,u,l,e,a)),null;case 27:if(pu(t),a=$.current,u=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==e&&Lt(t);else{if(!e){if(t.stateNode===null)throw Error(o(166));return pl(t),null}l=R.current,ne(t)?zs(t):(l=$o(u,e,a),t.stateNode=l,Lt(t))}return pl(t),null;case 5:if(pu(t),u=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==e&&Lt(t);else{if(!e){if(t.stateNode===null)throw Error(o(166));return pl(t),null}if(n=R.current,ne(t))zs(t);else{var i=Mn($.current);switch(n){case 1:n=i.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:n=i.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":n=i.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":n=i.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":n=i.createElement("div"),n.innerHTML="<script><\\/script>",n=n.removeChild(n.firstChild);break;case"select":n=typeof e.is=="string"?i.createElement("select",{is:e.is}):i.createElement("select"),e.multiple?n.multiple=!0:e.size&&(n.size=e.size);break;default:n=typeof e.is=="string"?i.createElement(u,{is:e.is}):i.createElement(u)}}n[Ll]=t,n[Pl]=e;l:for(i=t.child;i!==null;){if(i.tag===5||i.tag===6)n.appendChild(i.stateNode);else if(i.tag!==4&&i.tag!==27&&i.child!==null){i.child.return=i,i=i.child;continue}if(i===t)break l;for(;i.sibling===null;){if(i.return===null||i.return===t)break l;i=i.return}i.sibling.return=i.return,i=i.sibling}t.stateNode=n;l:switch(kl(n,u,e),u){case"button":case"input":case"select":case"textarea":e=!!e.autoFocus;break l;case"img":e=!0;break l;default:e=!1}e&&Lt(t)}}return pl(t),bc(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,a),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==e&&Lt(t);else{if(typeof e!="string"&&t.stateNode===null)throw Error(o(166));if(l=$.current,ne(t)){if(l=t.stateNode,a=t.memoizedProps,e=null,u=Kl,u!==null)switch(u.tag){case 27:case 5:e=u.memoizedProps}l[Ll]=t,l=!!(l.nodeValue===a||e!==null&&e.suppressHydrationWarning===!0||Go(l.nodeValue,a)),l||ea(t,!0)}else l=Mn(l).createTextNode(e),l[Ll]=t,t.stateNode=l}return pl(t),null;case 31:if(a=t.memoizedState,l===null||l.memoizedState!==null){if(e=ne(t),a!==null){if(l===null){if(!e)throw Error(o(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(557));l[Ll]=t}else Da(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;pl(t),l=!1}else a=ji(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=a),l=!0;if(!l)return t.flags&256?(mt(t),t):(mt(t),null);if((t.flags&128)!==0)throw Error(o(558))}return pl(t),null;case 13:if(e=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(u=ne(t),e!==null&&e.dehydrated!==null){if(l===null){if(!u)throw Error(o(318));if(u=t.memoizedState,u=u!==null?u.dehydrated:null,!u)throw Error(o(317));u[Ll]=t}else Da(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;pl(t),u=!1}else u=ji(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=u),u=!0;if(!u)return t.flags&256?(mt(t),t):(mt(t),null)}return mt(t),(t.flags&128)!==0?(t.lanes=a,t):(a=e!==null,l=l!==null&&l.memoizedState!==null,a&&(e=t.child,u=null,e.alternate!==null&&e.alternate.memoizedState!==null&&e.alternate.memoizedState.cachePool!==null&&(u=e.alternate.memoizedState.cachePool.pool),n=null,e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),n!==u&&(e.flags|=2048)),a!==l&&a&&(t.child.flags|=8192),rn(t,t.updateQueue),pl(t),null);case 4:return Hl(),l===null&&Qc(t.stateNode.containerInfo),pl(t),null;case 10:return Xt(t.type),pl(t),null;case 19:if(A(Rl),e=t.memoizedState,e===null)return pl(t),null;if(u=(t.flags&128)!==0,n=e.rendering,n===null)if(u)eu(e,!1);else{if(Dl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=Pu(l),n!==null){for(t.flags|=128,eu(e,!1),l=n.updateQueue,t.updateQueue=l,rn(t,l),t.subtreeFlags=0,l=a,a=t.child;a!==null;)ys(a,l),a=a.sibling;return D(Rl,Rl.current&1|2),al&&Yt(t,e.treeForkCount),t.child}l=l.sibling}e.tail!==null&&it()>Sn&&(t.flags|=128,u=!0,eu(e,!1),t.lanes=4194304)}else{if(!u)if(l=Pu(n),l!==null){if(t.flags|=128,u=!0,l=l.updateQueue,t.updateQueue=l,rn(t,l),eu(e,!0),e.tail===null&&e.tailMode==="hidden"&&!n.alternate&&!al)return pl(t),null}else 2*it()-e.renderingStartTime>Sn&&a!==536870912&&(t.flags|=128,u=!0,eu(e,!1),t.lanes=4194304);e.isBackwards?(n.sibling=t.child,t.child=n):(l=e.last,l!==null?l.sibling=n:t.child=n,e.last=n)}return e.tail!==null?(l=e.tail,e.rendering=l,e.tail=l.sibling,e.renderingStartTime=it(),l.sibling=null,a=Rl.current,D(Rl,u?a&1|2:a&1),al&&Yt(t,e.treeForkCount),l):(pl(t),null);case 22:case 23:return mt(t),Zi(),e=t.memoizedState!==null,l!==null?l.memoizedState!==null!==e&&(t.flags|=8192):e&&(t.flags|=8192),e?(a&536870912)!==0&&(t.flags&128)===0&&(pl(t),t.subtreeFlags&6&&(t.flags|=8192)):pl(t),a=t.updateQueue,a!==null&&rn(t,a.retryQueue),a=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==a&&(t.flags|=2048),l!==null&&A(Ra),null;case 24:return a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Xt(ql),pl(t),null;case 25:return null;case 30:return null}throw Error(o(156,t.tag))}function t0(l,t){switch(Ni(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Xt(ql),Hl(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return pu(t),null;case 31:if(t.memoizedState!==null){if(mt(t),t.alternate===null)throw Error(o(340));Da()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(mt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(o(340));Da()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return A(Rl),null;case 4:return Hl(),null;case 10:return Xt(t.type),null;case 22:case 23:return mt(t),Zi(),l!==null&&A(Ra),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Xt(ql),null;case 25:return null;default:return null}}function Vd(l,t){switch(Ni(t),t.tag){case 3:Xt(ql),Hl();break;case 26:case 27:case 5:pu(t);break;case 4:Hl();break;case 31:t.memoizedState!==null&&mt(t);break;case 13:mt(t);break;case 19:A(Rl);break;case 10:Xt(t.type);break;case 22:case 23:mt(t),Zi(),l!==null&&A(Ra);break;case 24:Xt(ql)}}function uu(l,t){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var u=e.next;a=u;do{if((a.tag&l)===l){e=void 0;var n=a.create,i=a.inst;e=n(),i.destroy=e}a=a.next}while(a!==u)}}catch(c){ol(t,t.return,c)}}function da(l,t,a){try{var e=t.updateQueue,u=e!==null?e.lastEffect:null;if(u!==null){var n=u.next;e=n;do{if((e.tag&l)===l){var i=e.inst,c=i.destroy;if(c!==void 0){i.destroy=void 0,u=t;var f=a,h=c;try{h()}catch(T){ol(u,f,T)}}}e=e.next}while(e!==n)}}catch(T){ol(t,t.return,T)}}function Ld(l){var t=l.updateQueue;if(t!==null){var a=l.stateNode;try{Rs(t,a)}catch(e){ol(l,l.return,e)}}}function Kd(l,t,a){a.props=Ga(l.type,l.memoizedProps),a.state=l.memoizedState;try{a.componentWillUnmount()}catch(e){ol(l,t,e)}}function nu(l,t){try{var a=l.ref;if(a!==null){switch(l.tag){case 26:case 27:case 5:var e=l.stateNode;break;case 30:e=l.stateNode;break;default:e=l.stateNode}typeof a=="function"?l.refCleanup=a(e):a.current=e}}catch(u){ol(l,t,u)}}function Ut(l,t){var a=l.ref,e=l.refCleanup;if(a!==null)if(typeof e=="function")try{e()}catch(u){ol(l,t,u)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(u){ol(l,t,u)}else a.current=null}function Jd(l){var t=l.type,a=l.memoizedProps,e=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&e.focus();break l;case"img":a.src?e.src=a.src:a.srcSet&&(e.srcset=a.srcSet)}}catch(u){ol(l,l.return,u)}}function Tc(l,t,a){try{var e=l.stateNode;p0(e,l.type,a,t),e[Pl]=t}catch(u){ol(l,l.return,u)}}function wd(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&ga(l.type)||l.tag===4}function zc(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||wd(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&ga(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function Ec(l,t,a){var e=l.tag;if(e===5||e===6)l=l.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(l,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(l),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=Ct));else if(e!==4&&(e===27&&ga(l.type)&&(a=l.stateNode,t=null),l=l.child,l!==null))for(Ec(l,t,a),l=l.sibling;l!==null;)Ec(l,t,a),l=l.sibling}function vn(l,t,a){var e=l.tag;if(e===5||e===6)l=l.stateNode,t?a.insertBefore(l,t):a.appendChild(l);else if(e!==4&&(e===27&&ga(l.type)&&(a=l.stateNode),l=l.child,l!==null))for(vn(l,t,a),l=l.sibling;l!==null;)vn(l,t,a),l=l.sibling}function kd(l){var t=l.stateNode,a=l.memoizedProps;try{for(var e=l.type,u=t.attributes;u.length;)t.removeAttributeNode(u[0]);kl(t,e,a),t[Ll]=l,t[Pl]=a}catch(n){ol(l,l.return,n)}}var Kt=!1,Gl=!1,pc=!1,Wd=typeof WeakSet=="function"?WeakSet:Set,Zl=null;function a0(l,t){if(l=l.containerInfo,Lc=Cn,l=cs(l),yi(l)){if("selectionStart"in l)var a={start:l.selectionStart,end:l.selectionEnd};else l:{a=(a=l.ownerDocument)&&a.defaultView||window;var e=a.getSelection&&a.getSelection();if(e&&e.rangeCount!==0){a=e.anchorNode;var u=e.anchorOffset,n=e.focusNode;e=e.focusOffset;try{a.nodeType,n.nodeType}catch{a=null;break l}var i=0,c=-1,f=-1,h=0,T=0,p=l,y=null;t:for(;;){for(var b;p!==a||u!==0&&p.nodeType!==3||(c=i+u),p!==n||e!==0&&p.nodeType!==3||(f=i+e),p.nodeType===3&&(i+=p.nodeValue.length),(b=p.firstChild)!==null;)y=p,p=b;for(;;){if(p===l)break t;if(y===a&&++h===u&&(c=i),y===n&&++T===e&&(f=i),(b=p.nextSibling)!==null)break;p=y,y=p.parentNode}p=b}a=c===-1||f===-1?null:{start:c,end:f}}else a=null}a=a||{start:0,end:0}}else a=null;for(Kc={focusedElem:l,selectionRange:a},Cn=!1,Zl=t;Zl!==null;)if(t=Zl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Zl=l;else for(;Zl!==null;){switch(t=Zl,n=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(a=0;a<l.length;a++)u=l[a],u.ref.impl=u.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,a=t,u=n.memoizedProps,n=n.memoizedState,e=a.stateNode;try{var U=Ga(a.type,u);l=e.getSnapshotBeforeUpdate(U,n),e.__reactInternalSnapshotBeforeUpdate=l}catch(Q){ol(a,a.return,Q)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,a=l.nodeType,a===9)kc(l);else if(a===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":kc(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(o(163))}if(l=t.sibling,l!==null){l.return=t.return,Zl=l;break}Zl=t.return}}function $d(l,t,a){var e=a.flags;switch(a.tag){case 0:case 11:case 15:wt(l,a),e&4&&uu(5,a);break;case 1:if(wt(l,a),e&4)if(l=a.stateNode,t===null)try{l.componentDidMount()}catch(i){ol(a,a.return,i)}else{var u=Ga(a.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(u,t,l.__reactInternalSnapshotBeforeUpdate)}catch(i){ol(a,a.return,i)}}e&64&&Ld(a),e&512&&nu(a,a.return);break;case 3:if(wt(l,a),e&64&&(l=a.updateQueue,l!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{Rs(l,t)}catch(i){ol(a,a.return,i)}}break;case 27:t===null&&e&4&&kd(a);case 26:case 5:wt(l,a),t===null&&e&4&&Jd(a),e&512&&nu(a,a.return);break;case 12:wt(l,a);break;case 31:wt(l,a),e&4&&Pd(l,a);break;case 13:wt(l,a),e&4&&lo(l,a),e&64&&(l=a.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(a=o0.bind(null,a),D0(l,a))));break;case 22:if(e=a.memoizedState!==null||Kt,!e){t=t!==null&&t.memoizedState!==null||Gl,u=Kt;var n=Gl;Kt=e,(Gl=t)&&!n?kt(l,a,(a.subtreeFlags&8772)!==0):wt(l,a),Kt=u,Gl=n}break;case 30:break;default:wt(l,a)}}function Fd(l){var t=l.alternate;t!==null&&(l.alternate=null,Fd(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&Pn(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var _l=null,tt=!1;function Jt(l,t,a){for(a=a.child;a!==null;)Id(l,t,a),a=a.sibling}function Id(l,t,a){if(ct&&typeof ct.onCommitFiberUnmount=="function")try{ct.onCommitFiberUnmount(je,a)}catch{}switch(a.tag){case 26:Gl||Ut(a,t),Jt(l,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:Gl||Ut(a,t);var e=_l,u=tt;ga(a.type)&&(_l=a.stateNode,tt=!1),Jt(l,t,a),vu(a.stateNode),_l=e,tt=u;break;case 5:Gl||Ut(a,t);case 6:if(e=_l,u=tt,_l=null,Jt(l,t,a),_l=e,tt=u,_l!==null)if(tt)try{(_l.nodeType===9?_l.body:_l.nodeName==="HTML"?_l.ownerDocument.body:_l).removeChild(a.stateNode)}catch(n){ol(a,t,n)}else try{_l.removeChild(a.stateNode)}catch(n){ol(a,t,n)}break;case 18:_l!==null&&(tt?(l=_l,Ko(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,a.stateNode),_e(l)):Ko(_l,a.stateNode));break;case 4:e=_l,u=tt,_l=a.stateNode.containerInfo,tt=!0,Jt(l,t,a),_l=e,tt=u;break;case 0:case 11:case 14:case 15:da(2,a,t),Gl||da(4,a,t),Jt(l,t,a);break;case 1:Gl||(Ut(a,t),e=a.stateNode,typeof e.componentWillUnmount=="function"&&Kd(a,t,e)),Jt(l,t,a);break;case 21:Jt(l,t,a);break;case 22:Gl=(e=Gl)||a.memoizedState!==null,Jt(l,t,a),Gl=e;break;default:Jt(l,t,a)}}function Pd(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{_e(l)}catch(a){ol(t,t.return,a)}}}function lo(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{_e(l)}catch(a){ol(t,t.return,a)}}function e0(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new Wd),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new Wd),t;default:throw Error(o(435,l.tag))}}function hn(l,t){var a=e0(l);t.forEach(function(e){if(!a.has(e)){a.add(e);var u=m0.bind(null,l,e);e.then(u,u)}})}function at(l,t){var a=t.deletions;if(a!==null)for(var e=0;e<a.length;e++){var u=a[e],n=l,i=t,c=i;l:for(;c!==null;){switch(c.tag){case 27:if(ga(c.type)){_l=c.stateNode,tt=!1;break l}break;case 5:_l=c.stateNode,tt=!1;break l;case 3:case 4:_l=c.stateNode.containerInfo,tt=!0;break l}c=c.return}if(_l===null)throw Error(o(160));Id(n,i,u),_l=null,tt=!1,n=u.alternate,n!==null&&(n.return=null),u.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)to(t,l),t=t.sibling}var Mt=null;function to(l,t){var a=l.alternate,e=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:at(t,l),et(l),e&4&&(da(3,l,l.return),uu(3,l),da(5,l,l.return));break;case 1:at(t,l),et(l),e&512&&(Gl||a===null||Ut(a,a.return)),e&64&&Kt&&(l=l.updateQueue,l!==null&&(e=l.callbacks,e!==null&&(a=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=a===null?e:a.concat(e))));break;case 26:var u=Mt;if(at(t,l),et(l),e&512&&(Gl||a===null||Ut(a,a.return)),e&4){var n=a!==null?a.memoizedState:null;if(e=l.memoizedState,a===null)if(e===null)if(l.stateNode===null){l:{e=l.type,a=l.memoizedProps,u=u.ownerDocument||u;t:switch(e){case"title":n=u.getElementsByTagName("title")[0],(!n||n[Ue]||n[Ll]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=u.createElement(e),u.head.insertBefore(n,u.querySelector("head > title"))),kl(n,e,a),n[Ll]=l,Ql(n),e=n;break l;case"link":var i=am("link","href",u).get(e+(a.href||""));if(i){for(var c=0;c<i.length;c++)if(n=i[c],n.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&n.getAttribute("rel")===(a.rel==null?null:a.rel)&&n.getAttribute("title")===(a.title==null?null:a.title)&&n.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){i.splice(c,1);break t}}n=u.createElement(e),kl(n,e,a),u.head.appendChild(n);break;case"meta":if(i=am("meta","content",u).get(e+(a.content||""))){for(c=0;c<i.length;c++)if(n=i[c],n.getAttribute("content")===(a.content==null?null:""+a.content)&&n.getAttribute("name")===(a.name==null?null:a.name)&&n.getAttribute("property")===(a.property==null?null:a.property)&&n.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&n.getAttribute("charset")===(a.charSet==null?null:a.charSet)){i.splice(c,1);break t}}n=u.createElement(e),kl(n,e,a),u.head.appendChild(n);break;default:throw Error(o(468,e))}n[Ll]=l,Ql(n),e=n}l.stateNode=e}else em(u,l.type,l.stateNode);else l.stateNode=tm(u,e,l.memoizedProps);else n!==e?(n===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):n.count--,e===null?em(u,l.type,l.stateNode):tm(u,e,l.memoizedProps)):e===null&&l.stateNode!==null&&Tc(l,l.memoizedProps,a.memoizedProps)}break;case 27:at(t,l),et(l),e&512&&(Gl||a===null||Ut(a,a.return)),a!==null&&e&4&&Tc(l,l.memoizedProps,a.memoizedProps);break;case 5:if(at(t,l),et(l),e&512&&(Gl||a===null||Ut(a,a.return)),l.flags&32){u=l.stateNode;try{Wa(u,"")}catch(U){ol(l,l.return,U)}}e&4&&l.stateNode!=null&&(u=l.memoizedProps,Tc(l,u,a!==null?a.memoizedProps:u)),e&1024&&(pc=!0);break;case 6:if(at(t,l),et(l),e&4){if(l.stateNode===null)throw Error(o(162));e=l.memoizedProps,a=l.stateNode;try{a.nodeValue=e}catch(U){ol(l,l.return,U)}}break;case 3:if(Dn=null,u=Mt,Mt=jn(t.containerInfo),at(t,l),Mt=u,et(l),e&4&&a!==null&&a.memoizedState.isDehydrated)try{_e(t.containerInfo)}catch(U){ol(l,l.return,U)}pc&&(pc=!1,ao(l));break;case 4:e=Mt,Mt=jn(l.stateNode.containerInfo),at(t,l),et(l),Mt=e;break;case 12:at(t,l),et(l);break;case 31:at(t,l),et(l),e&4&&(e=l.updateQueue,e!==null&&(l.updateQueue=null,hn(l,e)));break;case 13:at(t,l),et(l),l.child.flags&8192&&l.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(gn=it()),e&4&&(e=l.updateQueue,e!==null&&(l.updateQueue=null,hn(l,e)));break;case 22:u=l.memoizedState!==null;var f=a!==null&&a.memoizedState!==null,h=Kt,T=Gl;if(Kt=h||u,Gl=T||f,at(t,l),Gl=T,Kt=h,et(l),e&8192)l:for(t=l.stateNode,t._visibility=u?t._visibility&-2:t._visibility|1,u&&(a===null||f||Kt||Gl||Xa(l)),a=null,t=l;;){if(t.tag===5||t.tag===26){if(a===null){f=a=t;try{if(n=f.stateNode,u)i=n.style,typeof i.setProperty=="function"?i.setProperty("display","none","important"):i.display="none";else{c=f.stateNode;var p=f.memoizedProps.style,y=p!=null&&p.hasOwnProperty("display")?p.display:null;c.style.display=y==null||typeof y=="boolean"?"":(""+y).trim()}}catch(U){ol(f,f.return,U)}}}else if(t.tag===6){if(a===null){f=t;try{f.stateNode.nodeValue=u?"":f.memoizedProps}catch(U){ol(f,f.return,U)}}}else if(t.tag===18){if(a===null){f=t;try{var b=f.stateNode;u?Jo(b,!0):Jo(f.stateNode,!1)}catch(U){ol(f,f.return,U)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}e&4&&(e=l.updateQueue,e!==null&&(a=e.retryQueue,a!==null&&(e.retryQueue=null,hn(l,a))));break;case 19:at(t,l),et(l),e&4&&(e=l.updateQueue,e!==null&&(l.updateQueue=null,hn(l,e)));break;case 30:break;case 21:break;default:at(t,l),et(l)}}function et(l){var t=l.flags;if(t&2){try{for(var a,e=l.return;e!==null;){if(wd(e)){a=e;break}e=e.return}if(a==null)throw Error(o(160));switch(a.tag){case 27:var u=a.stateNode,n=zc(l);vn(l,n,u);break;case 5:var i=a.stateNode;a.flags&32&&(Wa(i,""),a.flags&=-33);var c=zc(l);vn(l,c,i);break;case 3:case 4:var f=a.stateNode.containerInfo,h=zc(l);Ec(l,h,f);break;default:throw Error(o(161))}}catch(T){ol(l,l.return,T)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function ao(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;ao(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function wt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)$d(l,t.alternate,t),t=t.sibling}function Xa(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:da(4,t,t.return),Xa(t);break;case 1:Ut(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&Kd(t,t.return,a),Xa(t);break;case 27:vu(t.stateNode);case 26:case 5:Ut(t,t.return),Xa(t);break;case 22:t.memoizedState===null&&Xa(t);break;case 30:Xa(t);break;default:Xa(t)}l=l.sibling}}function kt(l,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var e=t.alternate,u=l,n=t,i=n.flags;switch(n.tag){case 0:case 11:case 15:kt(u,n,a),uu(4,n);break;case 1:if(kt(u,n,a),e=n,u=e.stateNode,typeof u.componentDidMount=="function")try{u.componentDidMount()}catch(h){ol(e,e.return,h)}if(e=n,u=e.updateQueue,u!==null){var c=e.stateNode;try{var f=u.shared.hiddenCallbacks;if(f!==null)for(u.shared.hiddenCallbacks=null,u=0;u<f.length;u++)Hs(f[u],c)}catch(h){ol(e,e.return,h)}}a&&i&64&&Ld(n),nu(n,n.return);break;case 27:kd(n);case 26:case 5:kt(u,n,a),a&&e===null&&i&4&&Jd(n),nu(n,n.return);break;case 12:kt(u,n,a);break;case 31:kt(u,n,a),a&&i&4&&Pd(u,n);break;case 13:kt(u,n,a),a&&i&4&&lo(u,n);break;case 22:n.memoizedState===null&&kt(u,n,a),nu(n,n.return);break;case 30:break;default:kt(u,n,a)}t=t.sibling}}function Ac(l,t){var a=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(l!=null&&l.refCount++,a!=null&&Ke(a))}function Oc(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ke(l))}function jt(l,t,a,e){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)eo(l,t,a,e),t=t.sibling}function eo(l,t,a,e){var u=t.flags;switch(t.tag){case 0:case 11:case 15:jt(l,t,a,e),u&2048&&uu(9,t);break;case 1:jt(l,t,a,e);break;case 3:jt(l,t,a,e),u&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ke(l)));break;case 12:if(u&2048){jt(l,t,a,e),l=t.stateNode;try{var n=t.memoizedProps,i=n.id,c=n.onPostCommit;typeof c=="function"&&c(i,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(f){ol(t,t.return,f)}}else jt(l,t,a,e);break;case 31:jt(l,t,a,e);break;case 13:jt(l,t,a,e);break;case 23:break;case 22:n=t.stateNode,i=t.alternate,t.memoizedState!==null?n._visibility&2?jt(l,t,a,e):iu(l,t):n._visibility&2?jt(l,t,a,e):(n._visibility|=2,he(l,t,a,e,(t.subtreeFlags&10256)!==0||!1)),u&2048&&Ac(i,t);break;case 24:jt(l,t,a,e),u&2048&&Oc(t.alternate,t);break;default:jt(l,t,a,e)}}function he(l,t,a,e,u){for(u=u&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var n=l,i=t,c=a,f=e,h=i.flags;switch(i.tag){case 0:case 11:case 15:he(n,i,c,f,u),uu(8,i);break;case 23:break;case 22:var T=i.stateNode;i.memoizedState!==null?T._visibility&2?he(n,i,c,f,u):iu(n,i):(T._visibility|=2,he(n,i,c,f,u)),u&&h&2048&&Ac(i.alternate,i);break;case 24:he(n,i,c,f,u),u&&h&2048&&Oc(i.alternate,i);break;default:he(n,i,c,f,u)}t=t.sibling}}function iu(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=l,e=t,u=e.flags;switch(e.tag){case 22:iu(a,e),u&2048&&Ac(e.alternate,e);break;case 24:iu(a,e),u&2048&&Oc(e.alternate,e);break;default:iu(a,e)}t=t.sibling}}var cu=8192;function ye(l,t,a){if(l.subtreeFlags&cu)for(l=l.child;l!==null;)uo(l,t,a),l=l.sibling}function uo(l,t,a){switch(l.tag){case 26:ye(l,t,a),l.flags&cu&&l.memoizedState!==null&&V0(a,Mt,l.memoizedState,l.memoizedProps);break;case 5:ye(l,t,a);break;case 3:case 4:var e=Mt;Mt=jn(l.stateNode.containerInfo),ye(l,t,a),Mt=e;break;case 22:l.memoizedState===null&&(e=l.alternate,e!==null&&e.memoizedState!==null?(e=cu,cu=16777216,ye(l,t,a),cu=e):ye(l,t,a));break;default:ye(l,t,a)}}function no(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function fu(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var e=t[a];Zl=e,co(e,l)}no(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)io(l),l=l.sibling}function io(l){switch(l.tag){case 0:case 11:case 15:fu(l),l.flags&2048&&da(9,l,l.return);break;case 3:fu(l);break;case 12:fu(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,yn(l)):fu(l);break;default:fu(l)}}function yn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var e=t[a];Zl=e,co(e,l)}no(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:da(8,t,t.return),yn(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,yn(t));break;default:yn(t)}l=l.sibling}}function co(l,t){for(;Zl!==null;){var a=Zl;switch(a.tag){case 0:case 11:case 15:da(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var e=a.memoizedState.cachePool.pool;e!=null&&e.refCount++}break;case 24:Ke(a.memoizedState.cache)}if(e=a.child,e!==null)e.return=a,Zl=e;else l:for(a=l;Zl!==null;){e=Zl;var u=e.sibling,n=e.return;if(Fd(e),e===a){Zl=null;break l}if(u!==null){u.return=n,Zl=u;break l}Zl=n}}}var u0={getCacheForType:function(l){var t=Jl(ql),a=t.data.get(l);return a===void 0&&(a=l(),t.data.set(l,a)),a},cacheSignal:function(){return Jl(ql).controller.signal}},n0=typeof WeakMap=="function"?WeakMap:Map,fl=0,gl=null,F=null,ll=0,dl=0,rt=null,oa=!1,ge=!1,_c=!1,Wt=0,Dl=0,ma=0,Qa=0,Nc=0,vt=0,Se=0,su=null,ut=null,Mc=!1,gn=0,fo=0,Sn=1/0,bn=null,ra=null,Xl=0,va=null,be=null,$t=0,jc=0,xc=null,so=null,du=0,Dc=null;function ht(){return(fl&2)!==0&&ll!==0?ll&-ll:z.T!==null?Bc():Of()}function oo(){if(vt===0)if((ll&536870912)===0||al){var l=_u;_u<<=1,(_u&3932160)===0&&(_u=262144),vt=l}else vt=536870912;return l=ot.current,l!==null&&(l.flags|=32),vt}function nt(l,t,a){(l===gl&&(dl===2||dl===9)||l.cancelPendingCommit!==null)&&(Te(l,0),ha(l,ll,vt,!1)),De(l,a),((fl&2)===0||l!==gl)&&(l===gl&&((fl&2)===0&&(Qa|=a),Dl===4&&ha(l,ll,vt,!1)),Ht(l))}function mo(l,t,a){if((fl&6)!==0)throw Error(o(327));var e=!a&&(t&127)===0&&(t&l.expiredLanes)===0||xe(l,t),u=e?f0(l,t):Hc(l,t,!0),n=e;do{if(u===0){ge&&!e&&ha(l,t,0,!1);break}else{if(a=l.current.alternate,n&&!i0(a)){u=Hc(l,t,!1),n=!1;continue}if(u===2){if(n=t,l.errorRecoveryDisabledLanes&n)var i=0;else i=l.pendingLanes&-536870913,i=i!==0?i:i&536870912?536870912:0;if(i!==0){t=i;l:{var c=l;u=su;var f=c.current.memoizedState.isDehydrated;if(f&&(Te(c,i).flags|=256),i=Hc(c,i,!1),i!==2){if(_c&&!f){c.errorRecoveryDisabledLanes|=n,Qa|=n,u=4;break l}n=ut,ut=u,n!==null&&(ut===null?ut=n:ut.push.apply(ut,n))}u=i}if(n=!1,u!==2)continue}}if(u===1){Te(l,0),ha(l,t,0,!0);break}l:{switch(e=l,n=u,n){case 0:case 1:throw Error(o(345));case 4:if((t&4194048)!==t)break;case 6:ha(e,t,vt,!oa);break l;case 2:ut=null;break;case 3:case 5:break;default:throw Error(o(329))}if((t&62914560)===t&&(u=gn+300-it(),10<u)){if(ha(e,t,vt,!oa),Mu(e,0,!0)!==0)break l;$t=t,e.timeoutHandle=Vo(ro.bind(null,e,a,ut,bn,Mc,t,vt,Qa,Se,oa,n,"Throttled",-0,0),u);break l}ro(e,a,ut,bn,Mc,t,vt,Qa,Se,oa,n,null,-0,0)}}break}while(!0);Ht(l)}function ro(l,t,a,e,u,n,i,c,f,h,T,p,y,b){if(l.timeoutHandle=-1,p=t.subtreeFlags,p&8192||(p&16785408)===16785408){p={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Ct},uo(t,n,p);var U=(n&62914560)===n?gn-it():(n&4194048)===n?fo-it():0;if(U=L0(p,U),U!==null){$t=n,l.cancelPendingCommit=U(zo.bind(null,l,t,n,a,e,u,i,c,f,T,p,null,y,b)),ha(l,n,i,!h);return}}zo(l,t,n,a,e,u,i,c,f)}function i0(l){for(var t=l;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var e=0;e<a.length;e++){var u=a[e],n=u.getSnapshot;u=u.value;try{if(!st(n(),u))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function ha(l,t,a,e){t&=~Nc,t&=~Qa,l.suspendedLanes|=t,l.pingedLanes&=~t,e&&(l.warmLanes|=t),e=l.expirationTimes;for(var u=t;0<u;){var n=31-ft(u),i=1<<n;e[n]=-1,u&=~i}a!==0&&Ef(l,a,t)}function Tn(){return(fl&6)===0?(ou(0),!1):!0}function Uc(){if(F!==null){if(dl===0)var l=F.return;else l=F,Gt=Ua=null,ki(l),de=null,we=0,l=F;for(;l!==null;)Vd(l.alternate,l),l=l.return;F=null}}function Te(l,t){var a=l.timeoutHandle;a!==-1&&(l.timeoutHandle=-1,_0(a)),a=l.cancelPendingCommit,a!==null&&(l.cancelPendingCommit=null,a()),$t=0,Uc(),gl=l,F=a=Bt(l.current,null),ll=t,dl=0,rt=null,oa=!1,ge=xe(l,t),_c=!1,Se=vt=Nc=Qa=ma=Dl=0,ut=su=null,Mc=!1,(t&8)!==0&&(t|=t&32);var e=l.entangledLanes;if(e!==0)for(l=l.entanglements,e&=t;0<e;){var u=31-ft(e),n=1<<u;t|=l[u],e&=~n}return Wt=t,Xu(),a}function vo(l,t){k=null,z.H=tu,t===se||t===ku?(t=js(),dl=3):t===qi?(t=js(),dl=4):dl=t===dc?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,rt=t,F===null&&(Dl=1,sn(l,Tt(t,l.current)))}function ho(){var l=ot.current;return l===null?!0:(ll&4194048)===ll?At===null:(ll&62914560)===ll||(ll&536870912)!==0?l===At:!1}function yo(){var l=z.H;return z.H=tu,l===null?tu:l}function go(){var l=z.A;return z.A=u0,l}function zn(){Dl=4,oa||(ll&4194048)!==ll&&ot.current!==null||(ge=!0),(ma&134217727)===0&&(Qa&134217727)===0||gl===null||ha(gl,ll,vt,!1)}function Hc(l,t,a){var e=fl;fl|=2;var u=yo(),n=go();(gl!==l||ll!==t)&&(bn=null,Te(l,t)),t=!1;var i=Dl;l:do try{if(dl!==0&&F!==null){var c=F,f=rt;switch(dl){case 8:Uc(),i=6;break l;case 3:case 2:case 9:case 6:ot.current===null&&(t=!0);var h=dl;if(dl=0,rt=null,ze(l,c,f,h),a&&ge){i=0;break l}break;default:h=dl,dl=0,rt=null,ze(l,c,f,h)}}c0(),i=Dl;break}catch(T){vo(l,T)}while(!0);return t&&l.shellSuspendCounter++,Gt=Ua=null,fl=e,z.H=u,z.A=n,F===null&&(gl=null,ll=0,Xu()),i}function c0(){for(;F!==null;)So(F)}function f0(l,t){var a=fl;fl|=2;var e=yo(),u=go();gl!==l||ll!==t?(bn=null,Sn=it()+500,Te(l,t)):ge=xe(l,t);l:do try{if(dl!==0&&F!==null){t=F;var n=rt;t:switch(dl){case 1:dl=0,rt=null,ze(l,t,n,1);break;case 2:case 9:if(Ns(n)){dl=0,rt=null,bo(t);break}t=function(){dl!==2&&dl!==9||gl!==l||(dl=7),Ht(l)},n.then(t,t);break l;case 3:dl=7;break l;case 4:dl=5;break l;case 7:Ns(n)?(dl=0,rt=null,bo(t)):(dl=0,rt=null,ze(l,t,n,7));break;case 5:var i=null;switch(F.tag){case 26:i=F.memoizedState;case 5:case 27:var c=F;if(i?um(i):c.stateNode.complete){dl=0,rt=null;var f=c.sibling;if(f!==null)F=f;else{var h=c.return;h!==null?(F=h,En(h)):F=null}break t}}dl=0,rt=null,ze(l,t,n,5);break;case 6:dl=0,rt=null,ze(l,t,n,6);break;case 8:Uc(),Dl=6;break l;default:throw Error(o(462))}}s0();break}catch(T){vo(l,T)}while(!0);return Gt=Ua=null,z.H=e,z.A=u,fl=a,F!==null?0:(gl=null,ll=0,Xu(),Dl)}function s0(){for(;F!==null&&!Um();)So(F)}function So(l){var t=Qd(l.alternate,l,Wt);l.memoizedProps=l.pendingProps,t===null?En(l):F=t}function bo(l){var t=l,a=t.alternate;switch(t.tag){case 15:case 0:t=Cd(a,t,t.pendingProps,t.type,void 0,ll);break;case 11:t=Cd(a,t,t.pendingProps,t.type.render,t.ref,ll);break;case 5:ki(t);default:Vd(a,t),t=F=ys(t,Wt),t=Qd(a,t,Wt)}l.memoizedProps=l.pendingProps,t===null?En(l):F=t}function ze(l,t,a,e){Gt=Ua=null,ki(t),de=null,we=0;var u=t.return;try{if(Fr(l,u,t,a,ll)){Dl=1,sn(l,Tt(a,l.current)),F=null;return}}catch(n){if(u!==null)throw F=u,n;Dl=1,sn(l,Tt(a,l.current)),F=null;return}t.flags&32768?(al||e===1?l=!0:ge||(ll&536870912)!==0?l=!1:(oa=l=!0,(e===2||e===9||e===3||e===6)&&(e=ot.current,e!==null&&e.tag===13&&(e.flags|=16384))),To(t,l)):En(t)}function En(l){var t=l;do{if((t.flags&32768)!==0){To(t,oa);return}l=t.return;var a=l0(t.alternate,t,Wt);if(a!==null){F=a;return}if(t=t.sibling,t!==null){F=t;return}F=t=l}while(t!==null);Dl===0&&(Dl=5)}function To(l,t){do{var a=t0(l.alternate,l);if(a!==null){a.flags&=32767,F=a;return}if(a=l.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(l=l.sibling,l!==null)){F=l;return}F=l=a}while(l!==null);Dl=6,F=null}function zo(l,t,a,e,u,n,i,c,f){l.cancelPendingCommit=null;do pn();while(Xl!==0);if((fl&6)!==0)throw Error(o(327));if(t!==null){if(t===l.current)throw Error(o(177));if(n=t.lanes|t.childLanes,n|=zi,Zm(l,a,n,i,c,f),l===gl&&(F=gl=null,ll=0),be=t,va=l,$t=a,jc=n,xc=u,so=e,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,r0(Au,function(){return _o(),null})):(l.callbackNode=null,l.callbackPriority=0),e=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||e){e=z.T,z.T=null,u=j.p,j.p=2,i=fl,fl|=4;try{a0(l,t,a)}finally{fl=i,j.p=u,z.T=e}}Xl=1,Eo(),po(),Ao()}}function Eo(){if(Xl===1){Xl=0;var l=va,t=be,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=z.T,z.T=null;var e=j.p;j.p=2;var u=fl;fl|=4;try{to(t,l);var n=Kc,i=cs(l.containerInfo),c=n.focusedElem,f=n.selectionRange;if(i!==c&&c&&c.ownerDocument&&is(c.ownerDocument.documentElement,c)){if(f!==null&&yi(c)){var h=f.start,T=f.end;if(T===void 0&&(T=h),"selectionStart"in c)c.selectionStart=h,c.selectionEnd=Math.min(T,c.value.length);else{var p=c.ownerDocument||document,y=p&&p.defaultView||window;if(y.getSelection){var b=y.getSelection(),U=c.textContent.length,Q=Math.min(f.start,U),hl=f.end===void 0?Q:Math.min(f.end,U);!b.extend&&Q>hl&&(i=hl,hl=Q,Q=i);var m=ns(c,Q),s=ns(c,hl);if(m&&s&&(b.rangeCount!==1||b.anchorNode!==m.node||b.anchorOffset!==m.offset||b.focusNode!==s.node||b.focusOffset!==s.offset)){var v=p.createRange();v.setStart(m.node,m.offset),b.removeAllRanges(),Q>hl?(b.addRange(v),b.extend(s.node,s.offset)):(v.setEnd(s.node,s.offset),b.addRange(v))}}}}for(p=[],b=c;b=b.parentNode;)b.nodeType===1&&p.push({element:b,left:b.scrollLeft,top:b.scrollTop});for(typeof c.focus=="function"&&c.focus(),c=0;c<p.length;c++){var E=p[c];E.element.scrollLeft=E.left,E.element.scrollTop=E.top}}Cn=!!Lc,Kc=Lc=null}finally{fl=u,j.p=e,z.T=a}}l.current=t,Xl=2}}function po(){if(Xl===2){Xl=0;var l=va,t=be,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=z.T,z.T=null;var e=j.p;j.p=2;var u=fl;fl|=4;try{$d(l,t.alternate,t)}finally{fl=u,j.p=e,z.T=a}}Xl=3}}function Ao(){if(Xl===4||Xl===3){Xl=0,Hm();var l=va,t=be,a=$t,e=so;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Xl=5:(Xl=0,be=va=null,Oo(l,l.pendingLanes));var u=l.pendingLanes;if(u===0&&(ra=null),Fn(a),t=t.stateNode,ct&&typeof ct.onCommitFiberRoot=="function")try{ct.onCommitFiberRoot(je,t,void 0,(t.current.flags&128)===128)}catch{}if(e!==null){t=z.T,u=j.p,j.p=2,z.T=null;try{for(var n=l.onRecoverableError,i=0;i<e.length;i++){var c=e[i];n(c.value,{componentStack:c.stack})}}finally{z.T=t,j.p=u}}($t&3)!==0&&pn(),Ht(l),u=l.pendingLanes,(a&261930)!==0&&(u&42)!==0?l===Dc?du++:(du=0,Dc=l):du=0,ou(0)}}function Oo(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Ke(t)))}function pn(){return Eo(),po(),Ao(),_o()}function _o(){if(Xl!==5)return!1;var l=va,t=jc;jc=0;var a=Fn($t),e=z.T,u=j.p;try{j.p=32>a?32:a,z.T=null,a=xc,xc=null;var n=va,i=$t;if(Xl=0,be=va=null,$t=0,(fl&6)!==0)throw Error(o(331));var c=fl;if(fl|=4,io(n.current),eo(n,n.current,i,a),fl=c,ou(0,!1),ct&&typeof ct.onPostCommitFiberRoot=="function")try{ct.onPostCommitFiberRoot(je,n)}catch{}return!0}finally{j.p=u,z.T=e,Oo(l,t)}}function No(l,t,a){t=Tt(a,t),t=sc(l.stateNode,t,2),l=ca(l,t,2),l!==null&&(De(l,2),Ht(l))}function ol(l,t,a){if(l.tag===3)No(l,l,a);else for(;t!==null;){if(t.tag===3){No(t,l,a);break}else if(t.tag===1){var e=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof e.componentDidCatch=="function"&&(ra===null||!ra.has(e))){l=Tt(a,l),a=Nd(2),e=ca(t,a,2),e!==null&&(Md(a,e,t,l),De(e,2),Ht(e));break}}t=t.return}}function Rc(l,t,a){var e=l.pingCache;if(e===null){e=l.pingCache=new n0;var u=new Set;e.set(t,u)}else u=e.get(t),u===void 0&&(u=new Set,e.set(t,u));u.has(a)||(_c=!0,u.add(a),l=d0.bind(null,l,t,a),t.then(l,l))}function d0(l,t,a){var e=l.pingCache;e!==null&&e.delete(t),l.pingedLanes|=l.suspendedLanes&a,l.warmLanes&=~a,gl===l&&(ll&a)===a&&(Dl===4||Dl===3&&(ll&62914560)===ll&&300>it()-gn?(fl&2)===0&&Te(l,0):Nc|=a,Se===ll&&(Se=0)),Ht(l)}function Mo(l,t){t===0&&(t=zf()),l=ja(l,t),l!==null&&(De(l,t),Ht(l))}function o0(l){var t=l.memoizedState,a=0;t!==null&&(a=t.retryLane),Mo(l,a)}function m0(l,t){var a=0;switch(l.tag){case 31:case 13:var e=l.stateNode,u=l.memoizedState;u!==null&&(a=u.retryLane);break;case 19:e=l.stateNode;break;case 22:e=l.stateNode._retryCache;break;default:throw Error(o(314))}e!==null&&e.delete(t),Mo(l,a)}function r0(l,t){return wn(l,t)}var An=null,Ee=null,Cc=!1,On=!1,qc=!1,ya=0;function Ht(l){l!==Ee&&l.next===null&&(Ee===null?An=Ee=l:Ee=Ee.next=l),On=!0,Cc||(Cc=!0,h0())}function ou(l,t){if(!qc&&On){qc=!0;do for(var a=!1,e=An;e!==null;){if(l!==0){var u=e.pendingLanes;if(u===0)var n=0;else{var i=e.suspendedLanes,c=e.pingedLanes;n=(1<<31-ft(42|l)+1)-1,n&=u&~(i&~c),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(a=!0,Uo(e,n))}else n=ll,n=Mu(e,e===gl?n:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),(n&3)===0||xe(e,n)||(a=!0,Uo(e,n));e=e.next}while(a);qc=!1}}function v0(){jo()}function jo(){On=Cc=!1;var l=0;ya!==0&&O0()&&(l=ya);for(var t=it(),a=null,e=An;e!==null;){var u=e.next,n=xo(e,t);n===0?(e.next=null,a===null?An=u:a.next=u,u===null&&(Ee=a)):(a=e,(l!==0||(n&3)!==0)&&(On=!0)),e=u}Xl!==0&&Xl!==5||ou(l),ya!==0&&(ya=0)}function xo(l,t){for(var a=l.suspendedLanes,e=l.pingedLanes,u=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var i=31-ft(n),c=1<<i,f=u[i];f===-1?((c&a)===0||(c&e)!==0)&&(u[i]=Qm(c,t)):f<=t&&(l.expiredLanes|=c),n&=~c}if(t=gl,a=ll,a=Mu(l,l===t?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),e=l.callbackNode,a===0||l===t&&(dl===2||dl===9)||l.cancelPendingCommit!==null)return e!==null&&e!==null&&kn(e),l.callbackNode=null,l.callbackPriority=0;if((a&3)===0||xe(l,a)){if(t=a&-a,t===l.callbackPriority)return t;switch(e!==null&&kn(e),Fn(a)){case 2:case 8:a=bf;break;case 32:a=Au;break;case 268435456:a=Tf;break;default:a=Au}return e=Do.bind(null,l),a=wn(a,e),l.callbackPriority=t,l.callbackNode=a,t}return e!==null&&e!==null&&kn(e),l.callbackPriority=2,l.callbackNode=null,2}function Do(l,t){if(Xl!==0&&Xl!==5)return l.callbackNode=null,l.callbackPriority=0,null;var a=l.callbackNode;if(pn()&&l.callbackNode!==a)return null;var e=ll;return e=Mu(l,l===gl?e:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),e===0?null:(mo(l,e,t),xo(l,it()),l.callbackNode!=null&&l.callbackNode===a?Do.bind(null,l):null)}function Uo(l,t){if(pn())return null;mo(l,t,!0)}function h0(){N0(function(){(fl&6)!==0?wn(Sf,v0):jo()})}function Bc(){if(ya===0){var l=ce;l===0&&(l=Ou,Ou<<=1,(Ou&261888)===0&&(Ou=256)),ya=l}return ya}function Ho(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Uu(""+l)}function Ro(l,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,l.id&&a.setAttribute("form",l.id),t.parentNode.insertBefore(a,t),l=new FormData(l),a.parentNode.removeChild(a),l}function y0(l,t,a,e,u){if(t==="submit"&&a&&a.stateNode===u){var n=Ho((u[Pl]||null).action),i=e.submitter;i&&(t=(t=i[Pl]||null)?Ho(t.formAction):i.getAttribute("formAction"),t!==null&&(n=t,i=null));var c=new qu("action","action",null,e,u);l.push({event:c,listeners:[{instance:null,listener:function(){if(e.defaultPrevented){if(ya!==0){var f=i?Ro(u,i):new FormData(u);ec(a,{pending:!0,data:f,method:u.method,action:n},null,f)}}else typeof n=="function"&&(c.preventDefault(),f=i?Ro(u,i):new FormData(u),ec(a,{pending:!0,data:f,method:u.method,action:n},n,f))},currentTarget:u}]})}}for(var Yc=0;Yc<Ti.length;Yc++){var Gc=Ti[Yc],g0=Gc.toLowerCase(),S0=Gc[0].toUpperCase()+Gc.slice(1);Nt(g0,"on"+S0)}Nt(ds,"onAnimationEnd"),Nt(os,"onAnimationIteration"),Nt(ms,"onAnimationStart"),Nt("dblclick","onDoubleClick"),Nt("focusin","onFocus"),Nt("focusout","onBlur"),Nt(Rr,"onTransitionRun"),Nt(Cr,"onTransitionStart"),Nt(qr,"onTransitionCancel"),Nt(rs,"onTransitionEnd"),wa("onMouseEnter",["mouseout","mouseover"]),wa("onMouseLeave",["mouseout","mouseover"]),wa("onPointerEnter",["pointerout","pointerover"]),wa("onPointerLeave",["pointerout","pointerover"]),Oa("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Oa("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Oa("onBeforeInput",["compositionend","keypress","textInput","paste"]),Oa("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Oa("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Oa("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var mu="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),b0=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(mu));function Co(l,t){t=(t&4)!==0;for(var a=0;a<l.length;a++){var e=l[a],u=e.event;e=e.listeners;l:{var n=void 0;if(t)for(var i=e.length-1;0<=i;i--){var c=e[i],f=c.instance,h=c.currentTarget;if(c=c.listener,f!==n&&u.isPropagationStopped())break l;n=c,u.currentTarget=h;try{n(u)}catch(T){Gu(T)}u.currentTarget=null,n=f}else for(i=0;i<e.length;i++){if(c=e[i],f=c.instance,h=c.currentTarget,c=c.listener,f!==n&&u.isPropagationStopped())break l;n=c,u.currentTarget=h;try{n(u)}catch(T){Gu(T)}u.currentTarget=null,n=f}}}}function I(l,t){var a=t[In];a===void 0&&(a=t[In]=new Set);var e=l+"__bubble";a.has(e)||(qo(t,l,2,!1),a.add(e))}function Xc(l,t,a){var e=0;t&&(e|=4),qo(a,l,e,t)}var _n="_reactListening"+Math.random().toString(36).slice(2);function Qc(l){if(!l[_n]){l[_n]=!0,Mf.forEach(function(a){a!=="selectionchange"&&(b0.has(a)||Xc(a,!1,l),Xc(a,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[_n]||(t[_n]=!0,Xc("selectionchange",!1,t))}}function qo(l,t,a,e){switch(om(t)){case 2:var u=w0;break;case 8:u=k0;break;default:u=af}a=u.bind(null,t,a,l),u=void 0,!ci||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(u=!0),e?u!==void 0?l.addEventListener(t,a,{capture:!0,passive:u}):l.addEventListener(t,a,!0):u!==void 0?l.addEventListener(t,a,{passive:u}):l.addEventListener(t,a,!1)}function Zc(l,t,a,e,u){var n=e;if((t&1)===0&&(t&2)===0&&e!==null)l:for(;;){if(e===null)return;var i=e.tag;if(i===3||i===4){var c=e.stateNode.containerInfo;if(c===u)break;if(i===4)for(i=e.return;i!==null;){var f=i.tag;if((f===3||f===4)&&i.stateNode.containerInfo===u)return;i=i.return}for(;c!==null;){if(i=La(c),i===null)return;if(f=i.tag,f===5||f===6||f===26||f===27){e=n=i;continue l}c=c.parentNode}}e=e.return}Xf(function(){var h=n,T=ni(a),p=[];l:{var y=vs.get(l);if(y!==void 0){var b=qu,U=l;switch(l){case"keypress":if(Ru(a)===0)break l;case"keydown":case"keyup":b=mr;break;case"focusin":U="focus",b=oi;break;case"focusout":U="blur",b=oi;break;case"beforeblur":case"afterblur":b=oi;break;case"click":if(a.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":b=Vf;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":b=lr;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":b=hr;break;case ds:case os:case ms:b=er;break;case rs:b=gr;break;case"scroll":case"scrollend":b=Im;break;case"wheel":b=br;break;case"copy":case"cut":case"paste":b=nr;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":b=Kf;break;case"toggle":case"beforetoggle":b=zr}var Q=(t&4)!==0,hl=!Q&&(l==="scroll"||l==="scrollend"),m=Q?y!==null?y+"Capture":null:y;Q=[];for(var s=h,v;s!==null;){var E=s;if(v=E.stateNode,E=E.tag,E!==5&&E!==26&&E!==27||v===null||m===null||(E=Re(s,m),E!=null&&Q.push(ru(s,E,v))),hl)break;s=s.return}0<Q.length&&(y=new b(y,U,null,a,T),p.push({event:y,listeners:Q}))}}if((t&7)===0){l:{if(y=l==="mouseover"||l==="pointerover",b=l==="mouseout"||l==="pointerout",y&&a!==ui&&(U=a.relatedTarget||a.fromElement)&&(La(U)||U[Va]))break l;if((b||y)&&(y=T.window===T?T:(y=T.ownerDocument)?y.defaultView||y.parentWindow:window,b?(U=a.relatedTarget||a.toElement,b=h,U=U?La(U):null,U!==null&&(hl=C(U),Q=U.tag,U!==hl||Q!==5&&Q!==27&&Q!==6)&&(U=null)):(b=null,U=h),b!==U)){if(Q=Vf,E="onMouseLeave",m="onMouseEnter",s="mouse",(l==="pointerout"||l==="pointerover")&&(Q=Kf,E="onPointerLeave",m="onPointerEnter",s="pointer"),hl=b==null?y:He(b),v=U==null?y:He(U),y=new Q(E,s+"leave",b,a,T),y.target=hl,y.relatedTarget=v,E=null,La(T)===h&&(Q=new Q(m,s+"enter",U,a,T),Q.target=v,Q.relatedTarget=hl,E=Q),hl=E,b&&U)t:{for(Q=T0,m=b,s=U,v=0,E=m;E;E=Q(E))v++;E=0;for(var B=s;B;B=Q(B))E++;for(;0<v-E;)m=Q(m),v--;for(;0<E-v;)s=Q(s),E--;for(;v--;){if(m===s||s!==null&&m===s.alternate){Q=m;break t}m=Q(m),s=Q(s)}Q=null}else Q=null;b!==null&&Bo(p,y,b,Q,!1),U!==null&&hl!==null&&Bo(p,hl,U,Q,!0)}}l:{if(y=h?He(h):window,b=y.nodeName&&y.nodeName.toLowerCase(),b==="select"||b==="input"&&y.type==="file")var il=Pf;else if(Ff(y))if(ls)il=Dr;else{il=jr;var q=Mr}else b=y.nodeName,!b||b.toLowerCase()!=="input"||y.type!=="checkbox"&&y.type!=="radio"?h&&ei(h.elementType)&&(il=Pf):il=xr;if(il&&(il=il(l,h))){If(p,il,a,T);break l}q&&q(l,y,h),l==="focusout"&&h&&y.type==="number"&&h.memoizedProps.value!=null&&ai(y,"number",y.value)}switch(q=h?He(h):window,l){case"focusin":(Ff(q)||q.contentEditable==="true")&&(Pa=q,gi=h,Ze=null);break;case"focusout":Ze=gi=Pa=null;break;case"mousedown":Si=!0;break;case"contextmenu":case"mouseup":case"dragend":Si=!1,fs(p,a,T);break;case"selectionchange":if(Hr)break;case"keydown":case"keyup":fs(p,a,T)}var W;if(ri)l:{switch(l){case"compositionstart":var tl="onCompositionStart";break l;case"compositionend":tl="onCompositionEnd";break l;case"compositionupdate":tl="onCompositionUpdate";break l}tl=void 0}else Ia?Wf(l,a)&&(tl="onCompositionEnd"):l==="keydown"&&a.keyCode===229&&(tl="onCompositionStart");tl&&(Jf&&a.locale!=="ko"&&(Ia||tl!=="onCompositionStart"?tl==="onCompositionEnd"&&Ia&&(W=Qf()):(la=T,fi="value"in la?la.value:la.textContent,Ia=!0)),q=Nn(h,tl),0<q.length&&(tl=new Lf(tl,l,null,a,T),p.push({event:tl,listeners:q}),W?tl.data=W:(W=$f(a),W!==null&&(tl.data=W)))),(W=pr?Ar(l,a):Or(l,a))&&(tl=Nn(h,"onBeforeInput"),0<tl.length&&(q=new Lf("onBeforeInput","beforeinput",null,a,T),p.push({event:q,listeners:tl}),q.data=W)),y0(p,l,h,a,T)}Co(p,t)})}function ru(l,t,a){return{instance:l,listener:t,currentTarget:a}}function Nn(l,t){for(var a=t+"Capture",e=[];l!==null;){var u=l,n=u.stateNode;if(u=u.tag,u!==5&&u!==26&&u!==27||n===null||(u=Re(l,a),u!=null&&e.unshift(ru(l,u,n)),u=Re(l,t),u!=null&&e.push(ru(l,u,n))),l.tag===3)return e;l=l.return}return[]}function T0(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function Bo(l,t,a,e,u){for(var n=t._reactName,i=[];a!==null&&a!==e;){var c=a,f=c.alternate,h=c.stateNode;if(c=c.tag,f!==null&&f===e)break;c!==5&&c!==26&&c!==27||h===null||(f=h,u?(h=Re(a,n),h!=null&&i.unshift(ru(a,h,f))):u||(h=Re(a,n),h!=null&&i.push(ru(a,h,f)))),a=a.return}i.length!==0&&l.push({event:t,listeners:i})}var z0=/\\r\\n?/g,E0=/\\u0000|\\uFFFD/g;function Yo(l){return(typeof l=="string"?l:""+l).replace(z0,`
`).replace(E0,"")}function Go(l,t){return t=Yo(t),Yo(l)===t}function vl(l,t,a,e,u,n){switch(a){case"children":typeof e=="string"?t==="body"||t==="textarea"&&e===""||Wa(l,e):(typeof e=="number"||typeof e=="bigint")&&t!=="body"&&Wa(l,""+e);break;case"className":xu(l,"class",e);break;case"tabIndex":xu(l,"tabindex",e);break;case"dir":case"role":case"viewBox":case"width":case"height":xu(l,a,e);break;case"style":Yf(l,e,n);break;case"data":if(t!=="object"){xu(l,"data",e);break}case"src":case"href":if(e===""&&(t!=="a"||a!=="href")){l.removeAttribute(a);break}if(e==null||typeof e=="function"||typeof e=="symbol"||typeof e=="boolean"){l.removeAttribute(a);break}e=Uu(""+e),l.setAttribute(a,e);break;case"action":case"formAction":if(typeof e=="function"){l.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(a==="formAction"?(t!=="input"&&vl(l,t,"name",u.name,u,null),vl(l,t,"formEncType",u.formEncType,u,null),vl(l,t,"formMethod",u.formMethod,u,null),vl(l,t,"formTarget",u.formTarget,u,null)):(vl(l,t,"encType",u.encType,u,null),vl(l,t,"method",u.method,u,null),vl(l,t,"target",u.target,u,null)));if(e==null||typeof e=="symbol"||typeof e=="boolean"){l.removeAttribute(a);break}e=Uu(""+e),l.setAttribute(a,e);break;case"onClick":e!=null&&(l.onclick=Ct);break;case"onScroll":e!=null&&I("scroll",l);break;case"onScrollEnd":e!=null&&I("scrollend",l);break;case"dangerouslySetInnerHTML":if(e!=null){if(typeof e!="object"||!("__html"in e))throw Error(o(61));if(a=e.__html,a!=null){if(u.children!=null)throw Error(o(60));l.innerHTML=a}}break;case"multiple":l.multiple=e&&typeof e!="function"&&typeof e!="symbol";break;case"muted":l.muted=e&&typeof e!="function"&&typeof e!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(e==null||typeof e=="function"||typeof e=="boolean"||typeof e=="symbol"){l.removeAttribute("xlink:href");break}a=Uu(""+e),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":e!=null&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,""+e):l.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":e&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,""):l.removeAttribute(a);break;case"capture":case"download":e===!0?l.setAttribute(a,""):e!==!1&&e!=null&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,e):l.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":e!=null&&typeof e!="function"&&typeof e!="symbol"&&!isNaN(e)&&1<=e?l.setAttribute(a,e):l.removeAttribute(a);break;case"rowSpan":case"start":e==null||typeof e=="function"||typeof e=="symbol"||isNaN(e)?l.removeAttribute(a):l.setAttribute(a,e);break;case"popover":I("beforetoggle",l),I("toggle",l),ju(l,"popover",e);break;case"xlinkActuate":Rt(l,"http://www.w3.org/1999/xlink","xlink:actuate",e);break;case"xlinkArcrole":Rt(l,"http://www.w3.org/1999/xlink","xlink:arcrole",e);break;case"xlinkRole":Rt(l,"http://www.w3.org/1999/xlink","xlink:role",e);break;case"xlinkShow":Rt(l,"http://www.w3.org/1999/xlink","xlink:show",e);break;case"xlinkTitle":Rt(l,"http://www.w3.org/1999/xlink","xlink:title",e);break;case"xlinkType":Rt(l,"http://www.w3.org/1999/xlink","xlink:type",e);break;case"xmlBase":Rt(l,"http://www.w3.org/XML/1998/namespace","xml:base",e);break;case"xmlLang":Rt(l,"http://www.w3.org/XML/1998/namespace","xml:lang",e);break;case"xmlSpace":Rt(l,"http://www.w3.org/XML/1998/namespace","xml:space",e);break;case"is":ju(l,"is",e);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=$m.get(a)||a,ju(l,a,e))}}function Vc(l,t,a,e,u,n){switch(a){case"style":Yf(l,e,n);break;case"dangerouslySetInnerHTML":if(e!=null){if(typeof e!="object"||!("__html"in e))throw Error(o(61));if(a=e.__html,a!=null){if(u.children!=null)throw Error(o(60));l.innerHTML=a}}break;case"children":typeof e=="string"?Wa(l,e):(typeof e=="number"||typeof e=="bigint")&&Wa(l,""+e);break;case"onScroll":e!=null&&I("scroll",l);break;case"onScrollEnd":e!=null&&I("scrollend",l);break;case"onClick":e!=null&&(l.onclick=Ct);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!jf.hasOwnProperty(a))l:{if(a[0]==="o"&&a[1]==="n"&&(u=a.endsWith("Capture"),t=a.slice(2,u?a.length-7:void 0),n=l[Pl]||null,n=n!=null?n[a]:null,typeof n=="function"&&l.removeEventListener(t,n,u),typeof e=="function")){typeof n!="function"&&n!==null&&(a in l?l[a]=null:l.hasAttribute(a)&&l.removeAttribute(a)),l.addEventListener(t,e,u);break l}a in l?l[a]=e:e===!0?l.setAttribute(a,""):ju(l,a,e)}}}function kl(l,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":I("error",l),I("load",l);var e=!1,u=!1,n;for(n in a)if(a.hasOwnProperty(n)){var i=a[n];if(i!=null)switch(n){case"src":e=!0;break;case"srcSet":u=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(o(137,t));default:vl(l,t,n,i,a,null)}}u&&vl(l,t,"srcSet",a.srcSet,a,null),e&&vl(l,t,"src",a.src,a,null);return;case"input":I("invalid",l);var c=n=i=u=null,f=null,h=null;for(e in a)if(a.hasOwnProperty(e)){var T=a[e];if(T!=null)switch(e){case"name":u=T;break;case"type":i=T;break;case"checked":f=T;break;case"defaultChecked":h=T;break;case"value":n=T;break;case"defaultValue":c=T;break;case"children":case"dangerouslySetInnerHTML":if(T!=null)throw Error(o(137,t));break;default:vl(l,t,e,T,a,null)}}Rf(l,n,c,f,h,i,u,!1);return;case"select":I("invalid",l),e=i=n=null;for(u in a)if(a.hasOwnProperty(u)&&(c=a[u],c!=null))switch(u){case"value":n=c;break;case"defaultValue":i=c;break;case"multiple":e=c;default:vl(l,t,u,c,a,null)}t=n,a=i,l.multiple=!!e,t!=null?ka(l,!!e,t,!1):a!=null&&ka(l,!!e,a,!0);return;case"textarea":I("invalid",l),n=u=e=null;for(i in a)if(a.hasOwnProperty(i)&&(c=a[i],c!=null))switch(i){case"value":e=c;break;case"defaultValue":u=c;break;case"children":n=c;break;case"dangerouslySetInnerHTML":if(c!=null)throw Error(o(91));break;default:vl(l,t,i,c,a,null)}qf(l,e,u,n);return;case"option":for(f in a)if(a.hasOwnProperty(f)&&(e=a[f],e!=null))switch(f){case"selected":l.selected=e&&typeof e!="function"&&typeof e!="symbol";break;default:vl(l,t,f,e,a,null)}return;case"dialog":I("beforetoggle",l),I("toggle",l),I("cancel",l),I("close",l);break;case"iframe":case"object":I("load",l);break;case"video":case"audio":for(e=0;e<mu.length;e++)I(mu[e],l);break;case"image":I("error",l),I("load",l);break;case"details":I("toggle",l);break;case"embed":case"source":case"link":I("error",l),I("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(h in a)if(a.hasOwnProperty(h)&&(e=a[h],e!=null))switch(h){case"children":case"dangerouslySetInnerHTML":throw Error(o(137,t));default:vl(l,t,h,e,a,null)}return;default:if(ei(t)){for(T in a)a.hasOwnProperty(T)&&(e=a[T],e!==void 0&&Vc(l,t,T,e,a,void 0));return}}for(c in a)a.hasOwnProperty(c)&&(e=a[c],e!=null&&vl(l,t,c,e,a,null))}function p0(l,t,a,e){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var u=null,n=null,i=null,c=null,f=null,h=null,T=null;for(b in a){var p=a[b];if(a.hasOwnProperty(b)&&p!=null)switch(b){case"checked":break;case"value":break;case"defaultValue":f=p;default:e.hasOwnProperty(b)||vl(l,t,b,null,e,p)}}for(var y in e){var b=e[y];if(p=a[y],e.hasOwnProperty(y)&&(b!=null||p!=null))switch(y){case"type":n=b;break;case"name":u=b;break;case"checked":h=b;break;case"defaultChecked":T=b;break;case"value":i=b;break;case"defaultValue":c=b;break;case"children":case"dangerouslySetInnerHTML":if(b!=null)throw Error(o(137,t));break;default:b!==p&&vl(l,t,y,b,e,p)}}ti(l,i,c,f,h,T,n,u);return;case"select":b=i=c=y=null;for(n in a)if(f=a[n],a.hasOwnProperty(n)&&f!=null)switch(n){case"value":break;case"multiple":b=f;default:e.hasOwnProperty(n)||vl(l,t,n,null,e,f)}for(u in e)if(n=e[u],f=a[u],e.hasOwnProperty(u)&&(n!=null||f!=null))switch(u){case"value":y=n;break;case"defaultValue":c=n;break;case"multiple":i=n;default:n!==f&&vl(l,t,u,n,e,f)}t=c,a=i,e=b,y!=null?ka(l,!!a,y,!1):!!e!=!!a&&(t!=null?ka(l,!!a,t,!0):ka(l,!!a,a?[]:"",!1));return;case"textarea":b=y=null;for(c in a)if(u=a[c],a.hasOwnProperty(c)&&u!=null&&!e.hasOwnProperty(c))switch(c){case"value":break;case"children":break;default:vl(l,t,c,null,e,u)}for(i in e)if(u=e[i],n=a[i],e.hasOwnProperty(i)&&(u!=null||n!=null))switch(i){case"value":y=u;break;case"defaultValue":b=u;break;case"children":break;case"dangerouslySetInnerHTML":if(u!=null)throw Error(o(91));break;default:u!==n&&vl(l,t,i,u,e,n)}Cf(l,y,b);return;case"option":for(var U in a)if(y=a[U],a.hasOwnProperty(U)&&y!=null&&!e.hasOwnProperty(U))switch(U){case"selected":l.selected=!1;break;default:vl(l,t,U,null,e,y)}for(f in e)if(y=e[f],b=a[f],e.hasOwnProperty(f)&&y!==b&&(y!=null||b!=null))switch(f){case"selected":l.selected=y&&typeof y!="function"&&typeof y!="symbol";break;default:vl(l,t,f,y,e,b)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var Q in a)y=a[Q],a.hasOwnProperty(Q)&&y!=null&&!e.hasOwnProperty(Q)&&vl(l,t,Q,null,e,y);for(h in e)if(y=e[h],b=a[h],e.hasOwnProperty(h)&&y!==b&&(y!=null||b!=null))switch(h){case"children":case"dangerouslySetInnerHTML":if(y!=null)throw Error(o(137,t));break;default:vl(l,t,h,y,e,b)}return;default:if(ei(t)){for(var hl in a)y=a[hl],a.hasOwnProperty(hl)&&y!==void 0&&!e.hasOwnProperty(hl)&&Vc(l,t,hl,void 0,e,y);for(T in e)y=e[T],b=a[T],!e.hasOwnProperty(T)||y===b||y===void 0&&b===void 0||Vc(l,t,T,y,e,b);return}}for(var m in a)y=a[m],a.hasOwnProperty(m)&&y!=null&&!e.hasOwnProperty(m)&&vl(l,t,m,null,e,y);for(p in e)y=e[p],b=a[p],!e.hasOwnProperty(p)||y===b||y==null&&b==null||vl(l,t,p,y,e,b)}function Xo(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function A0(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,a=performance.getEntriesByType("resource"),e=0;e<a.length;e++){var u=a[e],n=u.transferSize,i=u.initiatorType,c=u.duration;if(n&&c&&Xo(i)){for(i=0,c=u.responseEnd,e+=1;e<a.length;e++){var f=a[e],h=f.startTime;if(h>c)break;var T=f.transferSize,p=f.initiatorType;T&&Xo(p)&&(f=f.responseEnd,i+=T*(f<c?1:(c-h)/(f-h)))}if(--e,t+=8*(n+i)/(u.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var Lc=null,Kc=null;function Mn(l){return l.nodeType===9?l:l.ownerDocument}function Qo(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Zo(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function Jc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var wc=null;function O0(){var l=window.event;return l&&l.type==="popstate"?l===wc?!1:(wc=l,!0):(wc=null,!1)}var Vo=typeof setTimeout=="function"?setTimeout:void 0,_0=typeof clearTimeout=="function"?clearTimeout:void 0,Lo=typeof Promise=="function"?Promise:void 0,N0=typeof queueMicrotask=="function"?queueMicrotask:typeof Lo<"u"?function(l){return Lo.resolve(null).then(l).catch(M0)}:Vo;function M0(l){setTimeout(function(){throw l})}function ga(l){return l==="head"}function Ko(l,t){var a=t,e=0;do{var u=a.nextSibling;if(l.removeChild(a),u&&u.nodeType===8)if(a=u.data,a==="/$"||a==="/&"){if(e===0){l.removeChild(u),_e(t);return}e--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")e++;else if(a==="html")vu(l.ownerDocument.documentElement);else if(a==="head"){a=l.ownerDocument.head,vu(a);for(var n=a.firstChild;n;){var i=n.nextSibling,c=n.nodeName;n[Ue]||c==="SCRIPT"||c==="STYLE"||c==="LINK"&&n.rel.toLowerCase()==="stylesheet"||a.removeChild(n),n=i}}else a==="body"&&vu(l.ownerDocument.body);a=u}while(a);_e(t)}function Jo(l,t){var a=l;l=0;do{var e=a.nextSibling;if(a.nodeType===1?t?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(t?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),e&&e.nodeType===8)if(a=e.data,a==="/$"){if(l===0)break;l--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||l++;a=e}while(a)}function kc(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":kc(a),Pn(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}l.removeChild(a)}}function j0(l,t,a,e){for(;l.nodeType===1;){var u=a;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!e&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(e){if(!l[Ue])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==u.rel||l.getAttribute("href")!==(u.href==null||u.href===""?null:u.href)||l.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin)||l.getAttribute("title")!==(u.title==null?null:u.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(u.src==null?null:u.src)||l.getAttribute("type")!==(u.type==null?null:u.type)||l.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=u.name==null?null:""+u.name;if(u.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=Ot(l.nextSibling),l===null)break}return null}function x0(l,t,a){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!a||(l=Ot(l.nextSibling),l===null))return null;return l}function wo(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=Ot(l.nextSibling),l===null))return null;return l}function Wc(l){return l.data==="$?"||l.data==="$~"}function $c(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function D0(l,t){var a=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||a.readyState!=="loading")t();else{var e=function(){t(),a.removeEventListener("DOMContentLoaded",e)};a.addEventListener("DOMContentLoaded",e),l._reactRetry=e}}function Ot(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var Fc=null;function ko(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="/$"||a==="/&"){if(t===0)return Ot(l.nextSibling);t--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||t++}l=l.nextSibling}return null}function Wo(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(t===0)return l;t--}else a!=="/$"&&a!=="/&"||t++}l=l.previousSibling}return null}function $o(l,t,a){switch(t=Mn(a),l){case"html":if(l=t.documentElement,!l)throw Error(o(452));return l;case"head":if(l=t.head,!l)throw Error(o(453));return l;case"body":if(l=t.body,!l)throw Error(o(454));return l;default:throw Error(o(451))}}function vu(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);Pn(l)}var _t=new Map,Fo=new Set;function jn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Ft=j.d;j.d={f:U0,r:H0,D:R0,C:C0,L:q0,m:B0,X:G0,S:Y0,M:X0};function U0(){var l=Ft.f(),t=Tn();return l||t}function H0(l){var t=Ka(l);t!==null&&t.tag===5&&t.type==="form"?rd(t):Ft.r(l)}var pe=typeof document>"u"?null:document;function Io(l,t,a){var e=pe;if(e&&typeof t=="string"&&t){var u=St(t);u='link[rel="'+l+'"][href="'+u+'"]',typeof a=="string"&&(u+='[crossorigin="'+a+'"]'),Fo.has(u)||(Fo.add(u),l={rel:l,crossOrigin:a,href:t},e.querySelector(u)===null&&(t=e.createElement("link"),kl(t,"link",l),Ql(t),e.head.appendChild(t)))}}function R0(l){Ft.D(l),Io("dns-prefetch",l,null)}function C0(l,t){Ft.C(l,t),Io("preconnect",l,t)}function q0(l,t,a){Ft.L(l,t,a);var e=pe;if(e&&l&&t){var u='link[rel="preload"][as="'+St(t)+'"]';t==="image"&&a&&a.imageSrcSet?(u+='[imagesrcset="'+St(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(u+='[imagesizes="'+St(a.imageSizes)+'"]')):u+='[href="'+St(l)+'"]';var n=u;switch(t){case"style":n=Ae(l);break;case"script":n=Oe(l)}_t.has(n)||(l=H({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:l,as:t},a),_t.set(n,l),e.querySelector(u)!==null||t==="style"&&e.querySelector(hu(n))||t==="script"&&e.querySelector(yu(n))||(t=e.createElement("link"),kl(t,"link",l),Ql(t),e.head.appendChild(t)))}}function B0(l,t){Ft.m(l,t);var a=pe;if(a&&l){var e=t&&typeof t.as=="string"?t.as:"script",u='link[rel="modulepreload"][as="'+St(e)+'"][href="'+St(l)+'"]',n=u;switch(e){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Oe(l)}if(!_t.has(n)&&(l=H({rel:"modulepreload",href:l},t),_t.set(n,l),a.querySelector(u)===null)){switch(e){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(yu(n)))return}e=a.createElement("link"),kl(e,"link",l),Ql(e),a.head.appendChild(e)}}}function Y0(l,t,a){Ft.S(l,t,a);var e=pe;if(e&&l){var u=Ja(e).hoistableStyles,n=Ae(l);t=t||"default";var i=u.get(n);if(!i){var c={loading:0,preload:null};if(i=e.querySelector(hu(n)))c.loading=5;else{l=H({rel:"stylesheet",href:l,"data-precedence":t},a),(a=_t.get(n))&&Ic(l,a);var f=i=e.createElement("link");Ql(f),kl(f,"link",l),f._p=new Promise(function(h,T){f.onload=h,f.onerror=T}),f.addEventListener("load",function(){c.loading|=1}),f.addEventListener("error",function(){c.loading|=2}),c.loading|=4,xn(i,t,e)}i={type:"stylesheet",instance:i,count:1,state:c},u.set(n,i)}}}function G0(l,t){Ft.X(l,t);var a=pe;if(a&&l){var e=Ja(a).hoistableScripts,u=Oe(l),n=e.get(u);n||(n=a.querySelector(yu(u)),n||(l=H({src:l,async:!0},t),(t=_t.get(u))&&Pc(l,t),n=a.createElement("script"),Ql(n),kl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},e.set(u,n))}}function X0(l,t){Ft.M(l,t);var a=pe;if(a&&l){var e=Ja(a).hoistableScripts,u=Oe(l),n=e.get(u);n||(n=a.querySelector(yu(u)),n||(l=H({src:l,async:!0,type:"module"},t),(t=_t.get(u))&&Pc(l,t),n=a.createElement("script"),Ql(n),kl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},e.set(u,n))}}function Po(l,t,a,e){var u=(u=$.current)?jn(u):null;if(!u)throw Error(o(446));switch(l){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=Ae(a.href),a=Ja(u).hoistableStyles,e=a.get(t),e||(e={type:"style",instance:null,count:0,state:null},a.set(t,e)),e):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){l=Ae(a.href);var n=Ja(u).hoistableStyles,i=n.get(l);if(i||(u=u.ownerDocument||u,i={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,i),(n=u.querySelector(hu(l)))&&!n._p&&(i.instance=n,i.state.loading=5),_t.has(l)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},_t.set(l,a),n||Q0(u,l,a,i.state))),t&&e===null)throw Error(o(528,""));return i}if(t&&e!==null)throw Error(o(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Oe(a),a=Ja(u).hoistableScripts,e=a.get(t),e||(e={type:"script",instance:null,count:0,state:null},a.set(t,e)),e):{type:"void",instance:null,count:0,state:null};default:throw Error(o(444,l))}}function Ae(l){return'href="'+St(l)+'"'}function hu(l){return'link[rel="stylesheet"]['+l+"]"}function lm(l){return H({},l,{"data-precedence":l.precedence,precedence:null})}function Q0(l,t,a,e){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?e.loading=1:(t=l.createElement("link"),e.preload=t,t.addEventListener("load",function(){return e.loading|=1}),t.addEventListener("error",function(){return e.loading|=2}),kl(t,"link",a),Ql(t),l.head.appendChild(t))}function Oe(l){return'[src="'+St(l)+'"]'}function yu(l){return"script[async]"+l}function tm(l,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var e=l.querySelector('style[data-href~="'+St(a.href)+'"]');if(e)return t.instance=e,Ql(e),e;var u=H({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return e=(l.ownerDocument||l).createElement("style"),Ql(e),kl(e,"style",u),xn(e,a.precedence,l),t.instance=e;case"stylesheet":u=Ae(a.href);var n=l.querySelector(hu(u));if(n)return t.state.loading|=4,t.instance=n,Ql(n),n;e=lm(a),(u=_t.get(u))&&Ic(e,u),n=(l.ownerDocument||l).createElement("link"),Ql(n);var i=n;return i._p=new Promise(function(c,f){i.onload=c,i.onerror=f}),kl(n,"link",e),t.state.loading|=4,xn(n,a.precedence,l),t.instance=n;case"script":return n=Oe(a.src),(u=l.querySelector(yu(n)))?(t.instance=u,Ql(u),u):(e=a,(u=_t.get(n))&&(e=H({},a),Pc(e,u)),l=l.ownerDocument||l,u=l.createElement("script"),Ql(u),kl(u,"link",e),l.head.appendChild(u),t.instance=u);case"void":return null;default:throw Error(o(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(e=t.instance,t.state.loading|=4,xn(e,a.precedence,l));return t.instance}function xn(l,t,a){for(var e=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),u=e.length?e[e.length-1]:null,n=u,i=0;i<e.length;i++){var c=e[i];if(c.dataset.precedence===t)n=c;else if(n!==u)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(l,t.firstChild))}function Ic(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function Pc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Dn=null;function am(l,t,a){if(Dn===null){var e=new Map,u=Dn=new Map;u.set(a,e)}else u=Dn,e=u.get(a),e||(e=new Map,u.set(a,e));if(e.has(l))return e;for(e.set(l,null),a=a.getElementsByTagName(l),u=0;u<a.length;u++){var n=a[u];if(!(n[Ue]||n[Ll]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var i=n.getAttribute(t)||"";i=l+i;var c=e.get(i);c?c.push(n):e.set(i,[n])}}return e}function em(l,t,a){l=l.ownerDocument||l,l.head.insertBefore(a,t==="title"?l.querySelector("head > title"):null)}function Z0(l,t,a){if(a===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function um(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function V0(l,t,a,e){if(a.type==="stylesheet"&&(typeof e.media!="string"||matchMedia(e.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var u=Ae(e.href),n=t.querySelector(hu(u));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Un.bind(l),t.then(l,l)),a.state.loading|=4,a.instance=n,Ql(n);return}n=t.ownerDocument||t,e=lm(e),(u=_t.get(u))&&Ic(e,u),n=n.createElement("link"),Ql(n);var i=n;i._p=new Promise(function(c,f){i.onload=c,i.onerror=f}),kl(n,"link",e),a.instance=n}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(a,t),(t=a.state.preload)&&(a.state.loading&3)===0&&(l.count++,a=Un.bind(l),t.addEventListener("load",a),t.addEventListener("error",a))}}var lf=0;function L0(l,t){return l.stylesheets&&l.count===0&&Rn(l,l.stylesheets),0<l.count||0<l.imgCount?function(a){var e=setTimeout(function(){if(l.stylesheets&&Rn(l,l.stylesheets),l.unsuspend){var n=l.unsuspend;l.unsuspend=null,n()}},6e4+t);0<l.imgBytes&&lf===0&&(lf=62500*A0());var u=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&Rn(l,l.stylesheets),l.unsuspend)){var n=l.unsuspend;l.unsuspend=null,n()}},(l.imgBytes>lf?50:800)+t);return l.unsuspend=a,function(){l.unsuspend=null,clearTimeout(e),clearTimeout(u)}}:null}function Un(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Rn(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Hn=null;function Rn(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Hn=new Map,t.forEach(K0,l),Hn=null,Un.call(l))}function K0(l,t){if(!(t.state.loading&4)){var a=Hn.get(l);if(a)var e=a.get(null);else{a=new Map,Hn.set(l,a);for(var u=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<u.length;n++){var i=u[n];(i.nodeName==="LINK"||i.getAttribute("media")!=="not all")&&(a.set(i.dataset.precedence,i),e=i)}e&&a.set(null,e)}u=t.instance,i=u.getAttribute("data-precedence"),n=a.get(i)||e,n===e&&a.set(null,u),a.set(i,u),this.count++,e=Un.bind(this),u.addEventListener("load",e),u.addEventListener("error",e),n?n.parentNode.insertBefore(u,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(u,l.firstChild)),t.state.loading|=4}}var gu={$$typeof:J,Provider:null,Consumer:null,_currentValue:V,_currentValue2:V,_threadCount:0};function J0(l,t,a,e,u,n,i,c,f){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Wn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Wn(0),this.hiddenUpdates=Wn(null),this.identifierPrefix=e,this.onUncaughtError=u,this.onCaughtError=n,this.onRecoverableError=i,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=f,this.incompleteTransitions=new Map}function nm(l,t,a,e,u,n,i,c,f,h,T,p){return l=new J0(l,t,a,i,f,h,T,p,c),t=1,n===!0&&(t|=24),n=dt(3,null,null,t),l.current=n,n.stateNode=l,t=Hi(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:e,isDehydrated:a,cache:t},Bi(n),l}function im(l){return l?(l=ae,l):ae}function cm(l,t,a,e,u,n){u=im(u),e.context===null?e.context=u:e.pendingContext=u,e=ia(t),e.payload={element:a},n=n===void 0?null:n,n!==null&&(e.callback=n),a=ca(l,e,t),a!==null&&(nt(a,l,t),We(a,l,t))}function fm(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var a=l.retryLane;l.retryLane=a!==0&&a<t?a:t}}function tf(l,t){fm(l,t),(l=l.alternate)&&fm(l,t)}function sm(l){if(l.tag===13||l.tag===31){var t=ja(l,67108864);t!==null&&nt(t,l,67108864),tf(l,67108864)}}function dm(l){if(l.tag===13||l.tag===31){var t=ht();t=$n(t);var a=ja(l,t);a!==null&&nt(a,l,t),tf(l,t)}}var Cn=!0;function w0(l,t,a,e){var u=z.T;z.T=null;var n=j.p;try{j.p=2,af(l,t,a,e)}finally{j.p=n,z.T=u}}function k0(l,t,a,e){var u=z.T;z.T=null;var n=j.p;try{j.p=8,af(l,t,a,e)}finally{j.p=n,z.T=u}}function af(l,t,a,e){if(Cn){var u=ef(e);if(u===null)Zc(l,t,e,qn,a),mm(l,e);else if($0(u,l,t,a,e))e.stopPropagation();else if(mm(l,e),t&4&&-1<W0.indexOf(l)){for(;u!==null;){var n=Ka(u);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var i=Aa(n.pendingLanes);if(i!==0){var c=n;for(c.pendingLanes|=2,c.entangledLanes|=2;i;){var f=1<<31-ft(i);c.entanglements[1]|=f,i&=~f}Ht(n),(fl&6)===0&&(Sn=it()+500,ou(0))}}break;case 31:case 13:c=ja(n,2),c!==null&&nt(c,n,2),Tn(),tf(n,2)}if(n=ef(e),n===null&&Zc(l,t,e,qn,a),n===u)break;u=n}u!==null&&e.stopPropagation()}else Zc(l,t,e,null,a)}}function ef(l){return l=ni(l),uf(l)}var qn=null;function uf(l){if(qn=null,l=La(l),l!==null){var t=C(l);if(t===null)l=null;else{var a=t.tag;if(a===13){if(l=G(t),l!==null)return l;l=null}else if(a===31){if(l=P(t),l!==null)return l;l=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return qn=l,null}function om(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Rm()){case Sf:return 2;case bf:return 8;case Au:case Cm:return 32;case Tf:return 268435456;default:return 32}default:return 32}}var nf=!1,Sa=null,ba=null,Ta=null,Su=new Map,bu=new Map,za=[],W0="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function mm(l,t){switch(l){case"focusin":case"focusout":Sa=null;break;case"dragenter":case"dragleave":ba=null;break;case"mouseover":case"mouseout":Ta=null;break;case"pointerover":case"pointerout":Su.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":bu.delete(t.pointerId)}}function Tu(l,t,a,e,u,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:a,eventSystemFlags:e,nativeEvent:n,targetContainers:[u]},t!==null&&(t=Ka(t),t!==null&&sm(t)),l):(l.eventSystemFlags|=e,t=l.targetContainers,u!==null&&t.indexOf(u)===-1&&t.push(u),l)}function $0(l,t,a,e,u){switch(t){case"focusin":return Sa=Tu(Sa,l,t,a,e,u),!0;case"dragenter":return ba=Tu(ba,l,t,a,e,u),!0;case"mouseover":return Ta=Tu(Ta,l,t,a,e,u),!0;case"pointerover":var n=u.pointerId;return Su.set(n,Tu(Su.get(n)||null,l,t,a,e,u)),!0;case"gotpointercapture":return n=u.pointerId,bu.set(n,Tu(bu.get(n)||null,l,t,a,e,u)),!0}return!1}function rm(l){var t=La(l.target);if(t!==null){var a=C(t);if(a!==null){if(t=a.tag,t===13){if(t=G(a),t!==null){l.blockedOn=t,_f(l.priority,function(){dm(a)});return}}else if(t===31){if(t=P(a),t!==null){l.blockedOn=t,_f(l.priority,function(){dm(a)});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){l.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Bn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var a=ef(l.nativeEvent);if(a===null){a=l.nativeEvent;var e=new a.constructor(a.type,a);ui=e,a.target.dispatchEvent(e),ui=null}else return t=Ka(a),t!==null&&sm(t),l.blockedOn=a,!1;t.shift()}return!0}function vm(l,t,a){Bn(l)&&a.delete(t)}function F0(){nf=!1,Sa!==null&&Bn(Sa)&&(Sa=null),ba!==null&&Bn(ba)&&(ba=null),Ta!==null&&Bn(Ta)&&(Ta=null),Su.forEach(vm),bu.forEach(vm)}function Yn(l,t){l.blockedOn===t&&(l.blockedOn=null,nf||(nf=!0,S.unstable_scheduleCallback(S.unstable_NormalPriority,F0)))}var Gn=null;function hm(l){Gn!==l&&(Gn=l,S.unstable_scheduleCallback(S.unstable_NormalPriority,function(){Gn===l&&(Gn=null);for(var t=0;t<l.length;t+=3){var a=l[t],e=l[t+1],u=l[t+2];if(typeof e!="function"){if(uf(e||a)===null)continue;break}var n=Ka(a);n!==null&&(l.splice(t,3),t-=3,ec(n,{pending:!0,data:u,method:a.method,action:e},e,u))}}))}function _e(l){function t(f){return Yn(f,l)}Sa!==null&&Yn(Sa,l),ba!==null&&Yn(ba,l),Ta!==null&&Yn(Ta,l),Su.forEach(t),bu.forEach(t);for(var a=0;a<za.length;a++){var e=za[a];e.blockedOn===l&&(e.blockedOn=null)}for(;0<za.length&&(a=za[0],a.blockedOn===null);)rm(a),a.blockedOn===null&&za.shift();if(a=(l.ownerDocument||l).$$reactFormReplay,a!=null)for(e=0;e<a.length;e+=3){var u=a[e],n=a[e+1],i=u[Pl]||null;if(typeof n=="function")i||hm(a);else if(i){var c=null;if(n&&n.hasAttribute("formAction")){if(u=n,i=n[Pl]||null)c=i.formAction;else if(uf(u)!==null)continue}else c=i.action;typeof c=="function"?a[e+1]=c:(a.splice(e,3),e-=3),hm(a)}}}function ym(){function l(n){n.canIntercept&&n.info==="react-transition"&&n.intercept({handler:function(){return new Promise(function(i){return u=i})},focusReset:"manual",scroll:"manual"})}function t(){u!==null&&(u(),u=null),e||setTimeout(a,20)}function a(){if(!e&&!navigation.transition){var n=navigation.currentEntry;n&&n.url!=null&&navigation.navigate(n.url,{state:n.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var e=!1,u=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(a,100),function(){e=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),u!==null&&(u(),u=null)}}}function cf(l){this._internalRoot=l}Xn.prototype.render=cf.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(o(409));var a=t.current,e=ht();cm(a,e,l,t,null,null)},Xn.prototype.unmount=cf.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;cm(l.current,2,null,l,null,null),Tn(),t[Va]=null}};function Xn(l){this._internalRoot=l}Xn.prototype.unstable_scheduleHydration=function(l){if(l){var t=Of();l={blockedOn:null,target:l,priority:t};for(var a=0;a<za.length&&t!==0&&t<za[a].priority;a++);za.splice(a,0,l),a===0&&rm(l)}};var gm=N.version;if(gm!=="19.2.4")throw Error(o(527,gm,"19.2.4"));j.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(o(188)):(l=Object.keys(l).join(","),Error(o(268,l)));return l=g(t),l=l!==null?Y(l):null,l=l===null?null:l.stateNode,l};var I0={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:z,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Qn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Qn.isDisabled&&Qn.supportsFiber)try{je=Qn.inject(I0),ct=Qn}catch{}}return Eu.createRoot=function(l,t){if(!_(l))throw Error(o(299));var a=!1,e="",u=pd,n=Ad,i=Od;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(e=t.identifierPrefix),t.onUncaughtError!==void 0&&(u=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(i=t.onRecoverableError)),t=nm(l,1,!1,null,null,a,e,null,u,n,i,ym),l[Va]=t.current,Qc(l),new cf(t)},Eu.hydrateRoot=function(l,t,a){if(!_(l))throw Error(o(299));var e=!1,u="",n=pd,i=Ad,c=Od,f=null;return a!=null&&(a.unstable_strictMode===!0&&(e=!0),a.identifierPrefix!==void 0&&(u=a.identifierPrefix),a.onUncaughtError!==void 0&&(n=a.onUncaughtError),a.onCaughtError!==void 0&&(i=a.onCaughtError),a.onRecoverableError!==void 0&&(c=a.onRecoverableError),a.formState!==void 0&&(f=a.formState)),t=nm(l,1,!0,t,a??null,e,u,f,n,i,c,ym),t.context=im(null),a=t.current,e=ht(),e=$n(e),u=ia(e),u.callback=null,ca(a,u,e),a=e,t.current.lanes=a,De(t,a),Ht(t),l[Va]=t.current,Qc(l),new Xn(t)},Eu.version="19.2.4",Eu}var Nm;function fv(){if(Nm)return df.exports;Nm=1;function S(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(S)}catch(N){console.error(N)}}return S(),df.exports=cv(),df.exports}var sv=fv();function dv({card:S,error:N}){if(N)return r.jsxs("div",{className:"panel-left",children:[r.jsx("h2",{children:"Agent Information"}),r.jsxs("div",{className:"error-banner",children:[r.jsx("p",{children:"Failed to load agent card"}),r.jsx("p",{style:{fontSize:12,color:"var(--text-dim)"},children:N}),r.jsx("button",{className:"btn btn-secondary",onClick:()=>location.reload(),children:"Retry"})]})]});if(!S)return r.jsxs("div",{className:"panel-left",children:[r.jsx("h2",{children:"Agent Information"}),r.jsx("p",{style:{color:"var(--text-dim)"},children:"Loading agent card..."})]});const O=S.preferredTransport==="jsonrpc"?"JSON-RPC":"HTTP+JSON",o=S.capabilities?.streaming,_=S.capabilities?.stateTransitionHistory,C=S.defaultInputModes||[],G=S.defaultOutputModes||[],P=S.skills||[];return r.jsxs("div",{className:"panel-left",children:[r.jsx("h2",{children:"Agent Information"}),r.jsxs("div",{className:"info-group",children:[r.jsx(Ne,{label:"Name",value:S.name}),r.jsx(Ne,{label:"Description",value:S.description||"—"}),r.jsx(Ne,{label:"Version",value:S.version||"—"}),r.jsx(Ne,{label:"Protocol",value:O}),r.jsx(Ne,{label:"A2A Version",value:S.protocolVersion||"—"}),r.jsx(Ne,{label:"URL",value:S.url||"—",mono:!0}),r.jsxs("div",{className:"info-row",children:[r.jsx("span",{className:"info-label",children:"Streaming"}),r.jsx("span",{className:"info-value",children:o?r.jsx("span",{className:"check",children:"✓"}):r.jsx("span",{className:"cross",children:"✗"})})]}),r.jsxs("div",{className:"info-row",children:[r.jsx("span",{className:"info-label",children:"State History"}),r.jsx("span",{className:"info-value",children:_?r.jsx("span",{className:"check",children:"✓"}):r.jsx("span",{className:"cross",children:"✗"})})]})]}),(C.length>0||G.length>0)&&r.jsxs(r.Fragment,{children:[r.jsx("h2",{style:{marginTop:8},children:"Modes"}),r.jsxs("div",{className:"info-group",children:[C.length>0&&r.jsxs("div",{className:"info-row",style:{flexDirection:"column"},children:[r.jsx("span",{className:"info-label",children:"Input"}),r.jsx("div",{style:{marginTop:4},children:C.map(M=>r.jsx("span",{className:"mode-tag",children:M},M))})]}),G.length>0&&r.jsxs("div",{className:"info-row",style:{flexDirection:"column"},children:[r.jsx("span",{className:"info-label",children:"Output"}),r.jsx("div",{style:{marginTop:4},children:G.map(M=>r.jsx("span",{className:"mode-tag",children:M},M))})]})]})]}),r.jsx("h2",{style:{marginTop:8},children:"Skills"}),P.length===0?r.jsx("p",{style:{color:"var(--text-dim)",fontSize:13},children:"(none)"}):P.map((M,g)=>r.jsxs("div",{className:"skill-item",children:[r.jsx("div",{className:"skill-name",children:M.name||M.id||"Unnamed"}),M.description&&r.jsx("div",{className:"skill-desc",children:M.description})]},g))]})}function Ne({label:S,value:N,mono:O}){return r.jsxs("div",{className:"info-row",children:[r.jsx("span",{className:"info-label",children:S}),r.jsx("span",{className:`info-value${O?" mono":""}`,children:N})]})}function hf(S){return S.preferredTransport==="jsonrpc"}function ov(S){return!!(S.capabilities&&S.capabilities.streaming)}function Za(S){let N="";for(const O of S)O.kind==="text"&&O.text?N+=(N?`
`:"")+O.text:O.kind==="data"&&(N+=(N?`
`:"")+JSON.stringify(O.data,null,2));return N}function Mm(S){if(!S)return"";const N=S.artifacts||[];let O="";for(const o of N)for(const _ of o.parts||[])_.kind==="text"&&_.text?O+=(O?`
`:"")+_.text:_.kind==="data"&&(O+=(O?`
`:"")+JSON.stringify(_.data,null,2));return O||(S.status?.message?Za(S.status.message.parts||[]):"")}function mv(S){const N=S.status;return N?.message?Za(N.message.parts||[]):N?.state?N.state:""}function rv(S){const O=(S.artifact||S).parts||[];let o="";for(const _ of O)_.kind==="text"&&_.text?o+=_.text:_.kind==="data"&&(o+=JSON.stringify(_.data));return o}async function vv({agentUrl:S,jsonRpc:N,params:O}){let o,_;N?(o=S,_=JSON.stringify({jsonrpc:"2.0",id:crypto.randomUUID(),method:"message/send",params:O})):(o=S+"/message:send",_=JSON.stringify(O));const C=await fetch(o,{method:"POST",headers:{"Content-Type":"application/json"},body:_});if(!C.ok){const P=await C.text().catch(()=>"");throw new Error("HTTP "+C.status+(P?": "+P:""))}let G=await C.json();if(N){if(G.error)throw new Error("JSON-RPC error "+G.error.code+": "+G.error.message);G=G.result}return G}async function hv({agentUrl:S,jsonRpc:N,params:O},o){let _,C;N?(_=S,C=JSON.stringify({jsonrpc:"2.0",id:crypto.randomUUID(),method:"message/sendStream",params:O})):(_=S+"/message:stream",C=JSON.stringify(O));const G=await fetch(_,{method:"POST",headers:{"Content-Type":"application/json",Accept:"text/event-stream"},body:C});if(!G.ok){const X=await G.text().catch(()=>"");throw new Error("HTTP "+G.status+(X?": "+X:""))}const P=G.body.getReader(),M=new TextDecoder;let g="",Y="",H="";for(;;){const{done:X,value:Tl}=await P.read();if(X)break;g+=M.decode(Tl,{stream:!0});const Nl=g.split(`
`);g=Nl.pop()||"";for(const zl of Nl)if(zl.startsWith("event:"))Y=zl.slice(6).trim();else if(zl.startsWith("data:"))H=zl.slice(5).trim();else if(zl===""&&H){try{let nl=JSON.parse(H);if(N&&nl.jsonrpc){if(nl.error){o.onError("JSON-RPC error "+nl.error.code+": "+nl.error.message),H="",Y="";continue}nl=nl.result}const Al=Y||nl.kind||"";if(Al==="status-update"){const Ul=mv(nl),J=nl.status?.state||"";Ul&&o.onStatus(Ul,J)}else if(Al==="artifact-update"){const Ul=rv(nl),J=nl.status?.state||"";Ul&&o.onArtifactChunk(Ul,J)}else if(Al==="task")o.onTask(nl);else if(Al==="message"){const Ul=Za(nl.parts||[]);Ul&&o.onMessage(Ul)}}catch{}H="",Y=""}}}async function yv(S){const N=S.url||"";if(hf(S)){const O=await fetch(N,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({jsonrpc:"2.0",id:crypto.randomUUID(),method:"tasks/list",params:{}})});if(!O.ok)throw new Error("HTTP "+O.status);const o=await O.json();if(o.error)throw new Error("JSON-RPC "+o.error.code+": "+o.error.message);return o.result?.tasks||o.result||[]}else{const O=await fetch(N+"/tasks",{headers:{"Content-Type":"application/json"}});if(!O.ok)throw new Error("HTTP "+O.status);const o=await O.json();return o.tasks||o||[]}}async function gv(S,N){const O=S.url||"";if(hf(S)){const o=await fetch(O,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({jsonrpc:"2.0",id:crypto.randomUUID(),method:"tasks/get",params:{id:N,historyLength:100}})});if(!o.ok)throw new Error("HTTP "+o.status);const _=await o.json();if(_.error)throw new Error("JSON-RPC "+_.error.code+": "+_.error.message);return _.result}else{const o=await fetch(O+"/tasks/"+encodeURIComponent(N)+"?historyLength=100",{headers:{"Content-Type":"application/json"}});if(!o.ok)throw new Error("HTTP "+o.status);return await o.json()}}const Sv={submitted:"state-submitted",working:"state-working",completed:"state-completed",failed:"state-failed",canceled:"state-canceled",rejected:"state-rejected","input-required":"state-input-required","auth-required":"state-auth-required"};function Zn({state:S}){if(!S)return null;const N=Sv[S]||"state-submitted";return r.jsx("span",{className:`state-badge ${N}`,children:S})}function bv({card:S}){const[N,O]=el.useState([]),[o,_]=el.useState(""),[C,G]=el.useState(!1),P=el.useRef(null),M=el.useRef(null),g=el.useRef(null),Y=el.useRef(null),H=el.useCallback(()=>{P.current?.scrollIntoView({behavior:"instant"})},[]);el.useEffect(()=>{H()},[N,H]);const X=el.useCallback((x,L,Z)=>{const ul={id:crypto.randomUUID(),type:x,text:L,state:Z};return O(Sl=>[...Sl,ul]),ul.id},[]),Tl=el.useCallback(x=>{if(!x)return;const L=x.status?.state;L==="input-required"||L==="auth-required"?(x.id&&(g.current=x.id),x.contextId&&(Y.current=x.contextId)):L==="completed"||L==="failed"||L==="canceled"||L==="rejected"?(g.current=null,Y.current=null):(x.id&&(g.current=x.id),x.contextId&&(Y.current=x.contextId))},[]),Nl=el.useCallback(async()=>{const x=o.trim();if(!x||C||!S)return;X("user",x),_(""),G(!0);const L=hf(S),Z=ov(S),ul=S.url||"",Sl={role:"user",messageId:crypto.randomUUID(),parts:[{kind:"text",text:x}]};g.current&&(Sl.taskId=g.current),Y.current&&(Sl.contextId=Y.current);const Ml={message:Sl};Z||(Ml.configuration={blocking:!0});try{Z?await Al(ul,Ml,L):await zl(ul,Ml,L)}catch(bl){X("error","Error: "+(bl instanceof Error?bl.message:String(bl)))}G(!1)},[o,C,S,X,Tl]),zl=el.useCallback(async(x,L,Z)=>{X("status","Thinking...");const ul=await vv({agentUrl:x,jsonRpc:Z,params:L});O(Sl=>Sl.filter(Ml=>!(Ml.type==="status"&&Ml.text==="Thinking..."))),nl(ul)},[X,Tl]),nl=el.useCallback(x=>{if(!x)return;if(x.kind==="message"||!x.id&&x.parts){const ul=Za(x.parts||[]);ul&&X("agent",ul,"completed");return}Tl(x);const L=x.status?.state||"completed";if(x.status?.message){const ul=Za(x.status.message.parts||[]);if(L==="input-required"||L==="auth-required"){X("agent",ul||L,L);return}}const Z=Mm(x);if(Z)X("agent",Z,L);else if(x.status){const ul=Za(x.status.message?.parts||[]);X("agent",ul||"(Task "+L+")",L)}},[X,Tl]),Al=el.useCallback(async(x,L,Z)=>{let ul="",Sl=null,Ml="";await hv({agentUrl:x,jsonRpc:Z,params:L},{onStatus(bl,jl){Ml=jl||Ml,X("status",bl)},onArtifactChunk(bl,jl){Ml=jl||Ml,ul+=bl;const yt=ul,Il=Ml;if(!Sl)Sl=X("agent",yt,Il);else{const Vl=Sl;O(z=>z.map(j=>j.id===Vl?{...j,text:yt,state:Il}:j))}},onTask(bl){if(Tl(bl),Ml=bl.status?.state||Ml,ul){if(Sl){const jl=Sl,yt=Ml;O(Il=>Il.map(Vl=>Vl.id===jl?{...Vl,state:yt}:Vl))}}else{const jl=Mm(bl);jl&&(Sl=X("agent",jl,Ml))}},onMessage(bl){X("agent",bl,"completed")},onError(bl){X("error",bl)}}),!Sl&&!ul&&X("status","Stream completed (no text content)")},[X,Tl]),Ul=el.useCallback(x=>{x.key==="Enter"&&!x.shiftKey&&(x.preventDefault(),Nl())},[Nl]),J=el.useCallback(()=>{g.current=null,Y.current=null,O([])},[]),Ol=el.useCallback(()=>{const x=M.current;x&&(x.style.height="auto",x.style.height=Math.min(x.scrollHeight,120)+"px")},[]);return r.jsxs(r.Fragment,{children:[r.jsxs("div",{className:"chat-header",children:[r.jsx("h2",{children:"Chat"}),r.jsx("button",{className:"btn btn-secondary",onClick:J,title:"Clear conversation and start fresh",children:"New Conversation"})]}),r.jsxs("div",{className:"chat-messages",children:[N.length===0&&r.jsx("div",{className:"empty-state",children:"Send a message to start chatting with the agent."}),N.map(x=>x.type==="user"?r.jsxs("div",{className:"msg msg-user",children:[r.jsx("div",{className:"msg-label",children:"You"}),x.text]},x.id):x.type==="agent"?r.jsxs("div",{className:"msg msg-agent",children:[r.jsxs("div",{className:"msg-label",children:["Agent ",x.state&&r.jsx(Zn,{state:x.state})]}),x.text]},x.id):x.type==="status"?r.jsx("div",{className:"msg msg-status",children:x.text},x.id):x.type==="error"?r.jsx("div",{className:"msg msg-error",children:x.text},x.id):null),C&&r.jsxs("div",{className:"loading",children:[r.jsxs("div",{className:"dot-pulse",children:[r.jsx("span",{}),r.jsx("span",{}),r.jsx("span",{})]}),r.jsx("span",{children:"Thinking..."})]}),r.jsx("div",{ref:P})]}),r.jsxs("div",{className:"chat-input-area",children:[r.jsx("textarea",{ref:M,value:o,onChange:x=>{_(x.target.value),Ol()},onKeyDown:Ul,placeholder:"Type a message...",rows:1,disabled:C}),r.jsx("button",{className:"btn btn-primary",onClick:Nl,disabled:C||!S,children:"Send"})]})]})}function jm({parts:S}){return r.jsx(r.Fragment,{children:S.map((N,O)=>N.kind==="text"&&N.text?r.jsx("div",{className:"artifact-text",children:N.text},O):N.kind==="data"?r.jsx("pre",{className:"json-block",children:JSON.stringify(N.data,null,2)},O):N.kind==="file"?r.jsxs("div",{style:{color:"var(--text-dim)",fontSize:12},children:["[file: ",N.filename||N.mediaType||"binary","]"]},O):null)})}const Tv=[{label:"0.5s",value:500},{label:"1s",value:1e3},{label:"2s",value:2e3},{label:"5s",value:5e3},{label:"10s",value:1e4},{label:"30s",value:3e4}];function xm(S){try{return new Date(S).toLocaleTimeString(void 0,{hour:"2-digit",minute:"2-digit",second:"2-digit"})}catch{return S}}function zv({card:S,active:N,pollInterval:O,onPollIntervalChange:o}){const[_,C]=el.useState([]),[G,P]=el.useState(null),[M,g]=el.useState(null),[Y,H]=el.useState(null),[X,Tl]=el.useState(!0),[Nl,zl]=el.useState(!0),nl=el.useRef(null),Al=el.useCallback(async()=>{if(S)try{const J=await yv(S);J.sort((Ol,x)=>{const L=Ol.status?.timestamp||"";return(x.status?.timestamp||"").localeCompare(L)}),C(J),zl(J.length===0),Tl(!0)}catch{Tl(!1)}},[S]);el.useEffect(()=>{if(!N){nl.current&&(clearInterval(nl.current),nl.current=null);return}return Al(),nl.current=setInterval(Al,O),()=>{nl.current&&clearInterval(nl.current)}},[N,Al,O]);const Ul=el.useCallback(async J=>{if(G===J){P(null),g(null),H(null);return}if(P(J),g(null),H(null),!!S)try{const Ol=await gv(S,J);g(Ol)}catch(Ol){H(Ol instanceof Error?Ol.message:String(Ol))}},[S,G]);return r.jsxs(r.Fragment,{children:[r.jsxs("div",{className:"tasks-header",children:[r.jsx("h2",{children:"Tasks"}),r.jsxs("div",{className:"tasks-status",children:[r.jsx("span",{className:`poll-dot${X?"":" stale"}`}),"polling:",r.jsx("select",{className:"poll-select",value:O,onChange:J=>o(Number(J.target.value)),children:Tv.map(J=>r.jsx("option",{value:J.value,children:J.label},J.value))})]})]}),r.jsx("div",{className:"tasks-content",children:Nl?r.jsx("div",{className:"empty-state",children:"No tasks yet."}):r.jsxs("table",{className:"task-table",children:[r.jsx("thead",{children:r.jsxs("tr",{children:[r.jsx("th",{children:"Task ID"}),r.jsx("th",{children:"State"}),r.jsx("th",{children:"Context"}),r.jsx("th",{children:"Timestamp"})]})}),r.jsx("tbody",{children:_.map(J=>{const Ol=J.status?.state||"unknown",x=J.status?.timestamp||"",L=G===J.id;return r.jsx(Ev,{task:J,state:Ol,ts:x,isExpanded:L,detail:L?M:null,detailError:L?Y:null,onClick:()=>Ul(J.id)},J.id)})})]})})]})}function Ev({task:S,state:N,ts:O,isExpanded:o,detail:_,detailError:C,onClick:G}){const P=(S.id||"").substring(0,8),M=(S.contextId||"").substring(0,12),g=O?xm(O):"—";return r.jsxs(r.Fragment,{children:[r.jsxs("tr",{className:"task-row",onClick:G,children:[r.jsx("td",{children:r.jsx("span",{className:"task-id",children:P})}),r.jsx("td",{children:r.jsx(Zn,{state:N})}),r.jsx("td",{children:r.jsx("span",{className:"task-ctx",children:M||"—"})}),r.jsx("td",{children:r.jsx("span",{className:"task-time",children:g})})]}),o&&r.jsx("tr",{children:r.jsx("td",{colSpan:4,className:"task-detail",children:C?r.jsxs("div",{className:"task-error",children:["Failed to load task: ",C]}):_?r.jsx(pv,{task:_}):r.jsx("div",{style:{color:"var(--text-dim)",fontSize:13},children:"Loading task details..."})})})]})}function pv({task:S}){const N=S.status?.state||"unknown",O=S.status?.timestamp||"",o=S.history||[],_=S.artifacts||[],C=S.metadata?.stateTransitions||[],G={};let P=!1;if(S.metadata)for(const[g,Y]of Object.entries(S.metadata))!g.startsWith("_")&&g!=="stateTransitions"&&(G[g]=Y,P=!0);const M=S.status?.message?Za(S.status.message.parts||[]):"";return r.jsxs(r.Fragment,{children:[r.jsxs("div",{className:"task-detail-section",children:[r.jsxs("div",{className:"task-detail-row",children:[r.jsx("span",{className:"task-detail-label",children:"Task"}),r.jsx("span",{className:"task-detail-value",children:S.id||""})]}),r.jsxs("div",{className:"task-detail-row",children:[r.jsx("span",{className:"task-detail-label",children:"Context"}),r.jsx("span",{className:"task-detail-value",children:S.contextId||"—"})]}),r.jsxs("div",{className:"task-detail-row",children:[r.jsx("span",{className:"task-detail-label",children:"State"}),r.jsxs("span",{className:"task-detail-value",children:[r.jsx(Zn,{state:N})," ",O]})]}),M&&r.jsxs("div",{className:"task-detail-row",children:[r.jsx("span",{className:"task-detail-label",children:"Status"}),r.jsx("span",{className:"task-detail-value",style:{fontFamily:"var(--font)"},children:M})]})]}),C.length>0&&r.jsxs("div",{className:"task-detail-section",children:[r.jsx("h3",{children:"State Transitions"}),r.jsx("div",{className:"transitions-timeline",children:C.map((g,Y)=>r.jsxs("div",{className:"transition-item",children:[r.jsxs("div",{className:"transition-dot-col",children:[r.jsx("span",{className:"transition-dot"}),Y<C.length-1&&r.jsx("span",{className:"transition-line"})]}),r.jsxs("div",{className:"transition-content",children:[r.jsx(Zn,{state:g.state}),r.jsx("span",{className:"transition-ts",children:xm(g.timestamp)}),g.messageText&&r.jsx("span",{className:"transition-msg",children:g.messageText})]})]},Y))})]}),o.length>0&&r.jsxs("div",{className:"task-detail-section",children:[r.jsx("h3",{children:"History"}),o.map((g,Y)=>{const H=g.role||"unknown",X=H==="user"?"history-user":"history-agent";return r.jsxs("div",{className:`history-entry ${X}`,children:[r.jsxs("div",{className:"history-role",children:[H,g.messageId&&r.jsx("span",{style:{color:"var(--text-dim)",fontFamily:"var(--mono)",fontSize:10,marginLeft:6},children:g.messageId.substring(0,8)})]}),r.jsx(jm,{parts:g.parts||[]})]},Y)})]}),_.length>0&&r.jsxs("div",{className:"task-detail-section",children:[r.jsx("h3",{children:"Artifacts"}),_.map((g,Y)=>r.jsxs("div",{className:"artifact-item",children:[g.artifactId&&r.jsx("div",{className:"artifact-id",children:g.artifactId}),r.jsx(jm,{parts:g.parts||[]})]},Y))]}),P&&r.jsxs("div",{className:"task-detail-section",children:[r.jsx("h3",{children:"Metadata"}),r.jsx("div",{className:"metadata-block",children:JSON.stringify(G,null,2)})]})]})}const Av=(()=>{try{const S=new URLSearchParams(window.location.search),N=parseInt(S.get("poll")||"",10);if(N>0)return N*1e3}catch{}return 1e3})();function Ov(){const[S,N]=el.useState(null),[O,o]=el.useState(null),[_,C]=el.useState("chat"),[G,P]=el.useState(Av);el.useEffect(()=>{(async()=>{try{const g=await fetch("/.well-known/agent-card.json");if(!g.ok)throw new Error("HTTP "+g.status);N(await g.json())}catch(g){o(g instanceof Error?g.message:String(g))}})()},[]);const M=el.useCallback(g=>C(g),[]);return r.jsxs("div",{className:"app",children:[r.jsxs("div",{className:"header",children:[r.jsxs("div",{className:"header-left",children:[r.jsx("h1",{children:"a2akit Debug UI"}),r.jsxs("div",{className:"tabs",children:[r.jsx("button",{className:`tab${_==="chat"?" active":""}`,onClick:()=>M("chat"),children:"Chat"}),r.jsx("button",{className:`tab${_==="tasks"?" active":""}`,onClick:()=>M("tasks"),children:"Tasks"})]})]}),r.jsx("span",{className:"badge",children:"Experimental"})]}),r.jsxs("div",{className:"main",children:[r.jsx(dv,{card:S,error:O}),r.jsx("div",{className:"panel-right",children:_==="chat"?r.jsx(bv,{card:S}):r.jsx(zv,{card:S,active:_==="tasks",pollInterval:G,onPollIntervalChange:P})})]}),r.jsxs("div",{className:"footer",children:[r.jsxs("span",{children:["a2akit v","{{VERSION}}"]}),r.jsxs("span",{children:["Agent Card:"," ",r.jsx("a",{href:"/.well-known/agent-card.json",target:"_blank",rel:"noopener",children:"/.well-known/agent-card.json"})]})]})]})}sv.createRoot(document.getElementById("root")).render(r.jsx(el.StrictMode,{children:r.jsx(Ov,{})}));</script>
  <style rel="stylesheet" crossorigin>*,*:before,*:after{box-sizing:border-box;margin:0;padding:0}:root{--bg:#0d1017;--surface:#151921;--surface2:#1c2130;--surface3:#232a3b;--border:#2a3040;--border-light:#353d52;--text:#d0d4e0;--text-dim:#6b7394;--text-bright:#f0f2f8;--accent:#7c9aff;--accent-dim:#5a7ae6;--accent-glow:rgba(124,154,255,.12);--user-bg:linear-gradient(135deg,#1a3a6a,#1e4080);--user-border:#2a5090;--agent-bg:linear-gradient(135deg,#161d2e,#1a2338);--agent-border:#263050;--error:#f06868;--error-bg:rgba(240,104,104,.08);--success:#4eca60;--warning:#f0c040;--orange:#f09030;--purple:#a888f0;--radius:10px;--radius-lg:14px;--font:"Inter",system-ui,-apple-system,sans-serif;--mono:"JetBrains Mono","Fira Code",monospace;--shadow-sm:0 1px 3px rgba(0,0,0,.3);--shadow-md:0 4px 12px rgba(0,0,0,.25)}html,body,#root{height:100%;font-family:var(--font);background:var(--bg);color:var(--text);font-size:14px;line-height:1.6}a{color:var(--accent);text-decoration:none}a:hover{text-decoration:underline}.app{display:flex;flex-direction:column;height:100vh}.header{display:flex;align-items:center;justify-content:space-between;padding:10px 24px;border-bottom:1px solid var(--border);background:var(--surface);flex-shrink:0}.header-left{display:flex;align-items:center;gap:20px}.header-left h1{font-size:15px;font-weight:600;color:var(--text-bright);letter-spacing:-.2px}.badge{font-size:10px;padding:3px 10px;border-radius:12px;background:linear-gradient(135deg,#e8a820,#d09018);color:#1a1400;font-weight:700;text-transform:uppercase;letter-spacing:.5px;box-shadow:0 1px 4px #d090184d}.main{display:flex;flex:1;min-height:0}.footer{padding:8px 24px;border-top:1px solid var(--border);background:var(--surface);font-size:11px;color:var(--text-dim);display:flex;justify-content:space-between;flex-shrink:0}.tabs{display:flex;gap:1px;background:var(--surface2);border-radius:8px;padding:3px}.tab{padding:5px 18px;border:none;background:none;color:var(--text-dim);font-family:var(--font);font-size:12px;font-weight:500;cursor:pointer;border-radius:6px;transition:all .2s ease}.tab:hover{color:var(--text);background:var(--surface3)}.tab.active{background:var(--accent);color:#fff;box-shadow:0 1px 4px #7c9aff4d}.panel-left{width:280px;border-right:1px solid var(--border);background:var(--surface);overflow-y:auto;flex-shrink:0;padding:20px 16px}.panel-left h2{font-size:10px;font-weight:700;color:var(--text-dim);text-transform:uppercase;letter-spacing:1px;margin-bottom:12px}.info-group{margin-bottom:20px}.info-row{display:flex;justify-content:space-between;align-items:baseline;padding:5px 0;border-bottom:1px solid rgba(42,48,64,.5)}.info-row:last-child{border-bottom:none}.info-label{color:var(--text-dim);font-size:12px}.info-value{color:var(--text-bright);font-size:12px;font-weight:500;text-align:right;max-width:160px;word-break:break-all}.info-value.mono{font-family:var(--mono);font-size:11px}.check{color:var(--success)}.cross{color:var(--error)}.skill-item{padding:8px 10px;background:var(--surface2);border-radius:var(--radius);margin-bottom:6px;border:1px solid var(--border);transition:border-color .15s}.skill-item:hover{border-color:var(--border-light)}.skill-name{font-weight:600;font-size:12px;color:var(--text-bright)}.skill-desc{font-size:11px;color:var(--text-dim);margin-top:2px}.mode-tag{display:inline-block;font-size:10px;padding:2px 8px;background:var(--surface3);border:1px solid var(--border);border-radius:4px;margin:2px;font-family:var(--mono);color:var(--text)}.panel-right{flex:1;display:flex;flex-direction:column;min-width:0;background:var(--bg)}.chat-header{padding:12px 24px;border-bottom:1px solid var(--border);display:flex;align-items:center;justify-content:space-between;background:var(--surface)}.chat-header h2{font-size:13px;font-weight:600;color:var(--text-bright)}.chat-messages{flex:1;overflow-y:auto;padding:20px 24px;display:flex;flex-direction:column;gap:16px}.chat-input-area{padding:16px 24px;border-top:1px solid var(--border);display:flex;gap:10px;align-items:flex-end;background:var(--surface)}.chat-input-area textarea{flex:1;background:var(--surface2);border:1px solid var(--border);border-radius:var(--radius);padding:10px 14px;color:var(--text);font-family:var(--font);font-size:14px;resize:none;outline:none;min-height:44px;max-height:120px;transition:border-color .2s,box-shadow .2s}.chat-input-area textarea:focus{border-color:var(--accent);box-shadow:0 0 0 2px var(--accent-glow)}.chat-input-area textarea::placeholder{color:var(--text-dim)}.btn{padding:10px 20px;border:none;border-radius:var(--radius);font-family:var(--font);font-size:13px;font-weight:500;cursor:pointer;transition:all .2s ease}.btn-primary{background:linear-gradient(135deg,var(--accent),var(--accent-dim));color:#fff;box-shadow:0 2px 8px #7c9aff40}.btn-primary:hover{box-shadow:0 4px 16px #7c9aff59;transform:translateY(-1px)}.btn-primary:active{transform:translateY(0)}.btn-primary:disabled{opacity:.4;cursor:not-allowed;transform:none;box-shadow:none}.btn-secondary{background:var(--surface2);color:var(--text);border:1px solid var(--border)}.btn-secondary:hover{background:var(--surface3);border-color:var(--border-light)}.msg{padding:12px 16px;border-radius:var(--radius-lg);max-width:75%;word-wrap:break-word;white-space:pre-wrap;font-size:14px;box-shadow:var(--shadow-sm)}.msg-user{background:var(--user-bg);align-self:flex-end;color:var(--text-bright);border:1px solid var(--user-border);border-bottom-right-radius:4px}.msg-agent{background:var(--agent-bg);align-self:flex-start;border:1px solid var(--agent-border);border-bottom-left-radius:4px}.msg-status{align-self:center;color:var(--text-dim);font-size:12px;font-style:italic;padding:4px 14px;background:var(--surface2);border-radius:20px;border:1px solid var(--border);box-shadow:none}.msg-error{background:var(--error-bg);border:1px solid rgba(240,104,104,.3);color:var(--error);align-self:center;padding:10px 16px;border-radius:var(--radius);font-size:13px;box-shadow:none}.msg-label{font-size:10px;font-weight:700;color:var(--text-dim);margin-bottom:6px;text-transform:uppercase;letter-spacing:.5px;display:flex;align-items:center;gap:8px}.state-badge{display:inline-flex;align-items:center;gap:4px;font-size:9px;padding:2px 8px;border-radius:10px;font-weight:700;text-transform:uppercase;letter-spacing:.4px;vertical-align:middle}.state-badge:before{content:"";width:5px;height:5px;border-radius:50%;display:inline-block}.state-submitted{background:#2a2d3f;color:#7a7d9b}.state-submitted:before{background:#7a7d9b}.state-working{background:#162a5a;color:#7c9aff;animation:badge-pulse 2s ease-in-out infinite}.state-working:before{background:#7c9aff}.state-completed{background:#143020;color:var(--success)}.state-completed:before{background:var(--success)}.state-failed{background:#301414;color:var(--error)}.state-failed:before{background:var(--error)}.state-canceled{background:#302a14;color:var(--warning)}.state-canceled:before{background:var(--warning)}.state-rejected{background:#302014;color:var(--orange)}.state-rejected:before{background:var(--orange)}.state-input-required,.state-auth-required{background:#241430;color:var(--purple)}.state-input-required:before,.state-auth-required:before{background:var(--purple)}@keyframes badge-pulse{0%,to{opacity:1}50%{opacity:.5}}.loading{display:flex;align-items:center;gap:8px;color:var(--text-dim);font-size:13px;align-self:flex-start;padding:8px 16px}.dot-pulse{display:flex;gap:4px}.dot-pulse span{width:6px;height:6px;background:var(--accent);border-radius:50%;animation:pulse 1.4s ease-in-out infinite;opacity:.4}.dot-pulse span:nth-child(2){animation-delay:.2s}.dot-pulse span:nth-child(3){animation-delay:.4s}@keyframes pulse{0%,80%,to{opacity:.3;transform:scale(.8)}40%{opacity:1;transform:scale(1.1)}}.error-banner{padding:20px;background:var(--error-bg);border:1px solid rgba(240,104,104,.2);margin:20px;border-radius:var(--radius);text-align:center}.error-banner p{color:var(--error);margin-bottom:10px}.empty-state{flex:1;display:flex;align-items:center;justify-content:center;color:var(--text-dim);font-size:14px;padding:40px;opacity:.7}.tasks-header{padding:12px 24px;border-bottom:1px solid var(--border);display:flex;align-items:center;justify-content:space-between;background:var(--surface)}.tasks-header h2{font-size:13px;font-weight:600;color:var(--text-bright)}.tasks-status{font-size:11px;color:var(--text-dim);display:flex;align-items:center;gap:6px}.poll-dot{width:6px;height:6px;border-radius:50%;background:var(--success);display:inline-block;box-shadow:0 0 6px #4eca6066}.poll-dot.stale{background:var(--warning);box-shadow:0 0 6px #f0c04066}.poll-select{background:var(--surface2);color:var(--text);border:1px solid var(--border);border-radius:4px;padding:2px 6px;font-family:var(--font);font-size:11px;cursor:pointer;outline:none;transition:border-color .15s}.poll-select:focus{border-color:var(--accent)}.tasks-content{flex:1;overflow-y:auto}.task-table{width:100%;border-collapse:collapse}.task-table th{padding:8px 20px;text-align:left;font-size:10px;font-weight:700;color:var(--text-dim);text-transform:uppercase;letter-spacing:.8px;border-bottom:1px solid var(--border);background:var(--surface);position:sticky;top:0;z-index:1}.task-table td{padding:10px 20px;border-bottom:1px solid rgba(42,48,64,.5);font-size:13px;vertical-align:middle}.task-row{cursor:pointer;transition:background .15s}.task-row:hover{background:var(--surface2)}.task-id{font-family:var(--mono);font-size:12px;color:var(--accent);font-weight:500}.task-ctx,.task-time{font-family:var(--mono);font-size:11px;color:var(--text-dim)}.task-detail{background:var(--surface);border-bottom:2px solid var(--accent);border-left:3px solid var(--accent);padding:20px 24px}.task-detail-section{margin-bottom:18px}.task-detail-section:last-child{margin-bottom:0}.task-detail-section h3{font-size:10px;font-weight:700;color:var(--text-dim);text-transform:uppercase;letter-spacing:.8px;margin-bottom:10px}.task-detail-row{display:flex;gap:12px;margin-bottom:5px;font-size:13px}.task-detail-label{color:var(--text-dim);min-width:70px;font-size:12px}.task-detail-value{color:var(--text-bright);font-family:var(--mono);font-size:11px;word-break:break-all}.history-entry{padding:10px 14px;margin-bottom:8px;border-radius:var(--radius);font-size:13px;white-space:pre-wrap;word-break:break-word;border:1px solid transparent}.history-user{background:var(--user-bg);border-color:var(--user-border)}.history-agent{background:var(--agent-bg);border-color:var(--agent-border)}.history-role{font-size:10px;font-weight:700;color:var(--text-dim);text-transform:uppercase;letter-spacing:.5px;margin-bottom:4px}.artifact-item{padding:10px 14px;background:var(--surface2);border-radius:var(--radius);margin-bottom:8px;border:1px solid var(--border)}.artifact-id{font-size:10px;color:var(--text-dim);font-family:var(--mono);margin-bottom:6px}.artifact-text{white-space:pre-wrap;word-break:break-word}pre.json-block{background:var(--bg);padding:10px;border-radius:6px;font-family:var(--mono);font-size:11px;overflow-x:auto;white-space:pre-wrap;word-break:break-word;margin:4px 0;border:1px solid var(--border)}.metadata-block{background:var(--bg);padding:10px;border-radius:6px;font-family:var(--mono);font-size:11px;white-space:pre-wrap;word-break:break-word;border:1px solid var(--border)}.transitions-timeline{display:flex;flex-direction:column;gap:0;margin:4px 0 0 2px}.transition-item{display:flex;gap:10px;min-height:28px}.transition-dot-col{display:flex;flex-direction:column;align-items:center;width:12px;flex-shrink:0}.transition-dot{width:8px;height:8px;border-radius:50%;background:var(--accent);flex-shrink:0;margin-top:4px}.transition-line{width:1px;flex:1;background:var(--border-light);min-height:12px}.transition-content{display:flex;align-items:center;gap:8px;flex-wrap:wrap;padding-bottom:6px}.transition-ts{font-family:var(--mono);font-size:10px;color:var(--text-dim)}.transition-msg{font-size:11px;color:var(--text);font-style:italic;max-width:300px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.task-error{padding:14px;background:var(--error-bg);border:1px solid rgba(240,104,104,.2);border-radius:var(--radius);color:var(--error);font-size:13px}::-webkit-scrollbar{width:6px}::-webkit-scrollbar-track{background:transparent}::-webkit-scrollbar-thumb{background:var(--border);border-radius:3px}::-webkit-scrollbar-thumb:hover{background:var(--border-light)}</style>
</head>
<body>
<div id="root"></div>

</body>
</html>

"""


def mount_chat_ui(app: FastAPI) -> None:
    """Mount the debug chat UI at ``/chat``."""
    from importlib.metadata import version

    try:
        pkg_version = version("a2akit")
    except Exception:
        pkg_version = "dev"

    html = CHAT_HTML.replace("{{VERSION}}", pkg_version)

    @app.get("/chat", response_class=HTMLResponse, include_in_schema=False)
    async def debug_chat() -> HTMLResponse:
        return HTMLResponse(html)
